package com.alibaba.fastjson.parser;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPath;
import com.alibaba.fastjson.JSONPathException;
import com.alibaba.fastjson.parser.deserializer.ExtraProcessable;
import com.alibaba.fastjson.parser.deserializer.ExtraProcessor;
import com.alibaba.fastjson.parser.deserializer.ExtraTypeProvider;
import com.alibaba.fastjson.parser.deserializer.FieldDeserializer;
import com.alibaba.fastjson.parser.deserializer.FieldTypeResolver;
import com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer;
import com.alibaba.fastjson.parser.deserializer.MapDeserializer;
import com.alibaba.fastjson.parser.deserializer.ObjectDeserializer;
import com.alibaba.fastjson.parser.deserializer.PropertyProcessable;
import com.alibaba.fastjson.parser.deserializer.ResolveFieldDeserializer;
import com.alibaba.fastjson.serializer.BeanContext;
import com.alibaba.fastjson.serializer.IntegerCodec;
import com.alibaba.fastjson.serializer.LongCodec;
import com.alibaba.fastjson.serializer.SerializeConfig;
import com.alibaba.fastjson.serializer.StringCodec;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.io.Closeable;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.lang.reflect.WildcardType;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;
/* loaded from: classes.dex */
public class DefaultJSONParser implements Closeable {
    public static final int NONE = 0;
    public static final int NeedToResolve = 1;
    public static final int TypeNameRedirect = 2;
    private static final Set<Class<?>> primitiveClasses;
    private String[] autoTypeAccept;
    private boolean autoTypeEnable;
    protected ParserConfig config;
    protected ParseContext context;
    private ParseContext[] contextArray;
    private int contextArrayIndex;
    private DateFormat dateFormat;
    private String dateFormatPattern;
    private List<ExtraProcessor> extraProcessors;
    private List<ExtraTypeProvider> extraTypeProviders;
    protected FieldTypeResolver fieldTypeResolver;
    public final Object input;
    protected transient BeanContext lastBeanContext;
    public final JSONLexer lexer;
    private int objectKeyLevel;
    public int resolveStatus;
    private List<ResolveTask> resolveTaskList;
    public final SymbolTable symbolTable;

    static {
        HashSet hashSet = new HashSet();
        primitiveClasses = hashSet;
        hashSet.addAll(Arrays.asList(Boolean.TYPE, Byte.TYPE, Short.TYPE, Integer.TYPE, Long.TYPE, Float.TYPE, Double.TYPE, Boolean.class, Byte.class, Short.class, Integer.class, Long.class, Float.class, Double.class, BigInteger.class, BigDecimal.class, String.class));
    }

    public String getDateFomartPattern() {
        return this.dateFormatPattern;
    }

    public DateFormat getDateFormat() {
        if (this.dateFormat == null) {
            SimpleDateFormat simpleDateFormat = new SimpleDateFormat(this.dateFormatPattern, this.lexer.getLocale());
            this.dateFormat = simpleDateFormat;
            simpleDateFormat.setTimeZone(this.lexer.getTimeZone());
        }
        return this.dateFormat;
    }

    public void setDateFormat(String str) {
        this.dateFormatPattern = str;
        this.dateFormat = null;
    }

    public void setDateFomrat(DateFormat dateFormat) {
        setDateFormat(dateFormat);
    }

    public void setDateFormat(DateFormat dateFormat) {
        this.dateFormat = dateFormat;
    }

    public DefaultJSONParser(String str) {
        this(str, ParserConfig.getGlobalInstance(), JSON.DEFAULT_PARSER_FEATURE);
    }

    public DefaultJSONParser(String str, ParserConfig parserConfig) {
        this(str, new JSONScanner(str, JSON.DEFAULT_PARSER_FEATURE), parserConfig);
    }

    public DefaultJSONParser(String str, ParserConfig parserConfig, int i) {
        this(str, new JSONScanner(str, i), parserConfig);
    }

    public DefaultJSONParser(char[] cArr, int i, ParserConfig parserConfig, int i2) {
        this(cArr, new JSONScanner(cArr, i, i2), parserConfig);
    }

    public DefaultJSONParser(JSONLexer jSONLexer) {
        this(jSONLexer, ParserConfig.getGlobalInstance());
    }

    public DefaultJSONParser(JSONLexer jSONLexer, ParserConfig parserConfig) {
        this((Object) null, jSONLexer, parserConfig);
    }

    public DefaultJSONParser(Object obj, JSONLexer jSONLexer, ParserConfig parserConfig) {
        this.dateFormatPattern = JSON.DEFFAULT_DATE_FORMAT;
        this.contextArrayIndex = 0;
        this.resolveStatus = 0;
        this.extraTypeProviders = null;
        this.extraProcessors = null;
        this.fieldTypeResolver = null;
        this.objectKeyLevel = 0;
        this.autoTypeAccept = null;
        this.lexer = jSONLexer;
        this.input = obj;
        this.config = parserConfig;
        this.symbolTable = parserConfig.symbolTable;
        char current = jSONLexer.getCurrent();
        if (current == '{') {
            jSONLexer.next();
            ((JSONLexerBase) jSONLexer).token = 12;
        } else if (current == '[') {
            jSONLexer.next();
            ((JSONLexerBase) jSONLexer).token = 14;
        } else {
            jSONLexer.nextToken();
        }
    }

    public SymbolTable getSymbolTable() {
        return this.symbolTable;
    }

    public String getInput() {
        Object obj = this.input;
        if (obj instanceof char[]) {
            return new String((char[]) obj);
        }
        return obj.toString();
    }

    /* JADX WARN: Code restructure failed: missing block: B:147:0x0299, code lost:
        r4.nextToken(16);
     */
    /* JADX WARN: Code restructure failed: missing block: B:148:0x02a4, code lost:
        if (r4.token() != 13) goto L83;
     */
    /* JADX WARN: Code restructure failed: missing block: B:149:0x02a6, code lost:
        r4.nextToken(16);
     */
    /* JADX WARN: Code restructure failed: missing block: B:151:0x02b1, code lost:
        if ((r17.config.getDeserializer(r7) instanceof com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) == false) goto L79;
     */
    /* JADX WARN: Code restructure failed: missing block: B:152:0x02b3, code lost:
        r0 = com.alibaba.fastjson.util.TypeUtils.cast((java.lang.Object) r18, (java.lang.Class<java.lang.Object>) r7, r17.config);
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x02ba, code lost:
        r0 = r12;
     */
    /* JADX WARN: Code restructure failed: missing block: B:154:0x02bb, code lost:
        if (r0 != null) goto L77;
     */
    /* JADX WARN: Code restructure failed: missing block: B:156:0x02bf, code lost:
        if (r7 != java.lang.Cloneable.class) goto L70;
     */
    /* JADX WARN: Code restructure failed: missing block: B:157:0x02c1, code lost:
        r0 = new java.util.HashMap();
     */
    /* JADX WARN: Code restructure failed: missing block: B:159:0x02cd, code lost:
        if ("java.util.Collections$EmptyMap".equals(r6) == false) goto L73;
     */
    /* JADX WARN: Code restructure failed: missing block: B:160:0x02cf, code lost:
        r0 = java.util.Collections.emptyMap();
     */
    /* JADX WARN: Code restructure failed: missing block: B:162:0x02da, code lost:
        if ("java.util.Collections$UnmodifiableMap".equals(r6) == false) goto L76;
     */
    /* JADX WARN: Code restructure failed: missing block: B:163:0x02dc, code lost:
        r0 = java.util.Collections.unmodifiableMap(new java.util.HashMap());
     */
    /* JADX WARN: Code restructure failed: missing block: B:164:0x02e6, code lost:
        r0 = r7.newInstance();
     */
    /* JADX WARN: Code restructure failed: missing block: B:166:0x02ed, code lost:
        return r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:167:0x02ee, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:169:0x02f6, code lost:
        throw new com.alibaba.fastjson.JSONException("create instance error", r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:170:0x02f7, code lost:
        setResolveStatus(2);
        r3 = r17.context;
     */
    /* JADX WARN: Code restructure failed: missing block: B:171:0x02fd, code lost:
        if (r3 == null) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:172:0x02ff, code lost:
        if (r19 == null) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:174:0x0303, code lost:
        if ((r19 instanceof java.lang.Integer) != false) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:176:0x0309, code lost:
        if ((r3.fieldName instanceof java.lang.Integer) != false) goto L91;
     */
    /* JADX WARN: Code restructure failed: missing block: B:177:0x030b, code lost:
        popContext();
     */
    /* JADX WARN: Code restructure failed: missing block: B:179:0x0312, code lost:
        if (r18.size() <= 0) goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:180:0x0314, code lost:
        r0 = com.alibaba.fastjson.util.TypeUtils.cast((java.lang.Object) r18, (java.lang.Class<java.lang.Object>) r7, r17.config);
        setResolveStatus(0);
        parseObject(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:182:0x0324, code lost:
        return r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:183:0x0325, code lost:
        r0 = r17.config.getDeserializer(r7);
        r3 = r0.getClass();
     */
    /* JADX WARN: Code restructure failed: missing block: B:184:0x0335, code lost:
        if (com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer.class.isAssignableFrom(r3) == false) goto L106;
     */
    /* JADX WARN: Code restructure failed: missing block: B:186:0x0339, code lost:
        if (r3 == com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer.class) goto L106;
     */
    /* JADX WARN: Code restructure failed: missing block: B:188:0x033d, code lost:
        if (r3 == com.alibaba.fastjson.parser.deserializer.ThrowableDeserializer.class) goto L106;
     */
    /* JADX WARN: Code restructure failed: missing block: B:189:0x033f, code lost:
        setResolveStatus(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:191:0x0346, code lost:
        if ((r0 instanceof com.alibaba.fastjson.parser.deserializer.MapDeserializer) == false) goto L103;
     */
    /* JADX WARN: Code restructure failed: missing block: B:192:0x0348, code lost:
        setResolveStatus(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:195:0x0353, code lost:
        return r0.deserialze(r17, r7, r19);
     */
    /* JADX WARN: Removed duplicated region for block: B:115:0x0214 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:146:0x0293 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:255:0x0461 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:272:0x048a A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:279:0x04b3  */
    /* JADX WARN: Removed duplicated region for block: B:292:0x04e6 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:349:0x05eb A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:354:0x05f7 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:357:0x0603 A[Catch: all -> 0x06a5, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:363:0x0618 A[Catch: all -> 0x06a5, TRY_ENTER, TryCatch #1 {all -> 0x06a5, blocks: (B:24:0x0070, B:26:0x0074, B:29:0x007e, B:32:0x0091, B:36:0x00aa, B:115:0x0214, B:116:0x021a, B:118:0x0225, B:120:0x022d, B:124:0x0242, B:126:0x0250, B:146:0x0293, B:147:0x0299, B:149:0x02a6, B:150:0x02a9, B:152:0x02b3, B:157:0x02c1, B:158:0x02c7, B:160:0x02cf, B:161:0x02d4, B:163:0x02dc, B:164:0x02e6, B:168:0x02ef, B:169:0x02f6, B:170:0x02f7, B:173:0x0301, B:175:0x0305, B:177:0x030b, B:178:0x030e, B:180:0x0314, B:183:0x0325, B:189:0x033f, B:193:0x034c, B:190:0x0344, B:192:0x0348, B:127:0x0255, B:131:0x0261, B:135:0x026d, B:137:0x0273, B:142:0x0280, B:143:0x0283, B:200:0x035d, B:202:0x0363, B:204:0x036b, B:206:0x0375, B:208:0x0386, B:210:0x0391, B:212:0x0399, B:214:0x039d, B:216:0x03a3, B:219:0x03a8, B:221:0x03ac, B:244:0x0412, B:246:0x041a, B:249:0x0423, B:250:0x043e, B:223:0x03b3, B:225:0x03bb, B:227:0x03bf, B:228:0x03c2, B:229:0x03ce, B:232:0x03d7, B:234:0x03db, B:235:0x03de, B:237:0x03e2, B:238:0x03e6, B:239:0x03f2, B:241:0x03fc, B:243:0x0409, B:251:0x043f, B:252:0x045d, B:255:0x0461, B:257:0x0465, B:259:0x0469, B:261:0x046f, B:262:0x0472, B:266:0x047a, B:272:0x048a, B:274:0x0499, B:276:0x04a4, B:277:0x04ac, B:278:0x04af, B:290:0x04db, B:292:0x04e6, B:296:0x04f3, B:299:0x0503, B:300:0x0524, B:285:0x04bf, B:287:0x04c9, B:289:0x04d8, B:288:0x04ce, B:303:0x0529, B:305:0x0533, B:307:0x053b, B:308:0x053e, B:310:0x0549, B:311:0x054d, B:313:0x0558, B:316:0x055f, B:319:0x0568, B:320:0x056d, B:323:0x0572, B:325:0x0577, B:329:0x0582, B:331:0x058a, B:333:0x059f, B:337:0x05be, B:339:0x05c6, B:342:0x05cc, B:344:0x05d2, B:346:0x05da, B:349:0x05eb, B:352:0x05f3, B:354:0x05f7, B:355:0x05fe, B:357:0x0603, B:358:0x0606, B:360:0x060e, B:363:0x0618, B:366:0x0622, B:367:0x0627, B:368:0x062c, B:369:0x0647, B:334:0x05aa, B:335:0x05b1, B:370:0x0648, B:372:0x065a, B:375:0x0661, B:378:0x066f, B:379:0x0690, B:39:0x00bc, B:40:0x00da, B:43:0x00df, B:45:0x00ea, B:47:0x00ee, B:49:0x00f2, B:51:0x00f8, B:52:0x00fb, B:59:0x010a, B:61:0x0112, B:64:0x0122, B:65:0x013a, B:66:0x013b, B:67:0x0140, B:78:0x0155, B:79:0x015b, B:81:0x0162, B:83:0x016b, B:90:0x017d, B:93:0x0185, B:94:0x019d, B:88:0x0178, B:82:0x0167, B:95:0x019e, B:96:0x01b6, B:102:0x01c0, B:104:0x01c8, B:107:0x01d9, B:108:0x01f9, B:109:0x01fa, B:110:0x01ff, B:111:0x0200, B:113:0x020a, B:380:0x0691, B:381:0x0698, B:382:0x0699, B:383:0x069e, B:384:0x069f, B:385:0x06a4), top: B:390:0x0070, inners: #0, #2 }] */
    /* JADX WARN: Removed duplicated region for block: B:403:0x0185 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:405:0x0299 A[EDGE_INSN: B:405:0x0299->B:147:0x0299 ?: BREAK  , SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:410:0x060e A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:418:0x04ef A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:92:0x0183  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final Object parseObject(Map map, Object obj) {
        Object parse;
        boolean z;
        char current;
        Map jSONObject;
        boolean z2;
        Object obj2;
        Object obj3;
        char current2;
        Object fluentPut;
        Object obj4;
        Class<?> cls;
        JSONLexer jSONLexer = this.lexer;
        if (jSONLexer.token() == 8) {
            jSONLexer.nextToken();
            return null;
        } else if (jSONLexer.token() == 13) {
            jSONLexer.nextToken();
            return map;
        } else if (jSONLexer.token() == 4 && jSONLexer.stringVal().length() == 0) {
            jSONLexer.nextToken();
            return map;
        } else if (jSONLexer.token() != 12 && jSONLexer.token() != 16) {
            throw new JSONException("syntax error, expect {, actual " + jSONLexer.tokenName() + ", " + jSONLexer.info());
        } else {
            ParseContext parseContext = this.context;
            try {
                boolean z3 = map instanceof JSONObject;
                Map<String, Object> innerMap = z3 ? ((JSONObject) map).getInnerMap() : map;
                boolean z4 = false;
                while (true) {
                    jSONLexer.skipWhitespace();
                    char current3 = jSONLexer.getCurrent();
                    if (jSONLexer.isEnabled(Feature.AllowArbitraryCommas)) {
                        while (current3 == ',') {
                            jSONLexer.next();
                            jSONLexer.skipWhitespace();
                            current3 = jSONLexer.getCurrent();
                        }
                    }
                    if (current3 == '\"') {
                        parse = jSONLexer.scanSymbol(this.symbolTable, '\"');
                        jSONLexer.skipWhitespace();
                        if (jSONLexer.getCurrent() != ':') {
                            throw new JSONException("expect ':' at " + jSONLexer.pos() + ", name " + parse);
                        }
                    } else if (current3 == '}') {
                        jSONLexer.next();
                        jSONLexer.resetStringPosition();
                        jSONLexer.nextToken();
                        if (!z4) {
                            ParseContext parseContext2 = this.context;
                            if (parseContext2 != null && obj == parseContext2.fieldName && map == this.context.object) {
                                parseContext = this.context;
                            } else {
                                ParseContext context = setContext(map, obj);
                                if (parseContext == null) {
                                    parseContext = context;
                                }
                            }
                        }
                        return map;
                    } else if (current3 == '\'') {
                        if (!jSONLexer.isEnabled(Feature.AllowSingleQuotes)) {
                            throw new JSONException("syntax error");
                        }
                        parse = jSONLexer.scanSymbol(this.symbolTable, Operators.SINGLE_QUOTE);
                        jSONLexer.skipWhitespace();
                        if (jSONLexer.getCurrent() != ':') {
                            throw new JSONException("expect ':' at " + jSONLexer.pos());
                        }
                    } else if (current3 == 26) {
                        throw new JSONException("syntax error");
                    } else {
                        if (current3 == ',') {
                            throw new JSONException("syntax error");
                        }
                        if ((current3 < '0' || current3 > '9') && current3 != '-') {
                            if (current3 != '{' && current3 != '[') {
                                if (!jSONLexer.isEnabled(Feature.AllowUnQuotedFieldNames)) {
                                    throw new JSONException("syntax error");
                                }
                                parse = jSONLexer.scanSymbolUnQuoted(this.symbolTable);
                                jSONLexer.skipWhitespace();
                                char current4 = jSONLexer.getCurrent();
                                if (current4 != ':') {
                                    throw new JSONException("expect ':' at " + jSONLexer.pos() + ", actual " + current4);
                                }
                            }
                            int i = this.objectKeyLevel;
                            this.objectKeyLevel = i + 1;
                            if (i > 512) {
                                throw new JSONException("object key level > 512");
                            }
                            jSONLexer.nextToken();
                            parse = parse();
                            z = true;
                            if (!z) {
                                jSONLexer.next();
                                jSONLexer.skipWhitespace();
                            }
                            current = jSONLexer.getCurrent();
                            jSONLexer.resetStringPosition();
                            if (parse != JSON.DEFAULT_TYPE_KEY && !jSONLexer.isEnabled(Feature.DisableSpecialKeyDetect)) {
                                String scanSymbol = jSONLexer.scanSymbol(this.symbolTable, '\"');
                                if (!jSONLexer.isEnabled(Feature.IgnoreAutoType)) {
                                    if (map != null && map.getClass().getName().equals(scanSymbol)) {
                                        cls = map.getClass();
                                    } else if ("java.util.HashMap".equals(scanSymbol)) {
                                        cls = HashMap.class;
                                    } else if (!"java.util.LinkedHashMap".equals(scanSymbol)) {
                                        for (int i2 = 0; i2 < scanSymbol.length(); i2++) {
                                            char charAt = scanSymbol.charAt(i2);
                                            if (charAt >= '0' && charAt <= '9') {
                                            }
                                            obj4 = null;
                                            cls = this.config.checkAutoType(scanSymbol, null, jSONLexer.getFeatures());
                                        }
                                        obj4 = null;
                                        cls = null;
                                        if (cls == null) {
                                            break;
                                        }
                                        innerMap.put(JSON.DEFAULT_TYPE_KEY, scanSymbol);
                                    } else {
                                        cls = LinkedHashMap.class;
                                    }
                                    obj4 = null;
                                    if (cls == null) {
                                    }
                                }
                            } else if (parse == "$ref" || parseContext == null || (!(map == null || map.size() == 0) || jSONLexer.isEnabled(Feature.DisableSpecialKeyDetect))) {
                                if (!z4) {
                                    ParseContext parseContext3 = this.context;
                                    if (parseContext3 != null && obj == parseContext3.fieldName && map == this.context.object) {
                                        parseContext = this.context;
                                    } else {
                                        ParseContext context2 = setContext(map, obj);
                                        if (parseContext == null) {
                                            parseContext = context2;
                                        }
                                        z4 = true;
                                    }
                                }
                                if (map.getClass() == JSONObject.class && parse == null) {
                                    parse = "null";
                                }
                                if (current != '\"') {
                                    jSONLexer.scanString();
                                    String stringVal = jSONLexer.stringVal();
                                    Number number = stringVal;
                                    if (jSONLexer.isEnabled(Feature.AllowISO8601DateFormat)) {
                                        JSONScanner jSONScanner = new JSONScanner(stringVal);
                                        Date date = stringVal;
                                        if (jSONScanner.scanISO8601DateIfMatch()) {
                                            date = jSONScanner.getCalendar().getTime();
                                        }
                                        jSONScanner.close();
                                        number = date;
                                    }
                                    innerMap.put(parse, number);
                                    obj3 = number;
                                } else if ((current >= '0' && current <= '9') || current == '-') {
                                    jSONLexer.scanNumber();
                                    Number integerValue = jSONLexer.token() == 2 ? jSONLexer.integerValue() : jSONLexer.decimalValue(jSONLexer.isEnabled(Feature.UseBigDecimal));
                                    innerMap.put(parse, integerValue);
                                    obj3 = integerValue;
                                } else if (current == '[') {
                                    jSONLexer.nextToken();
                                    Collection jSONArray = new JSONArray();
                                    if (obj != null) {
                                        obj.getClass();
                                    }
                                    if (obj == null) {
                                        setContext(parseContext);
                                    }
                                    parseArray(jSONArray, parse);
                                    Object[] objArr = jSONArray;
                                    if (jSONLexer.isEnabled(Feature.UseObjectArray)) {
                                        objArr = jSONArray.toArray();
                                    }
                                    innerMap.put(parse, objArr);
                                    if (jSONLexer.token() == 13) {
                                        jSONLexer.nextToken();
                                        return map;
                                    } else if (jSONLexer.token() != 16) {
                                        throw new JSONException("syntax error");
                                    }
                                } else if (current == '{') {
                                    jSONLexer.nextToken();
                                    boolean z5 = obj != null && obj.getClass() == Integer.class;
                                    if (jSONLexer.isEnabled(Feature.CustomMapDeserializer)) {
                                        MapDeserializer mapDeserializer = (MapDeserializer) this.config.getDeserializer(Map.class);
                                        jSONObject = (jSONLexer.getFeatures() & Feature.OrderedField.mask) != 0 ? mapDeserializer.createMap(Map.class, jSONLexer.getFeatures()) : mapDeserializer.createMap(Map.class);
                                    } else {
                                        jSONObject = new JSONObject(jSONLexer.isEnabled(Feature.OrderedField));
                                    }
                                    ParseContext context3 = !z5 ? setContext(this.context, jSONObject, parse) : null;
                                    if (this.fieldTypeResolver != null) {
                                        Type resolve = this.fieldTypeResolver.resolve(map, parse != null ? parse.toString() : null);
                                        if (resolve != null) {
                                            obj2 = this.config.getDeserializer(resolve).deserialze(this, resolve, parse);
                                            z2 = true;
                                            if (!z2) {
                                                obj2 = parseObject(jSONObject, parse);
                                            }
                                            if (context3 != null && jSONObject != obj2) {
                                                context3.object = map;
                                            }
                                            if (parse != null) {
                                                checkMapResolve(map, parse.toString());
                                            }
                                            innerMap.put(parse, obj2);
                                            if (z5) {
                                                setContext(obj2, parse);
                                            }
                                            if (jSONLexer.token() != 13) {
                                                jSONLexer.nextToken();
                                                setContext(parseContext);
                                                return map;
                                            } else if (jSONLexer.token() != 16) {
                                                throw new JSONException("syntax error, " + jSONLexer.tokenName());
                                            } else if (z5) {
                                                popContext();
                                            } else {
                                                setContext(parseContext);
                                            }
                                        }
                                    }
                                    z2 = false;
                                    obj2 = null;
                                    if (!z2) {
                                    }
                                    if (context3 != null) {
                                        context3.object = map;
                                    }
                                    if (parse != null) {
                                    }
                                    innerMap.put(parse, obj2);
                                    if (z5) {
                                    }
                                    if (jSONLexer.token() != 13) {
                                    }
                                } else {
                                    jSONLexer.nextToken();
                                    innerMap.put(parse, parse());
                                    if (jSONLexer.token() == 13) {
                                        jSONLexer.nextToken();
                                        return map;
                                    } else if (jSONLexer.token() != 16) {
                                        throw new JSONException("syntax error, position at " + jSONLexer.pos() + ", name " + parse);
                                    }
                                }
                                jSONLexer.skipWhitespace();
                                current2 = jSONLexer.getCurrent();
                                if (current2 == ',') {
                                    if (current2 == '}') {
                                        jSONLexer.next();
                                        jSONLexer.resetStringPosition();
                                        jSONLexer.nextToken();
                                        setContext(obj3, parse);
                                        return map;
                                    }
                                    throw new JSONException("syntax error, position at " + jSONLexer.pos() + ", name " + parse);
                                }
                                jSONLexer.next();
                            } else {
                                jSONLexer.nextToken(4);
                                if (jSONLexer.token() != 4) {
                                    throw new JSONException("illegal ref, " + JSONToken.name(jSONLexer.token()));
                                }
                                String stringVal2 = jSONLexer.stringVal();
                                jSONLexer.nextToken(13);
                                if (jSONLexer.token() != 16) {
                                    if ("@".equals(stringVal2)) {
                                        ParseContext parseContext4 = this.context;
                                        if (parseContext4 != null) {
                                            Object obj5 = parseContext4.object;
                                            if (!(obj5 instanceof Object[]) && !(obj5 instanceof Collection)) {
                                                if (parseContext4.parent != null) {
                                                    fluentPut = parseContext4.parent.object;
                                                }
                                            }
                                            fluentPut = obj5;
                                        }
                                        fluentPut = null;
                                    } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(stringVal2)) {
                                        if (parseContext.object != null) {
                                            fluentPut = parseContext.object;
                                        } else {
                                            addResolveTask(new ResolveTask(parseContext, stringVal2));
                                            setResolveStatus(1);
                                            fluentPut = null;
                                        }
                                    } else if (Operators.DOLLAR_STR.equals(stringVal2)) {
                                        ParseContext parseContext5 = parseContext;
                                        while (parseContext5.parent != null) {
                                            parseContext5 = parseContext5.parent;
                                        }
                                        if (parseContext5.object != null) {
                                            fluentPut = parseContext5.object;
                                        } else {
                                            addResolveTask(new ResolveTask(parseContext5, stringVal2));
                                            setResolveStatus(1);
                                            fluentPut = null;
                                        }
                                    } else if (JSONPath.compile(stringVal2).isRef()) {
                                        addResolveTask(new ResolveTask(parseContext, stringVal2));
                                        setResolveStatus(1);
                                        fluentPut = null;
                                    } else {
                                        fluentPut = new JSONObject().fluentPut("$ref", stringVal2);
                                    }
                                    if (jSONLexer.token() == 13) {
                                        jSONLexer.nextToken(16);
                                        return fluentPut;
                                    }
                                    throw new JSONException("syntax error, " + jSONLexer.info());
                                }
                                innerMap.put(parse, stringVal2);
                            }
                        } else {
                            jSONLexer.resetStringPosition();
                            jSONLexer.scanNumber();
                            try {
                                Object integerValue2 = jSONLexer.token() == 2 ? jSONLexer.integerValue() : jSONLexer.decimalValue(true);
                                if (!jSONLexer.isEnabled(Feature.NonStringKeyAsString)) {
                                    if (z3) {
                                    }
                                    parse = integerValue2;
                                    if (jSONLexer.getCurrent() == ':') {
                                        throw new JSONException("parse number key error" + jSONLexer.info());
                                    }
                                }
                                integerValue2 = integerValue2.toString();
                                parse = integerValue2;
                                if (jSONLexer.getCurrent() == ':') {
                                }
                            } catch (NumberFormatException unused) {
                                throw new JSONException("parse number key error" + jSONLexer.info());
                            }
                        }
                    }
                    z = false;
                    if (!z) {
                    }
                    current = jSONLexer.getCurrent();
                    jSONLexer.resetStringPosition();
                    if (parse != JSON.DEFAULT_TYPE_KEY) {
                    }
                    if (parse == "$ref") {
                    }
                    if (!z4) {
                    }
                    if (map.getClass() == JSONObject.class) {
                        parse = "null";
                    }
                    if (current != '\"') {
                    }
                    jSONLexer.skipWhitespace();
                    current2 = jSONLexer.getCurrent();
                    if (current2 == ',') {
                    }
                }
            } finally {
                setContext(parseContext);
            }
        }
    }

    public ParserConfig getConfig() {
        return this.config;
    }

    public void setConfig(ParserConfig parserConfig) {
        this.config = parserConfig;
    }

    public <T> T parseObject(Class<T> cls) {
        return (T) parseObject(cls, (Object) null);
    }

    public <T> T parseObject(Type type) {
        return (T) parseObject(type, (Object) null);
    }

    public <T> T parseObject(Type type, Object obj) {
        int i = this.lexer.token();
        if (i == 8) {
            this.lexer.nextToken();
            return (T) TypeUtils.optionalEmpty(type);
        }
        if (i == 4) {
            if (type == byte[].class) {
                T t = (T) this.lexer.bytesValue();
                this.lexer.nextToken();
                return t;
            } else if (type == char[].class) {
                String stringVal = this.lexer.stringVal();
                this.lexer.nextToken();
                return (T) stringVal.toCharArray();
            }
        }
        ObjectDeserializer deserializer = this.config.getDeserializer(type);
        try {
            if (deserializer.getClass() == JavaBeanDeserializer.class) {
                if (this.lexer.token() != 12 && this.lexer.token() != 14) {
                    throw new JSONException("syntax error,expect start with { or [,but actually start with " + this.lexer.tokenName());
                }
                return (T) ((JavaBeanDeserializer) deserializer).deserialze(this, type, obj, 0);
            }
            return (T) deserializer.deserialze(this, type, obj);
        } catch (JSONException e) {
            throw e;
        } catch (Throwable th) {
            throw new JSONException(th.getMessage(), th);
        }
    }

    public <T> List<T> parseArray(Class<T> cls) {
        ArrayList arrayList = new ArrayList();
        parseArray((Class<?>) cls, (Collection) arrayList);
        return arrayList;
    }

    public void parseArray(Class<?> cls, Collection collection) {
        parseArray((Type) cls, collection);
    }

    public void parseArray(Type type, Collection collection) {
        parseArray(type, collection, null);
    }

    public void parseArray(Type type, Collection collection, Object obj) {
        ObjectDeserializer deserializer;
        int i = this.lexer.token();
        if (i == 21 || i == 22) {
            this.lexer.nextToken();
            i = this.lexer.token();
        }
        if (i != 14) {
            throw new JSONException("field " + obj + " expect '[', but " + JSONToken.name(i) + ", " + this.lexer.info());
        }
        if (Integer.TYPE == type) {
            deserializer = IntegerCodec.instance;
            this.lexer.nextToken(2);
        } else if (String.class == type) {
            deserializer = StringCodec.instance;
            this.lexer.nextToken(4);
        } else {
            deserializer = this.config.getDeserializer(type);
            this.lexer.nextToken(deserializer.getFastMatchToken());
        }
        ParseContext parseContext = this.context;
        setContext(collection, obj);
        int i2 = 0;
        while (true) {
            try {
                if (this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                    while (this.lexer.token() == 16) {
                        this.lexer.nextToken();
                    }
                }
                if (this.lexer.token() != 15) {
                    Object obj2 = null;
                    if (Integer.TYPE == type) {
                        collection.add(IntegerCodec.instance.deserialze(this, null, null));
                    } else if (String.class == type) {
                        if (this.lexer.token() == 4) {
                            obj2 = this.lexer.stringVal();
                            this.lexer.nextToken(16);
                        } else {
                            Object parse = parse();
                            if (parse != null) {
                                obj2 = parse.toString();
                            }
                        }
                        collection.add(obj2);
                    } else {
                        if (this.lexer.token() == 8) {
                            this.lexer.nextToken();
                        } else {
                            obj2 = deserializer.deserialze(this, type, Integer.valueOf(i2));
                        }
                        collection.add(obj2);
                        checkListResolve(collection);
                    }
                    if (this.lexer.token() == 16) {
                        this.lexer.nextToken(deserializer.getFastMatchToken());
                    }
                    i2++;
                } else {
                    setContext(parseContext);
                    this.lexer.nextToken(16);
                    return;
                }
            } catch (Throwable th) {
                setContext(parseContext);
                throw th;
            }
        }
    }

    public Object[] parseArray(Type[] typeArr) {
        Object cast;
        Class<?> cls;
        boolean z;
        Class cls2;
        int i = 8;
        if (this.lexer.token() == 8) {
            this.lexer.nextToken(16);
            return null;
        }
        int i2 = 14;
        if (this.lexer.token() != 14) {
            throw new JSONException("syntax error : " + this.lexer.tokenName());
        }
        Object[] objArr = new Object[typeArr.length];
        if (typeArr.length == 0) {
            this.lexer.nextToken(15);
            if (this.lexer.token() != 15) {
                throw new JSONException("syntax error");
            }
            this.lexer.nextToken(16);
            return new Object[0];
        }
        this.lexer.nextToken(2);
        int i3 = 0;
        while (i3 < typeArr.length) {
            if (this.lexer.token() == i) {
                this.lexer.nextToken(16);
                cast = null;
            } else {
                Type type = typeArr[i3];
                if (type == Integer.TYPE || type == Integer.class) {
                    if (this.lexer.token() == 2) {
                        cast = Integer.valueOf(this.lexer.intValue());
                        this.lexer.nextToken(16);
                    } else {
                        cast = TypeUtils.cast(parse(), type, this.config);
                    }
                } else if (type == String.class) {
                    if (this.lexer.token() == 4) {
                        cast = this.lexer.stringVal();
                        this.lexer.nextToken(16);
                    } else {
                        cast = TypeUtils.cast(parse(), type, this.config);
                    }
                } else {
                    if (i3 == typeArr.length - 1 && (type instanceof Class) && (((cls2 = (Class) type) != byte[].class && cls2 != char[].class) || this.lexer.token() != 4)) {
                        z = cls2.isArray();
                        cls = cls2.getComponentType();
                    } else {
                        cls = null;
                        z = false;
                    }
                    if (z && this.lexer.token() != i2) {
                        ArrayList arrayList = new ArrayList();
                        ObjectDeserializer deserializer = this.config.getDeserializer(cls);
                        int fastMatchToken = deserializer.getFastMatchToken();
                        if (this.lexer.token() != 15) {
                            while (true) {
                                arrayList.add(deserializer.deserialze(this, type, null));
                                if (this.lexer.token() != 16) {
                                    break;
                                }
                                this.lexer.nextToken(fastMatchToken);
                            }
                            if (this.lexer.token() != 15) {
                                throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
                            }
                        }
                        cast = TypeUtils.cast(arrayList, type, this.config);
                    } else {
                        cast = this.config.getDeserializer(type).deserialze(this, type, Integer.valueOf(i3));
                    }
                }
            }
            objArr[i3] = cast;
            if (this.lexer.token() == 15) {
                break;
            } else if (this.lexer.token() != 16) {
                throw new JSONException("syntax error :" + JSONToken.name(this.lexer.token()));
            } else {
                if (i3 == typeArr.length - 1) {
                    this.lexer.nextToken(15);
                } else {
                    this.lexer.nextToken(2);
                }
                i3++;
                i = 8;
                i2 = 14;
            }
        }
        if (this.lexer.token() != 15) {
            throw new JSONException("syntax error");
        }
        this.lexer.nextToken(16);
        return objArr;
    }

    public void parseObject(Object obj) {
        Object deserialze;
        Class<?> cls = obj.getClass();
        ObjectDeserializer deserializer = this.config.getDeserializer(cls);
        JavaBeanDeserializer javaBeanDeserializer = deserializer instanceof JavaBeanDeserializer ? (JavaBeanDeserializer) deserializer : null;
        if (this.lexer.token() != 12 && this.lexer.token() != 16) {
            throw new JSONException("syntax error, expect {, actual " + this.lexer.tokenName());
        }
        while (true) {
            String scanSymbol = this.lexer.scanSymbol(this.symbolTable);
            if (scanSymbol == null) {
                if (this.lexer.token() == 13) {
                    this.lexer.nextToken(16);
                    return;
                } else if (this.lexer.token() == 16 && this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                }
            }
            FieldDeserializer fieldDeserializer = javaBeanDeserializer != null ? javaBeanDeserializer.getFieldDeserializer(scanSymbol) : null;
            if (fieldDeserializer == null) {
                if (!this.lexer.isEnabled(Feature.IgnoreNotMatch)) {
                    throw new JSONException("setter not found, class " + cls.getName() + ", property " + scanSymbol);
                }
                this.lexer.nextTokenWithColon();
                parse();
                if (this.lexer.token() == 13) {
                    this.lexer.nextToken();
                    return;
                }
            } else {
                Class<?> cls2 = fieldDeserializer.fieldInfo.fieldClass;
                Type type = fieldDeserializer.fieldInfo.fieldType;
                if (cls2 == Integer.TYPE) {
                    this.lexer.nextTokenWithColon(2);
                    deserialze = IntegerCodec.instance.deserialze(this, type, null);
                } else if (cls2 == String.class) {
                    this.lexer.nextTokenWithColon(4);
                    deserialze = StringCodec.deserialze(this);
                } else if (cls2 == Long.TYPE) {
                    this.lexer.nextTokenWithColon(2);
                    deserialze = LongCodec.instance.deserialze(this, type, null);
                } else {
                    ObjectDeserializer deserializer2 = this.config.getDeserializer(cls2, type);
                    this.lexer.nextTokenWithColon(deserializer2.getFastMatchToken());
                    deserialze = deserializer2.deserialze(this, type, null);
                }
                fieldDeserializer.setValue(obj, deserialze);
                if (this.lexer.token() != 16 && this.lexer.token() == 13) {
                    this.lexer.nextToken(16);
                    return;
                }
            }
        }
    }

    public Object parseArrayWithType(Type type) {
        if (this.lexer.token() == 8) {
            this.lexer.nextToken();
            return null;
        }
        Type[] actualTypeArguments = ((ParameterizedType) type).getActualTypeArguments();
        if (actualTypeArguments.length != 1) {
            throw new JSONException("not support type " + type);
        }
        Type type2 = actualTypeArguments[0];
        if (type2 instanceof Class) {
            ArrayList arrayList = new ArrayList();
            parseArray((Class) type2, (Collection) arrayList);
            return arrayList;
        } else if (type2 instanceof WildcardType) {
            WildcardType wildcardType = (WildcardType) type2;
            Type type3 = wildcardType.getUpperBounds()[0];
            if (Object.class.equals(type3)) {
                if (wildcardType.getLowerBounds().length == 0) {
                    return parse();
                }
                throw new JSONException("not support type : " + type);
            }
            ArrayList arrayList2 = new ArrayList();
            parseArray((Class) type3, (Collection) arrayList2);
            return arrayList2;
        } else {
            if (type2 instanceof TypeVariable) {
                TypeVariable typeVariable = (TypeVariable) type2;
                Type[] bounds = typeVariable.getBounds();
                if (bounds.length != 1) {
                    throw new JSONException("not support : " + typeVariable);
                }
                Type type4 = bounds[0];
                if (type4 instanceof Class) {
                    ArrayList arrayList3 = new ArrayList();
                    parseArray((Class) type4, (Collection) arrayList3);
                    return arrayList3;
                }
            }
            if (type2 instanceof ParameterizedType) {
                ArrayList arrayList4 = new ArrayList();
                parseArray((ParameterizedType) type2, arrayList4);
                return arrayList4;
            }
            throw new JSONException("TODO : " + type);
        }
    }

    public void acceptType(String str) {
        JSONLexer jSONLexer = this.lexer;
        jSONLexer.nextTokenWithColon();
        if (jSONLexer.token() != 4) {
            throw new JSONException("type not match error");
        }
        if (str.equals(jSONLexer.stringVal())) {
            jSONLexer.nextToken();
            if (jSONLexer.token() == 16) {
                jSONLexer.nextToken();
                return;
            }
            return;
        }
        throw new JSONException("type not match error");
    }

    public int getResolveStatus() {
        return this.resolveStatus;
    }

    public void setResolveStatus(int i) {
        this.resolveStatus = i;
    }

    public Object getObject(String str) {
        for (int i = 0; i < this.contextArrayIndex; i++) {
            if (str.equals(this.contextArray[i].toString())) {
                return this.contextArray[i].object;
            }
        }
        return null;
    }

    public void checkListResolve(Collection collection) {
        if (this.resolveStatus == 1) {
            if (collection instanceof List) {
                ResolveTask lastResolveTask = getLastResolveTask();
                lastResolveTask.fieldDeserializer = new ResolveFieldDeserializer(this, (List) collection, collection.size() - 1);
                lastResolveTask.ownerContext = this.context;
                setResolveStatus(0);
                return;
            }
            ResolveTask lastResolveTask2 = getLastResolveTask();
            lastResolveTask2.fieldDeserializer = new ResolveFieldDeserializer(collection);
            lastResolveTask2.ownerContext = this.context;
            setResolveStatus(0);
        }
    }

    public void checkMapResolve(Map map, Object obj) {
        if (this.resolveStatus == 1) {
            ResolveFieldDeserializer resolveFieldDeserializer = new ResolveFieldDeserializer(map, obj);
            ResolveTask lastResolveTask = getLastResolveTask();
            lastResolveTask.fieldDeserializer = resolveFieldDeserializer;
            lastResolveTask.ownerContext = this.context;
            setResolveStatus(0);
        }
    }

    public Object parseObject(Map map) {
        return parseObject(map, (Object) null);
    }

    public JSONObject parseObject() {
        Object parseObject = parseObject((Map) new JSONObject(this.lexer.isEnabled(Feature.OrderedField)));
        if (parseObject instanceof JSONObject) {
            return (JSONObject) parseObject;
        }
        if (parseObject == null) {
            return null;
        }
        return new JSONObject((Map) parseObject);
    }

    public final void parseArray(Collection collection) {
        parseArray(collection, (Object) null);
    }

    public final void parseArray(Collection collection, Object obj) {
        Number number;
        Number decimalValue;
        JSONLexer jSONLexer = this.lexer;
        if (jSONLexer.token() == 21 || jSONLexer.token() == 22) {
            jSONLexer.nextToken();
        }
        if (jSONLexer.token() != 14) {
            throw new JSONException("syntax error, expect [, actual " + JSONToken.name(jSONLexer.token()) + ", pos " + jSONLexer.pos() + ", fieldName " + obj);
        }
        jSONLexer.nextToken(4);
        ParseContext parseContext = this.context;
        if (parseContext != null && parseContext.level > 512) {
            throw new JSONException("array level > 512");
        }
        ParseContext parseContext2 = this.context;
        setContext(collection, obj);
        int i = 0;
        while (true) {
            try {
                try {
                    if (jSONLexer.isEnabled(Feature.AllowArbitraryCommas)) {
                        while (jSONLexer.token() == 16) {
                            jSONLexer.nextToken();
                        }
                    }
                    int i2 = jSONLexer.token();
                    if (i2 == 2) {
                        Number integerValue = jSONLexer.integerValue();
                        jSONLexer.nextToken(16);
                        number = integerValue;
                    } else if (i2 == 3) {
                        if (jSONLexer.isEnabled(Feature.UseBigDecimal)) {
                            decimalValue = jSONLexer.decimalValue(true);
                        } else {
                            decimalValue = jSONLexer.decimalValue(false);
                        }
                        number = decimalValue;
                        jSONLexer.nextToken(16);
                    } else if (i2 == 4) {
                        String stringVal = jSONLexer.stringVal();
                        jSONLexer.nextToken(16);
                        number = stringVal;
                        if (jSONLexer.isEnabled(Feature.AllowISO8601DateFormat)) {
                            JSONScanner jSONScanner = new JSONScanner(stringVal);
                            Date date = stringVal;
                            if (jSONScanner.scanISO8601DateIfMatch()) {
                                date = jSONScanner.getCalendar().getTime();
                            }
                            jSONScanner.close();
                            number = date;
                        }
                    } else if (i2 == 6) {
                        Boolean bool = Boolean.TRUE;
                        jSONLexer.nextToken(16);
                        number = bool;
                    } else if (i2 != 7) {
                        number = null;
                        number = null;
                        if (i2 == 8) {
                            jSONLexer.nextToken(4);
                        } else if (i2 == 12) {
                            number = parseObject(new JSONObject(jSONLexer.isEnabled(Feature.OrderedField)), Integer.valueOf(i));
                        } else if (i2 == 20) {
                            throw new JSONException("unclosed jsonArray");
                        } else {
                            if (i2 == 23) {
                                jSONLexer.nextToken(4);
                            } else if (i2 == 14) {
                                JSONArray jSONArray = new JSONArray();
                                parseArray(jSONArray, Integer.valueOf(i));
                                number = jSONArray;
                                if (jSONLexer.isEnabled(Feature.UseObjectArray)) {
                                    number = jSONArray.toArray();
                                }
                            } else if (i2 == 15) {
                                jSONLexer.nextToken(16);
                                return;
                            } else {
                                number = parse();
                            }
                        }
                    } else {
                        Boolean bool2 = Boolean.FALSE;
                        jSONLexer.nextToken(16);
                        number = bool2;
                    }
                    collection.add(number);
                    checkListResolve(collection);
                    if (jSONLexer.token() == 16) {
                        jSONLexer.nextToken(4);
                    }
                    i++;
                } catch (ClassCastException e) {
                    throw new JSONException("unkown error", e);
                }
            } finally {
                setContext(parseContext2);
            }
        }
    }

    public ParseContext getContext() {
        return this.context;
    }

    public ParseContext getOwnerContext() {
        return this.context.parent;
    }

    public List<ResolveTask> getResolveTaskList() {
        if (this.resolveTaskList == null) {
            this.resolveTaskList = new ArrayList(2);
        }
        return this.resolveTaskList;
    }

    public void addResolveTask(ResolveTask resolveTask) {
        if (this.resolveTaskList == null) {
            this.resolveTaskList = new ArrayList(2);
        }
        this.resolveTaskList.add(resolveTask);
    }

    public ResolveTask getLastResolveTask() {
        List<ResolveTask> list = this.resolveTaskList;
        return list.get(list.size() - 1);
    }

    public List<ExtraProcessor> getExtraProcessors() {
        if (this.extraProcessors == null) {
            this.extraProcessors = new ArrayList(2);
        }
        return this.extraProcessors;
    }

    public List<ExtraTypeProvider> getExtraTypeProviders() {
        if (this.extraTypeProviders == null) {
            this.extraTypeProviders = new ArrayList(2);
        }
        return this.extraTypeProviders;
    }

    public FieldTypeResolver getFieldTypeResolver() {
        return this.fieldTypeResolver;
    }

    public void setFieldTypeResolver(FieldTypeResolver fieldTypeResolver) {
        this.fieldTypeResolver = fieldTypeResolver;
    }

    public void setContext(ParseContext parseContext) {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return;
        }
        this.context = parseContext;
    }

    public void popContext() {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return;
        }
        this.context = this.context.parent;
        int i = this.contextArrayIndex;
        if (i <= 0) {
            return;
        }
        int i2 = i - 1;
        this.contextArrayIndex = i2;
        this.contextArray[i2] = null;
    }

    public ParseContext setContext(Object obj, Object obj2) {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        return setContext(this.context, obj, obj2);
    }

    public ParseContext setContext(ParseContext parseContext, Object obj, Object obj2) {
        if (this.lexer.isEnabled(Feature.DisableCircularReferenceDetect)) {
            return null;
        }
        ParseContext parseContext2 = new ParseContext(parseContext, obj, obj2);
        this.context = parseContext2;
        addContext(parseContext2);
        return this.context;
    }

    private void addContext(ParseContext parseContext) {
        int i = this.contextArrayIndex;
        this.contextArrayIndex = i + 1;
        ParseContext[] parseContextArr = this.contextArray;
        if (parseContextArr == null) {
            this.contextArray = new ParseContext[8];
        } else if (i >= parseContextArr.length) {
            ParseContext[] parseContextArr2 = new ParseContext[(parseContextArr.length * 3) / 2];
            System.arraycopy(parseContextArr, 0, parseContextArr2, 0, parseContextArr.length);
            this.contextArray = parseContextArr2;
        }
        this.contextArray[i] = parseContext;
    }

    public Object parse() {
        return parse(null);
    }

    public Object parseKey() {
        if (this.lexer.token() == 18) {
            String stringVal = this.lexer.stringVal();
            this.lexer.nextToken(16);
            return stringVal;
        }
        return parse(null);
    }

    public Object parse(Object obj) {
        Map jSONObject;
        JSONLexer jSONLexer = this.lexer;
        int i = jSONLexer.token();
        if (i == 2) {
            Number integerValue = jSONLexer.integerValue();
            jSONLexer.nextToken();
            return integerValue;
        } else if (i == 3) {
            Number decimalValue = jSONLexer.decimalValue(jSONLexer.isEnabled(Feature.UseBigDecimal));
            jSONLexer.nextToken();
            return decimalValue;
        } else if (i == 4) {
            String stringVal = jSONLexer.stringVal();
            jSONLexer.nextToken(16);
            if (jSONLexer.isEnabled(Feature.AllowISO8601DateFormat)) {
                JSONScanner jSONScanner = new JSONScanner(stringVal);
                try {
                    if (jSONScanner.scanISO8601DateIfMatch()) {
                        return jSONScanner.getCalendar().getTime();
                    }
                } finally {
                    jSONScanner.close();
                }
            }
            return stringVal;
        } else if (i == 12) {
            if (isEnabled(Feature.UseNativeJavaObject)) {
                jSONObject = jSONLexer.isEnabled(Feature.OrderedField) ? new HashMap() : new LinkedHashMap();
            } else {
                jSONObject = new JSONObject(jSONLexer.isEnabled(Feature.OrderedField));
            }
            return parseObject(jSONObject, obj);
        } else if (i == 14) {
            Collection arrayList = isEnabled(Feature.UseNativeJavaObject) ? new ArrayList() : new JSONArray();
            parseArray(arrayList, obj);
            return jSONLexer.isEnabled(Feature.UseObjectArray) ? arrayList.toArray() : arrayList;
        } else if (i == 18) {
            if ("NaN".equals(jSONLexer.stringVal())) {
                jSONLexer.nextToken();
                return null;
            }
            throw new JSONException("syntax error, " + jSONLexer.info());
        } else if (i != 26) {
            switch (i) {
                case 6:
                    jSONLexer.nextToken();
                    return Boolean.TRUE;
                case 7:
                    jSONLexer.nextToken();
                    return Boolean.FALSE;
                case 8:
                    jSONLexer.nextToken();
                    return null;
                case 9:
                    jSONLexer.nextToken(18);
                    if (jSONLexer.token() != 18) {
                        throw new JSONException("syntax error");
                    }
                    jSONLexer.nextToken(10);
                    accept(10);
                    long longValue = jSONLexer.integerValue().longValue();
                    accept(2);
                    accept(11);
                    return new Date(longValue);
                default:
                    switch (i) {
                        case 20:
                            if (jSONLexer.isBlankInput()) {
                                return null;
                            }
                            throw new JSONException("unterminated json string, " + jSONLexer.info());
                        case 21:
                            jSONLexer.nextToken();
                            HashSet hashSet = new HashSet();
                            parseArray(hashSet, obj);
                            return hashSet;
                        case 22:
                            jSONLexer.nextToken();
                            TreeSet treeSet = new TreeSet();
                            parseArray(treeSet, obj);
                            return treeSet;
                        case 23:
                            jSONLexer.nextToken();
                            return null;
                        default:
                            throw new JSONException("syntax error, " + jSONLexer.info());
                    }
            }
        } else {
            byte[] bytesValue = jSONLexer.bytesValue();
            jSONLexer.nextToken();
            return bytesValue;
        }
    }

    public void config(Feature feature, boolean z) {
        this.lexer.config(feature, z);
    }

    public boolean isEnabled(Feature feature) {
        return this.lexer.isEnabled(feature);
    }

    public JSONLexer getLexer() {
        return this.lexer;
    }

    public final void accept(int i) {
        JSONLexer jSONLexer = this.lexer;
        if (jSONLexer.token() == i) {
            jSONLexer.nextToken();
            return;
        }
        throw new JSONException("syntax error, expect " + JSONToken.name(i) + ", actual " + JSONToken.name(jSONLexer.token()));
    }

    public final void accept(int i, int i2) {
        JSONLexer jSONLexer = this.lexer;
        if (jSONLexer.token() == i) {
            jSONLexer.nextToken(i2);
        } else {
            throwException(i);
        }
    }

    public void throwException(int i) {
        throw new JSONException("syntax error, expect " + JSONToken.name(i) + ", actual " + JSONToken.name(this.lexer.token()));
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    public void close() {
        JSONLexer jSONLexer = this.lexer;
        try {
            if (jSONLexer.isEnabled(Feature.AutoCloseSource) && jSONLexer.token() != 20) {
                throw new JSONException("not close json text, token : " + JSONToken.name(jSONLexer.token()));
            }
        } finally {
            jSONLexer.close();
        }
    }

    public Object resolveReference(String str) {
        if (this.contextArray == null) {
            return null;
        }
        int i = 0;
        while (true) {
            ParseContext[] parseContextArr = this.contextArray;
            if (i >= parseContextArr.length || i >= this.contextArrayIndex) {
                break;
            }
            ParseContext parseContext = parseContextArr[i];
            if (parseContext.toString().equals(str)) {
                return parseContext.object;
            }
            i++;
        }
        return null;
    }

    public void handleResovleTask(Object obj) {
        Object obj2;
        List<ResolveTask> list = this.resolveTaskList;
        if (list == null) {
            return;
        }
        int size = list.size();
        for (int i = 0; i < size; i++) {
            ResolveTask resolveTask = this.resolveTaskList.get(i);
            String str = resolveTask.referenceValue;
            Object obj3 = resolveTask.ownerContext != null ? resolveTask.ownerContext.object : null;
            if (str.startsWith(Operators.DOLLAR_STR)) {
                obj2 = getObject(str);
                if (obj2 == null) {
                    try {
                        JSONPath jSONPath = new JSONPath(str, SerializeConfig.getGlobalInstance(), this.config, true);
                        if (jSONPath.isRef()) {
                            obj2 = jSONPath.eval(obj);
                        }
                    } catch (JSONPathException unused) {
                    }
                }
            } else {
                obj2 = resolveTask.context.object;
            }
            FieldDeserializer fieldDeserializer = resolveTask.fieldDeserializer;
            if (fieldDeserializer != null) {
                if (obj2 != null && obj2.getClass() == JSONObject.class && fieldDeserializer.fieldInfo != null && !Map.class.isAssignableFrom(fieldDeserializer.fieldInfo.fieldClass)) {
                    Object obj4 = this.contextArray[0].object;
                    JSONPath compile = JSONPath.compile(str);
                    if (compile.isRef()) {
                        obj2 = compile.eval(obj4);
                    }
                }
                if (fieldDeserializer.getOwnerClass() != null && !fieldDeserializer.getOwnerClass().isInstance(obj3) && resolveTask.ownerContext.parent != null) {
                    ParseContext parseContext = resolveTask.ownerContext;
                    while (true) {
                        parseContext = parseContext.parent;
                        if (parseContext == null) {
                            break;
                        } else if (fieldDeserializer.getOwnerClass().isInstance(parseContext.object)) {
                            obj3 = parseContext.object;
                            break;
                        }
                    }
                }
                fieldDeserializer.setValue(obj3, obj2);
            }
        }
    }

    /* loaded from: classes.dex */
    public static class ResolveTask {
        public final ParseContext context;
        public FieldDeserializer fieldDeserializer;
        public ParseContext ownerContext;
        public final String referenceValue;

        public ResolveTask(ParseContext parseContext, String str) {
            this.context = parseContext;
            this.referenceValue = str;
        }
    }

    public void parseExtra(Object obj, String str) {
        Object parseObject;
        this.lexer.nextTokenWithColon();
        List<ExtraTypeProvider> list = this.extraTypeProviders;
        Type type = null;
        if (list != null) {
            for (ExtraTypeProvider extraTypeProvider : list) {
                type = extraTypeProvider.getExtraType(obj, str);
            }
        }
        if (type == null) {
            parseObject = parse();
        } else {
            parseObject = parseObject(type);
        }
        if (obj instanceof ExtraProcessable) {
            ((ExtraProcessable) obj).processExtra(str, parseObject);
            return;
        }
        List<ExtraProcessor> list2 = this.extraProcessors;
        if (list2 != null) {
            for (ExtraProcessor extraProcessor : list2) {
                extraProcessor.processExtra(obj, str, parseObject);
            }
        }
        if (this.resolveStatus == 1) {
            this.resolveStatus = 0;
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:86:0x0235, code lost:
        return r11;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public Object parse(PropertyProcessable propertyProcessable, Object obj) {
        String scanSymbolUnQuoted;
        int i = 0;
        if (this.lexer.token() != 12) {
            String str = "syntax error, expect {, actual " + this.lexer.tokenName();
            if (obj instanceof String) {
                str = (str + ", fieldName ") + obj;
            }
            String str2 = (str + ", ") + this.lexer.info();
            JSONArray jSONArray = new JSONArray();
            parseArray(jSONArray, obj);
            if (jSONArray.size() == 1) {
                Object obj2 = jSONArray.get(0);
                if (obj2 instanceof JSONObject) {
                    return (JSONObject) obj2;
                }
            }
            throw new JSONException(str2);
        }
        ParseContext parseContext = this.context;
        while (true) {
            try {
                this.lexer.skipWhitespace();
                char current = this.lexer.getCurrent();
                if (this.lexer.isEnabled(Feature.AllowArbitraryCommas)) {
                    while (current == ',') {
                        this.lexer.next();
                        this.lexer.skipWhitespace();
                        current = this.lexer.getCurrent();
                    }
                }
                if (current == '\"') {
                    scanSymbolUnQuoted = this.lexer.scanSymbol(this.symbolTable, '\"');
                    this.lexer.skipWhitespace();
                    if (this.lexer.getCurrent() != ':') {
                        throw new JSONException("expect ':' at " + this.lexer.pos());
                    }
                } else if (current == '}') {
                    this.lexer.next();
                    this.lexer.resetStringPosition();
                    this.lexer.nextToken(16);
                    return propertyProcessable;
                } else if (current == '\'') {
                    if (!this.lexer.isEnabled(Feature.AllowSingleQuotes)) {
                        throw new JSONException("syntax error");
                    }
                    scanSymbolUnQuoted = this.lexer.scanSymbol(this.symbolTable, Operators.SINGLE_QUOTE);
                    this.lexer.skipWhitespace();
                    if (this.lexer.getCurrent() != ':') {
                        throw new JSONException("expect ':' at " + this.lexer.pos());
                    }
                } else if (!this.lexer.isEnabled(Feature.AllowUnQuotedFieldNames)) {
                    throw new JSONException("syntax error");
                } else {
                    scanSymbolUnQuoted = this.lexer.scanSymbolUnQuoted(this.symbolTable);
                    this.lexer.skipWhitespace();
                    char current2 = this.lexer.getCurrent();
                    if (current2 != ':') {
                        throw new JSONException("expect ':' at " + this.lexer.pos() + ", actual " + current2);
                    }
                }
                this.lexer.next();
                this.lexer.skipWhitespace();
                this.lexer.getCurrent();
                this.lexer.resetStringPosition();
                Object obj3 = null;
                if (scanSymbolUnQuoted != JSON.DEFAULT_TYPE_KEY || this.lexer.isEnabled(Feature.DisableSpecialKeyDetect)) {
                    this.lexer.nextToken();
                    if (i != 0) {
                        setContext(parseContext);
                    }
                    Type type = propertyProcessable.getType(scanSymbolUnQuoted);
                    if (this.lexer.token() == 8) {
                        this.lexer.nextToken();
                    } else {
                        obj3 = parseObject(type, scanSymbolUnQuoted);
                    }
                    propertyProcessable.apply(scanSymbolUnQuoted, obj3);
                    setContext(parseContext, obj3, scanSymbolUnQuoted);
                    setContext(parseContext);
                    int i2 = this.lexer.token();
                    if (i2 == 20 || i2 == 15) {
                        break;
                    } else if (i2 == 13) {
                        this.lexer.nextToken();
                        return propertyProcessable;
                    }
                } else {
                    Class<?> checkAutoType = this.config.checkAutoType(this.lexer.scanSymbol(this.symbolTable, '\"'), null, this.lexer.getFeatures());
                    if (!Map.class.isAssignableFrom(checkAutoType)) {
                        ObjectDeserializer deserializer = this.config.getDeserializer(checkAutoType);
                        this.lexer.nextToken(16);
                        setResolveStatus(2);
                        if (parseContext != null && !(obj instanceof Integer)) {
                            popContext();
                        }
                        return (Map) deserializer.deserialze(this, checkAutoType, obj);
                    }
                    this.lexer.nextToken(16);
                    if (this.lexer.token() == 13) {
                        this.lexer.nextToken(16);
                        return propertyProcessable;
                    }
                }
                i++;
            } finally {
                setContext(parseContext);
            }
        }
    }
}
