package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JSONLexerBase;
import com.alibaba.fastjson.parser.JSONToken;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.JavaBeanInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
/* loaded from: classes.dex */
public class JavaBeanDeserializer implements ObjectDeserializer {
    private final Map<String, FieldDeserializer> alterNameFieldDeserializers;
    private final ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler;
    public final JavaBeanInfo beanInfo;
    protected final Class<?> clazz;
    private ConcurrentMap<String, Object> extraFieldDeserializers;
    private Map<String, FieldDeserializer> fieldDeserializerMap;
    private final FieldDeserializer[] fieldDeserializers;
    private transient long[] hashArray;
    private transient short[] hashArrayMapping;
    private transient long[] smartMatchHashArray;
    private transient short[] smartMatchHashArrayMapping;
    protected final FieldDeserializer[] sortedFieldDeserializers;

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls) {
        this(parserConfig, cls, cls);
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls, Type type) {
        this(parserConfig, JavaBeanInfo.build(cls, type, parserConfig.propertyNamingStrategy, parserConfig.fieldBased, parserConfig.compatibleWithJavaBean, parserConfig.isJacksonCompatible()));
    }

    /* JADX WARN: Removed duplicated region for block: B:11:0x0036  */
    /* JADX WARN: Removed duplicated region for block: B:26:0x007e A[LOOP:2: B:25:0x007c->B:26:0x007e, LOOP_END] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public JavaBeanDeserializer(ParserConfig parserConfig, JavaBeanInfo javaBeanInfo) {
        ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler;
        int length;
        int i;
        int i2;
        int length2;
        String[] strArr;
        this.clazz = javaBeanInfo.clazz;
        this.beanInfo = javaBeanInfo;
        HashMap hashMap = null;
        if (javaBeanInfo.jsonType != null && javaBeanInfo.jsonType.autoTypeCheckHandler() != ParserConfig.AutoTypeCheckHandler.class) {
            try {
                autoTypeCheckHandler = javaBeanInfo.jsonType.autoTypeCheckHandler().newInstance();
            } catch (Exception unused) {
            }
            this.autoTypeCheckHandler = autoTypeCheckHandler;
            this.sortedFieldDeserializers = new FieldDeserializer[javaBeanInfo.sortedFields.length];
            length = javaBeanInfo.sortedFields.length;
            for (i2 = 0; i2 < length; i2++) {
                FieldInfo fieldInfo = javaBeanInfo.sortedFields[i2];
                FieldDeserializer createFieldDeserializer = parserConfig.createFieldDeserializer(parserConfig, javaBeanInfo, fieldInfo);
                this.sortedFieldDeserializers[i2] = createFieldDeserializer;
                if (length > 128) {
                    if (this.fieldDeserializerMap == null) {
                        this.fieldDeserializerMap = new HashMap();
                    }
                    this.fieldDeserializerMap.put(fieldInfo.name, createFieldDeserializer);
                }
                for (String str : fieldInfo.alternateNames) {
                    if (hashMap == null) {
                        hashMap = new HashMap();
                    }
                    hashMap.put(str, createFieldDeserializer);
                }
            }
            this.alterNameFieldDeserializers = hashMap;
            this.fieldDeserializers = new FieldDeserializer[javaBeanInfo.fields.length];
            length2 = javaBeanInfo.fields.length;
            for (i = 0; i < length2; i++) {
                this.fieldDeserializers[i] = getFieldDeserializer(javaBeanInfo.fields[i].name);
            }
        }
        autoTypeCheckHandler = null;
        this.autoTypeCheckHandler = autoTypeCheckHandler;
        this.sortedFieldDeserializers = new FieldDeserializer[javaBeanInfo.sortedFields.length];
        length = javaBeanInfo.sortedFields.length;
        while (i2 < length) {
        }
        this.alterNameFieldDeserializers = hashMap;
        this.fieldDeserializers = new FieldDeserializer[javaBeanInfo.fields.length];
        length2 = javaBeanInfo.fields.length;
        while (i < length2) {
        }
    }

    public FieldDeserializer getFieldDeserializer(String str) {
        return getFieldDeserializer(str, null);
    }

    public FieldDeserializer getFieldDeserializer(String str, int[] iArr) {
        FieldDeserializer fieldDeserializer;
        if (str == null) {
            return null;
        }
        Map<String, FieldDeserializer> map = this.fieldDeserializerMap;
        if (map == null || (fieldDeserializer = map.get(str)) == null) {
            int length = this.sortedFieldDeserializers.length - 1;
            int i = 0;
            while (i <= length) {
                int i2 = (i + length) >>> 1;
                int compareTo = this.sortedFieldDeserializers[i2].fieldInfo.name.compareTo(str);
                if (compareTo < 0) {
                    i = i2 + 1;
                } else if (compareTo <= 0) {
                    if (isSetFlag(i2, iArr)) {
                        return null;
                    }
                    return this.sortedFieldDeserializers[i2];
                } else {
                    length = i2 - 1;
                }
            }
            Map<String, FieldDeserializer> map2 = this.alterNameFieldDeserializers;
            if (map2 != null) {
                return map2.get(str);
            }
            return null;
        }
        return fieldDeserializer;
    }

    public FieldDeserializer getFieldDeserializer(long j) {
        int i = 0;
        if (this.hashArray == null) {
            long[] jArr = new long[this.sortedFieldDeserializers.length];
            int i2 = 0;
            while (true) {
                FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                if (i2 >= fieldDeserializerArr.length) {
                    break;
                }
                jArr[i2] = TypeUtils.fnv1a_64(fieldDeserializerArr[i2].fieldInfo.name);
                i2++;
            }
            Arrays.sort(jArr);
            this.hashArray = jArr;
        }
        int binarySearch = Arrays.binarySearch(this.hashArray, j);
        if (binarySearch < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            short[] sArr = new short[this.hashArray.length];
            Arrays.fill(sArr, (short) -1);
            while (true) {
                FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                if (i >= fieldDeserializerArr2.length) {
                    break;
                }
                int binarySearch2 = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(fieldDeserializerArr2[i].fieldInfo.name));
                if (binarySearch2 >= 0) {
                    sArr[binarySearch2] = (short) i;
                }
                i++;
            }
            this.hashArrayMapping = sArr;
        }
        short s = this.hashArrayMapping[binarySearch];
        if (s != -1) {
            return this.sortedFieldDeserializers[s];
        }
        return null;
    }

    static boolean isSetFlag(int i, int[] iArr) {
        int i2;
        if (iArr != null && (i2 = i / 32) < iArr.length) {
            return ((1 << (i % 32)) & iArr[i2]) != 0;
        }
        return false;
    }

    public Object createInstance(DefaultJSONParser defaultJSONParser, Type type) {
        Object newInstance;
        FieldInfo[] fieldInfoArr;
        if ((type instanceof Class) && this.clazz.isInterface()) {
            return Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{(Class) type}, new JSONObject());
        }
        Object obj = null;
        if (this.beanInfo.defaultConstructor == null && this.beanInfo.factoryMethod == null) {
            return null;
        }
        if (this.beanInfo.factoryMethod == null || this.beanInfo.defaultConstructorParameterSize <= 0) {
            try {
                Constructor<?> constructor = this.beanInfo.defaultConstructor;
                if (this.beanInfo.defaultConstructorParameterSize != 0) {
                    ParseContext context = defaultJSONParser.getContext();
                    if (context == null || context.object == null) {
                        throw new JSONException("can't create non-static inner class instance.");
                    }
                    if (type instanceof Class) {
                        String name = ((Class) type).getName();
                        String substring = name.substring(0, name.lastIndexOf(36));
                        Object obj2 = context.object;
                        String name2 = obj2.getClass().getName();
                        if (!name2.equals(substring)) {
                            ParseContext parseContext = context.parent;
                            if (parseContext == null || parseContext.object == null || !("java.util.ArrayList".equals(name2) || "java.util.List".equals(name2) || "java.util.Collection".equals(name2) || "java.util.Map".equals(name2) || "java.util.HashMap".equals(name2))) {
                                obj = obj2;
                            } else if (parseContext.object.getClass().getName().equals(substring)) {
                                obj = parseContext.object;
                            }
                            obj2 = obj;
                        }
                        if (obj2 == null || ((obj2 instanceof Collection) && ((Collection) obj2).isEmpty())) {
                            throw new JSONException("can't create non-static inner class instance.");
                        }
                        newInstance = constructor.newInstance(obj2);
                    } else {
                        throw new JSONException("can't create non-static inner class instance.");
                    }
                } else if (constructor != null) {
                    newInstance = constructor.newInstance(null);
                } else {
                    newInstance = this.beanInfo.factoryMethod.invoke(null, null);
                }
                if (defaultJSONParser != null && defaultJSONParser.lexer.isEnabled(Feature.InitStringFieldAsEmpty)) {
                    for (FieldInfo fieldInfo : this.beanInfo.fields) {
                        if (fieldInfo.fieldClass == String.class) {
                            try {
                                fieldInfo.set(newInstance, "");
                            } catch (Exception e) {
                                throw new JSONException("create instance error, class " + this.clazz.getName(), e);
                            }
                        }
                    }
                }
                return newInstance;
            } catch (JSONException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new JSONException("create instance error, class " + this.clazz.getName(), e3);
            }
        }
        return null;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        return (T) deserialze(defaultJSONParser, type, obj, 0);
    }

    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj, int i) {
        return (T) deserialze(defaultJSONParser, type, obj, null, i, null);
    }

    public <T> T deserialzeArrayMapping(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2) {
        Enum<?> scanEnum;
        JSONLexer jSONLexer = defaultJSONParser.lexer;
        if (jSONLexer.token() != 14) {
            throw new JSONException("error");
        }
        String scanTypeName = jSONLexer.scanTypeName(defaultJSONParser.symbolTable);
        if (scanTypeName != null) {
            ObjectDeserializer seeAlso = getSeeAlso(defaultJSONParser.getConfig(), this.beanInfo, scanTypeName);
            if (seeAlso == null) {
                seeAlso = defaultJSONParser.getConfig().getDeserializer(defaultJSONParser.getConfig().checkAutoType(scanTypeName, TypeUtils.getClass(type), jSONLexer.getFeatures()));
            }
            if (seeAlso instanceof JavaBeanDeserializer) {
                return (T) ((JavaBeanDeserializer) seeAlso).deserialzeArrayMapping(defaultJSONParser, type, obj, obj2);
            }
        }
        T t = (T) createInstance(defaultJSONParser, type);
        int length = this.sortedFieldDeserializers.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            char c = i == length + (-1) ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
            FieldDeserializer fieldDeserializer = this.sortedFieldDeserializers[i];
            Class<?> cls = fieldDeserializer.fieldInfo.fieldClass;
            if (cls == Integer.TYPE) {
                fieldDeserializer.setValue((Object) t, jSONLexer.scanInt(c));
            } else if (cls == String.class) {
                fieldDeserializer.setValue((Object) t, jSONLexer.scanString(c));
            } else if (cls == Long.TYPE) {
                fieldDeserializer.setValue(t, jSONLexer.scanLong(c));
            } else if (cls.isEnum()) {
                char current = jSONLexer.getCurrent();
                if (current == '\"' || current == 'n') {
                    scanEnum = jSONLexer.scanEnum(cls, defaultJSONParser.getSymbolTable(), c);
                } else if (current >= '0' && current <= '9') {
                    scanEnum = ((EnumDeserializer) ((DefaultFieldDeserializer) fieldDeserializer).getFieldValueDeserilizer(defaultJSONParser.getConfig())).valueOf(jSONLexer.scanInt(c));
                } else {
                    scanEnum = scanEnum(jSONLexer, c);
                }
                fieldDeserializer.setValue(t, scanEnum);
            } else if (cls == Boolean.TYPE) {
                fieldDeserializer.setValue(t, jSONLexer.scanBoolean(c));
            } else if (cls == Float.TYPE) {
                fieldDeserializer.setValue(t, Float.valueOf(jSONLexer.scanFloat(c)));
            } else if (cls == Double.TYPE) {
                fieldDeserializer.setValue(t, Double.valueOf(jSONLexer.scanDouble(c)));
            } else if (cls == Date.class && jSONLexer.getCurrent() == '1') {
                fieldDeserializer.setValue(t, new Date(jSONLexer.scanLong(c)));
            } else if (cls == BigDecimal.class) {
                fieldDeserializer.setValue(t, jSONLexer.scanDecimal(c));
            } else {
                jSONLexer.nextToken(14);
                fieldDeserializer.setValue(t, defaultJSONParser.parseObject(fieldDeserializer.fieldInfo.fieldType, fieldDeserializer.fieldInfo.name));
                if (jSONLexer.token() == 15) {
                    break;
                }
                check(jSONLexer, c == ']' ? 15 : 16);
            }
            i++;
        }
        jSONLexer.nextToken(16);
        return t;
    }

    protected void check(JSONLexer jSONLexer, int i) {
        if (jSONLexer.token() != i) {
            throw new JSONException("syntax error");
        }
    }

    protected Enum<?> scanEnum(JSONLexer jSONLexer, char c) {
        throw new JSONException("illegal enum. " + jSONLexer.info());
    }

    /* JADX WARN: Code restructure failed: missing block: B:295:0x037f, code lost:
        if (r12.matchStat == (-2)) goto L619;
     */
    /* JADX WARN: Code restructure failed: missing block: B:311:0x03c5, code lost:
        r1 = r27;
        r3 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:315:0x03d3, code lost:
        if (r12.isEnabled(com.alibaba.fastjson.parser.Feature.AllowArbitraryCommas) != false) goto L471;
     */
    /* JADX WARN: Code restructure failed: missing block: B:398:0x0532, code lost:
        if (r3 != null) goto L567;
     */
    /* JADX WARN: Code restructure failed: missing block: B:399:0x0534, code lost:
        r15 = r13.checkAutoType(r1, r2, r12.getFeatures());
     */
    /* JADX WARN: Code restructure failed: missing block: B:400:0x053e, code lost:
        r15 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:401:0x053f, code lost:
        r2 = r33.getConfig().getDeserializer(r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:404:0x0549, code lost:
        r3 = (T) r2.deserialze(r33, r15, r35);
     */
    /* JADX WARN: Code restructure failed: missing block: B:405:0x054f, code lost:
        if ((r2 instanceof com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) == false) goto L562;
     */
    /* JADX WARN: Code restructure failed: missing block: B:406:0x0551, code lost:
        r2 = (com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) r2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:407:0x0553, code lost:
        if (r5 == null) goto L562;
     */
    /* JADX WARN: Code restructure failed: missing block: B:408:0x0555, code lost:
        r2 = r2.getFieldDeserializer(r5);
     */
    /* JADX WARN: Code restructure failed: missing block: B:409:0x0559, code lost:
        if (r2 == null) goto L562;
     */
    /* JADX WARN: Code restructure failed: missing block: B:410:0x055b, code lost:
        r2.setValue((java.lang.Object) r3, r1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:411:0x055e, code lost:
        if (r6 == null) goto L564;
     */
    /* JADX WARN: Code restructure failed: missing block: B:412:0x0560, code lost:
        r6.object = r27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:413:0x0564, code lost:
        r33.setContext(r7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:414:0x0567, code lost:
        return r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:419:0x0575, code lost:
        r31 = r7;
        r2 = r17;
        r36 = 0;
        r3 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:468:0x0652, code lost:
        if (r1 != 0) goto L432;
     */
    /* JADX WARN: Code restructure failed: missing block: B:491:0x06c6, code lost:
        r12.nextToken();
        r3 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:504:0x06f7, code lost:
        r12.nextToken(16);
        r3 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:505:0x06fa, code lost:
        r1 = (T) r19;
        r2 = r21;
        r6 = r30;
        r3 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:506:0x0700, code lost:
        if (r1 != null) goto L393;
     */
    /* JADX WARN: Code restructure failed: missing block: B:507:0x0702, code lost:
        if (r2 != null) goto L177;
     */
    /* JADX WARN: Code restructure failed: missing block: B:508:0x0704, code lost:
        r1 = (T) createInstance((com.alibaba.fastjson.parser.DefaultJSONParser) r33, r34);
     */
    /* JADX WARN: Code restructure failed: missing block: B:509:0x0708, code lost:
        if (r6 != null) goto L389;
     */
    /* JADX WARN: Code restructure failed: missing block: B:510:0x070a, code lost:
        r3 = r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:511:0x070c, code lost:
        r6 = r33.setContext(r3, r1, r35);
     */
    /* JADX WARN: Code restructure failed: missing block: B:513:0x0711, code lost:
        r3 = r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:514:0x0713, code lost:
        if (r6 == null) goto L387;
     */
    /* JADX WARN: Code restructure failed: missing block: B:515:0x0715, code lost:
        r6.object = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:516:0x0717, code lost:
        r33.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:517:0x071a, code lost:
        return r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:518:0x071b, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:519:0x071c, code lost:
        r3 = r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:520:0x0720, code lost:
        r3 = r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:521:0x0722, code lost:
        r4 = r32.beanInfo.creatorConstructorParameters;
     */
    /* JADX WARN: Code restructure failed: missing block: B:523:0x0728, code lost:
        if (r4 == null) goto L328;
     */
    /* JADX WARN: Code restructure failed: missing block: B:524:0x072a, code lost:
        r7 = new java.lang.Object[r4.length];
        r10 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:526:0x072f, code lost:
        if (r10 >= r4.length) goto L231;
     */
    /* JADX WARN: Code restructure failed: missing block: B:527:0x0731, code lost:
        r11 = r2.remove(r4[r10]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:528:0x0737, code lost:
        if (r11 != null) goto L216;
     */
    /* JADX WARN: Code restructure failed: missing block: B:529:0x0739, code lost:
        r12 = r32.beanInfo.creatorConstructorParameterTypes[r10];
        r13 = r32.beanInfo.fields[r10];
     */
    /* JADX WARN: Code restructure failed: missing block: B:530:0x0747, code lost:
        if (r12 != java.lang.Byte.TYPE) goto L193;
     */
    /* JADX WARN: Code restructure failed: missing block: B:531:0x0749, code lost:
        r11 = java.lang.Byte.valueOf(r36);
     */
    /* JADX WARN: Code restructure failed: missing block: B:533:0x0750, code lost:
        if (r12 != java.lang.Short.TYPE) goto L196;
     */
    /* JADX WARN: Code restructure failed: missing block: B:534:0x0752, code lost:
        r11 = java.lang.Short.valueOf(r36);
     */
    /* JADX WARN: Code restructure failed: missing block: B:536:0x0759, code lost:
        if (r12 != java.lang.Integer.TYPE) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:537:0x075b, code lost:
        r11 = java.lang.Integer.valueOf(r36);
     */
    /* JADX WARN: Code restructure failed: missing block: B:539:0x0762, code lost:
        if (r12 != java.lang.Long.TYPE) goto L202;
     */
    /* JADX WARN: Code restructure failed: missing block: B:540:0x0764, code lost:
        r11 = 0L;
     */
    /* JADX WARN: Code restructure failed: missing block: B:542:0x076b, code lost:
        if (r12 != java.lang.Float.TYPE) goto L205;
     */
    /* JADX WARN: Code restructure failed: missing block: B:543:0x076d, code lost:
        r11 = java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARN: Code restructure failed: missing block: B:545:0x0774, code lost:
        if (r12 != java.lang.Double.TYPE) goto L208;
     */
    /* JADX WARN: Code restructure failed: missing block: B:546:0x0776, code lost:
        r11 = java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:548:0x077d, code lost:
        if (r12 != java.lang.Boolean.TYPE) goto L211;
     */
    /* JADX WARN: Code restructure failed: missing block: B:549:0x077f, code lost:
        r11 = java.lang.Boolean.FALSE;
     */
    /* JADX WARN: Code restructure failed: missing block: B:551:0x0784, code lost:
        if (r12 != java.lang.String.class) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:553:0x078d, code lost:
        if ((r13.parserFeatures & com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask) == 0) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:554:0x078f, code lost:
        r11 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:557:0x0796, code lost:
        if (r32.beanInfo.creatorConstructorParameterTypes == null) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:559:0x079d, code lost:
        if (r10 >= r32.beanInfo.creatorConstructorParameterTypes.length) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:560:0x079f, code lost:
        r12 = r32.beanInfo.creatorConstructorParameterTypes[r10];
     */
    /* JADX WARN: Code restructure failed: missing block: B:561:0x07a7, code lost:
        if ((r12 instanceof java.lang.Class) == false) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:562:0x07a9, code lost:
        r12 = (java.lang.Class) r12;
     */
    /* JADX WARN: Code restructure failed: missing block: B:563:0x07af, code lost:
        if (r12.isInstance(r11) != false) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:565:0x07b3, code lost:
        if ((r11 instanceof java.util.List) == false) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:566:0x07b5, code lost:
        r13 = (java.util.List) r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:567:0x07bd, code lost:
        if (r13.size() != 1) goto L190;
     */
    /* JADX WARN: Code restructure failed: missing block: B:569:0x07c8, code lost:
        if (r12.isInstance(r13.get(0)) == false) goto L191;
     */
    /* JADX WARN: Code restructure failed: missing block: B:570:0x07ca, code lost:
        r11 = r13.get(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:571:0x07ce, code lost:
        r7[r10] = r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:572:0x07d0, code lost:
        r10 = r10 + 1;
        r36 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:573:0x07d6, code lost:
        r37 = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:575:0x07db, code lost:
        r7 = r32.beanInfo.fields;
        r10 = r7.length;
        r11 = new java.lang.Object[r10];
        r12 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:576:0x07e3, code lost:
        if (r12 >= r10) goto L376;
     */
    /* JADX WARN: Code restructure failed: missing block: B:577:0x07e5, code lost:
        r13 = r7[r12];
        r15 = r2.get(r13.name);
     */
    /* JADX WARN: Code restructure failed: missing block: B:578:0x07ed, code lost:
        if (r15 != null) goto L373;
     */
    /* JADX WARN: Code restructure failed: missing block: B:579:0x07ef, code lost:
        r14 = r13.fieldType;
     */
    /* JADX WARN: Code restructure failed: missing block: B:580:0x07f1, code lost:
        r37 = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:582:0x07f5, code lost:
        if (r14 != java.lang.Byte.TYPE) goto L341;
     */
    /* JADX WARN: Code restructure failed: missing block: B:583:0x07f7, code lost:
        r15 = (byte) 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:585:0x07ff, code lost:
        if (r14 != java.lang.Short.TYPE) goto L345;
     */
    /* JADX WARN: Code restructure failed: missing block: B:586:0x0801, code lost:
        r15 = (short) 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:588:0x0809, code lost:
        if (r14 != java.lang.Integer.TYPE) goto L349;
     */
    /* JADX WARN: Code restructure failed: missing block: B:589:0x080b, code lost:
        r15 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:591:0x0813, code lost:
        if (r14 != java.lang.Long.TYPE) goto L353;
     */
    /* JADX WARN: Code restructure failed: missing block: B:592:0x0815, code lost:
        r15 = 0L;
     */
    /* JADX WARN: Code restructure failed: missing block: B:594:0x081c, code lost:
        if (r14 != java.lang.Float.TYPE) goto L357;
     */
    /* JADX WARN: Code restructure failed: missing block: B:595:0x081e, code lost:
        r15 = java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARN: Code restructure failed: missing block: B:597:0x0825, code lost:
        if (r14 != java.lang.Double.TYPE) goto L361;
     */
    /* JADX WARN: Code restructure failed: missing block: B:598:0x0827, code lost:
        r15 = java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:600:0x082e, code lost:
        if (r14 != java.lang.Boolean.TYPE) goto L365;
     */
    /* JADX WARN: Code restructure failed: missing block: B:601:0x0830, code lost:
        r15 = java.lang.Boolean.FALSE;
     */
    /* JADX WARN: Code restructure failed: missing block: B:603:0x0835, code lost:
        if (r14 != java.lang.String.class) goto L372;
     */
    /* JADX WARN: Code restructure failed: missing block: B:605:0x083e, code lost:
        if ((r13.parserFeatures & com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask) == 0) goto L371;
     */
    /* JADX WARN: Code restructure failed: missing block: B:606:0x0840, code lost:
        r15 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:607:0x0842, code lost:
        r37 = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:608:0x0844, code lost:
        r11[r12] = r15;
        r12 = r12 + 1;
        r1 = (T) r37;
     */
    /* JADX WARN: Code restructure failed: missing block: B:609:0x084c, code lost:
        r37 = r1;
        r7 = r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:611:0x0853, code lost:
        if (r32.beanInfo.creatorConstructor == null) goto L315;
     */
    /* JADX WARN: Code restructure failed: missing block: B:613:0x0859, code lost:
        if (r32.beanInfo.f4kotlin == false) goto L314;
     */
    /* JADX WARN: Code restructure failed: missing block: B:614:0x085b, code lost:
        r1 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:616:0x085d, code lost:
        if (r1 >= r7.length) goto L313;
     */
    /* JADX WARN: Code restructure failed: missing block: B:618:0x0861, code lost:
        if (r7[r1] != null) goto L312;
     */
    /* JADX WARN: Code restructure failed: missing block: B:620:0x0867, code lost:
        if (r32.beanInfo.fields == null) goto L311;
     */
    /* JADX WARN: Code restructure failed: missing block: B:622:0x086e, code lost:
        if (r1 >= r32.beanInfo.fields.length) goto L309;
     */
    /* JADX WARN: Code restructure failed: missing block: B:624:0x087a, code lost:
        if (r32.beanInfo.fields[r1].fieldClass != java.lang.String.class) goto L314;
     */
    /* JADX WARN: Code restructure failed: missing block: B:626:0x0880, code lost:
        if (r32.beanInfo.kotlinDefaultConstructor == null) goto L314;
     */
    /* JADX WARN: Code restructure failed: missing block: B:627:0x0882, code lost:
        r1 = (T) r32.beanInfo.kotlinDefaultConstructor.newInstance(null);
     */
    /* JADX WARN: Code restructure failed: missing block: B:628:0x088b, code lost:
        r5 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:630:0x088d, code lost:
        if (r5 >= r7.length) goto L269;
     */
    /* JADX WARN: Code restructure failed: missing block: B:631:0x088f, code lost:
        r10 = r7[r5];
     */
    /* JADX WARN: Code restructure failed: missing block: B:632:0x0891, code lost:
        if (r10 == null) goto L268;
     */
    /* JADX WARN: Code restructure failed: missing block: B:634:0x0897, code lost:
        if (r32.beanInfo.fields == null) goto L267;
     */
    /* JADX WARN: Code restructure failed: missing block: B:636:0x089e, code lost:
        if (r5 >= r32.beanInfo.fields.length) goto L266;
     */
    /* JADX WARN: Code restructure failed: missing block: B:637:0x08a0, code lost:
        r32.beanInfo.fields[r5].set(r1, r10);
     */
    /* JADX WARN: Code restructure failed: missing block: B:638:0x08a9, code lost:
        r5 = r5 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:639:0x08ac, code lost:
        r0 = e;
     */
    /* JADX WARN: Code restructure failed: missing block: B:641:0x08ae, code lost:
        r1 = r1 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:642:0x08b1, code lost:
        r1 = r32.beanInfo.creatorConstructor.newInstance(r7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:643:0x08b9, code lost:
        if (r4 == null) goto L282;
     */
    /* JADX WARN: Code restructure failed: missing block: B:644:0x08bb, code lost:
        r2 = r2.entrySet().iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:646:0x08c7, code lost:
        if (r2.hasNext() == false) goto L281;
     */
    /* JADX WARN: Code restructure failed: missing block: B:647:0x08c9, code lost:
        r4 = r2.next();
        r5 = getFieldDeserializer(r4.getKey());
     */
    /* JADX WARN: Code restructure failed: missing block: B:648:0x08d9, code lost:
        if (r5 == null) goto L280;
     */
    /* JADX WARN: Code restructure failed: missing block: B:649:0x08db, code lost:
        r5.setValue(r1, r4.getValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:650:0x08e3, code lost:
        r0 = e;
     */
    /* JADX WARN: Code restructure failed: missing block: B:653:0x090d, code lost:
        throw new com.alibaba.fastjson.JSONException("create instance error, " + r4 + ", " + r32.beanInfo.creatorConstructor.toGenericString(), r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:655:0x0912, code lost:
        if (r32.beanInfo.factoryMethod == null) goto L317;
     */
    /* JADX WARN: Code restructure failed: missing block: B:656:0x0914, code lost:
        r1 = r32.beanInfo.factoryMethod.invoke(null, r7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:658:0x091e, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:661:0x093e, code lost:
        throw new com.alibaba.fastjson.JSONException("create factory method error, " + r32.beanInfo.factoryMethod.toString(), r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:662:0x093f, code lost:
        r1 = r37;
     */
    /* JADX WARN: Code restructure failed: missing block: B:663:0x0941, code lost:
        if (r6 == null) goto L284;
     */
    /* JADX WARN: Code restructure failed: missing block: B:664:0x0943, code lost:
        r6.object = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:665:0x0946, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:666:0x0947, code lost:
        r1 = (T) r37;
     */
    /* JADX WARN: Code restructure failed: missing block: B:667:0x094b, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:668:0x094c, code lost:
        r1 = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:669:0x0950, code lost:
        r1 = r1;
        r3 = r31;
     */
    /* JADX WARN: Code restructure failed: missing block: B:670:0x0954, code lost:
        r2 = r32.beanInfo.buildMethod;
     */
    /* JADX WARN: Code restructure failed: missing block: B:671:0x0958, code lost:
        if (r2 != null) goto L290;
     */
    /* JADX WARN: Code restructure failed: missing block: B:672:0x095a, code lost:
        if (r6 == null) goto L288;
     */
    /* JADX WARN: Code restructure failed: missing block: B:673:0x095c, code lost:
        r6.object = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:674:0x095e, code lost:
        r33.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:675:0x0961, code lost:
        return (T) r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:677:0x0963, code lost:
        r2 = (T) r2.invoke(r1, null);
     */
    /* JADX WARN: Code restructure failed: missing block: B:678:0x0967, code lost:
        if (r6 == null) goto L295;
     */
    /* JADX WARN: Code restructure failed: missing block: B:679:0x0969, code lost:
        r6.object = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:680:0x096b, code lost:
        r33.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:681:0x096e, code lost:
        return r2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:682:0x096f, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:685:0x0978, code lost:
        throw new com.alibaba.fastjson.JSONException("build object error", r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:686:0x0979, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:695:0x09c2, code lost:
        throw new com.alibaba.fastjson.JSONException("syntax error, unexpect token " + com.alibaba.fastjson.parser.JSONToken.name(r12.token()));
     */
    /* JADX WARN: Code restructure failed: missing block: B:705:0x09da, code lost:
        r2 = r0;
        r15 = r6;
     */
    /* JADX WARN: Code restructure failed: missing block: B:709:0x09e5, code lost:
        r15.object = r1;
     */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:247:0x0301 A[Catch: all -> 0x03db, TryCatch #18 {all -> 0x03db, blocks: (B:308:0x03b6, B:310:0x03c0, B:314:0x03cd, B:324:0x03ee, B:326:0x03f7, B:328:0x0403, B:330:0x0409, B:332:0x0411, B:334:0x0417, B:335:0x041a, B:336:0x0426, B:339:0x042f, B:341:0x0433, B:342:0x0436, B:344:0x043a, B:345:0x043d, B:346:0x0449, B:348:0x0451, B:349:0x0457, B:351:0x045d, B:353:0x0463, B:354:0x0469, B:355:0x046f, B:356:0x0473, B:359:0x047b, B:370:0x04ab, B:371:0x04c5, B:373:0x04c8, B:386:0x0501, B:388:0x0509, B:391:0x0515, B:393:0x051d, B:395:0x0525, B:397:0x052d, B:399:0x0534, B:401:0x053f, B:406:0x0551, B:408:0x0555, B:410:0x055b, B:134:0x01db, B:141:0x01e9, B:146:0x01f8, B:153:0x0207, B:155:0x020b, B:158:0x0214, B:163:0x021e, B:166:0x0227, B:171:0x0231, B:174:0x023a, B:177:0x0240, B:182:0x024a, B:187:0x0254, B:192:0x025e, B:194:0x0264, B:197:0x0272, B:199:0x027a, B:201:0x027e, B:204:0x028e, B:211:0x029f, B:214:0x02a9, B:219:0x02b4, B:222:0x02bd, B:227:0x02c8, B:230:0x02d1, B:233:0x02d8, B:237:0x02e4, B:239:0x02ec, B:244:0x02fb, B:247:0x0301, B:243:0x02f7, B:250:0x0308, B:252:0x0312, B:256:0x031d, B:259:0x0322, B:255:0x0319, B:262:0x0328, B:266:0x0339, B:269:0x033e, B:265:0x0335, B:272:0x0344, B:274:0x034e, B:278:0x0359, B:281:0x035e, B:277:0x0355, B:284:0x0364, B:286:0x036c, B:290:0x0377, B:293:0x037c, B:289:0x0373), top: B:745:0x03b6 }] */
    /* JADX WARN: Removed duplicated region for block: B:427:0x05ab  */
    /* JADX WARN: Removed duplicated region for block: B:429:0x05b6 A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:441:0x05ef  */
    /* JADX WARN: Removed duplicated region for block: B:478:0x067f  */
    /* JADX WARN: Removed duplicated region for block: B:501:0x06ed  */
    /* JADX WARN: Removed duplicated region for block: B:502:0x06f1 A[Catch: all -> 0x09d0, TryCatch #9 {all -> 0x09d0, blocks: (B:499:0x06e5, B:502:0x06f1, B:504:0x06f7, B:487:0x06ba, B:497:0x06dd), top: B:729:0x06e5 }] */
    /* JADX WARN: Removed duplicated region for block: B:709:0x09e5  */
    /* JADX WARN: Removed duplicated region for block: B:720:0x03ac A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Type inference failed for: r33v0, types: [com.alibaba.fastjson.parser.DefaultJSONParser] */
    /* JADX WARN: Type inference failed for: r3v114 */
    /* JADX WARN: Type inference failed for: r3v115 */
    /* JADX WARN: Type inference failed for: r3v17 */
    /* JADX WARN: Type inference failed for: r3v38 */
    /* JADX WARN: Type inference failed for: r3v39 */
    /* JADX WARN: Type inference failed for: r3v41, types: [com.alibaba.fastjson.parser.ParseContext] */
    /* JADX WARN: Type inference failed for: r3v47 */
    /* JADX WARN: Type inference failed for: r3v85 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i, int[] iArr) {
        Object obj3;
        Throwable th;
        ParseContext parseContext;
        int i2;
        boolean z;
        Class<?> cls;
        FieldDeserializer fieldDeserializer;
        FieldInfo fieldInfo;
        JSONField jSONField;
        Throwable th2;
        Object obj4;
        int[] iArr2;
        Class<?> cls2;
        Object obj5;
        boolean z2;
        ParseContext parseContext2;
        HashMap hashMap;
        Object obj6;
        int i3;
        String str;
        int i4;
        ParseContext parseContext3;
        int[] iArr3;
        int i5;
        Throwable th3;
        boolean z3;
        String scanSymbol;
        Object obj7;
        ParseContext parseContext4;
        byte b;
        int i6;
        Object obj8;
        ?? r3;
        int i7;
        T t;
        String str2;
        Class<String> cls3;
        HashMap hashMap2;
        Object obj9;
        Class<String> cls4;
        int i8;
        ParseContext parseContext5;
        Class<String> cls5;
        String str3;
        Class<String> cls6;
        Class<String> cls7;
        Class<String> cls8;
        Class<String> cls9;
        HashMap hashMap3;
        Object scanFieldBigInteger;
        Class<?> cls10;
        Class<?>[] seeAlso;
        if (type == JSON.class || type == JSONObject.class) {
            return (T) defaultJSONParser.parse();
        }
        JSONLexerBase jSONLexerBase = (JSONLexerBase) defaultJSONParser.lexer;
        ParserConfig config = defaultJSONParser.getConfig();
        int i9 = jSONLexerBase.token();
        ParseContext parseContext6 = null;
        if (i9 == 8) {
            jSONLexerBase.nextToken(16);
            return null;
        }
        ParseContext context = defaultJSONParser.getContext();
        if (obj2 != null && context != null) {
            context = context.parent;
        }
        ParseContext parseContext7 = context;
        try {
            if (i9 == 13) {
                jSONLexerBase.nextToken(16);
                T t2 = obj2 == null ? (T) createInstance((DefaultJSONParser) defaultJSONParser, type) : (T) obj2;
                defaultJSONParser.setContext(parseContext7);
                return t2;
            }
            if (i9 == 14) {
                int i10 = Feature.SupportArrayToBean.mask;
                if ((this.beanInfo.parserFeatures & i10) != 0 || jSONLexerBase.isEnabled(Feature.SupportArrayToBean) || (i & i10) != 0) {
                    T t3 = (T) deserialzeArrayMapping(defaultJSONParser, type, obj, obj2);
                    defaultJSONParser.setContext(parseContext7);
                    return t3;
                }
            }
            if (i9 != 12 && i9 != 16) {
                if (jSONLexerBase.isBlankInput()) {
                    defaultJSONParser.setContext(parseContext7);
                    return null;
                }
                if (i9 == 4) {
                    String stringVal = jSONLexerBase.stringVal();
                    if (stringVal.length() == 0) {
                        jSONLexerBase.nextToken();
                        defaultJSONParser.setContext(parseContext7);
                        return null;
                    } else if (this.beanInfo.jsonType != null) {
                        for (Class<?> cls11 : this.beanInfo.jsonType.seeAlso()) {
                            if (Enum.class.isAssignableFrom(cls11)) {
                                try {
                                    T t4 = (T) Enum.valueOf(cls11, stringVal);
                                    defaultJSONParser.setContext(parseContext7);
                                    return t4;
                                } catch (IllegalArgumentException unused) {
                                    continue;
                                }
                            }
                        }
                    }
                }
                if (i9 == 14 && jSONLexerBase.getCurrent() == ']') {
                    jSONLexerBase.next();
                    jSONLexerBase.nextToken();
                    defaultJSONParser.setContext(parseContext7);
                    return null;
                }
                if (this.beanInfo.factoryMethod != null && this.beanInfo.fields.length == 1) {
                    try {
                        FieldInfo fieldInfo2 = this.beanInfo.fields[0];
                        if (fieldInfo2.fieldClass == Integer.class) {
                            if (i9 == 2) {
                                int intValue = jSONLexerBase.intValue();
                                jSONLexerBase.nextToken();
                                T t5 = (T) createFactoryInstance(config, Integer.valueOf(intValue));
                                defaultJSONParser.setContext(parseContext7);
                                return t5;
                            }
                        } else if (fieldInfo2.fieldClass == String.class && i9 == 4) {
                            String stringVal2 = jSONLexerBase.stringVal();
                            jSONLexerBase.nextToken();
                            T t6 = (T) createFactoryInstance(config, stringVal2);
                            defaultJSONParser.setContext(parseContext7);
                            return t6;
                        }
                    } catch (Exception e) {
                        throw new JSONException(e.getMessage(), e);
                    }
                }
                StringBuilder sb = new StringBuilder();
                sb.append("syntax error, expect {, actual ");
                sb.append(jSONLexerBase.tokenName());
                sb.append(", pos ");
                sb.append(jSONLexerBase.pos());
                if (obj instanceof String) {
                    sb.append(", fieldName ");
                    sb.append(obj);
                }
                sb.append(", fastjson-version ");
                sb.append(JSON.VERSION);
                throw new JSONException(sb.toString());
            }
            try {
                if (defaultJSONParser.resolveStatus == 2) {
                    defaultJSONParser.resolveStatus = 0;
                }
                String str4 = this.beanInfo.typeKey;
                obj3 = obj2;
                int[] iArr4 = iArr;
                ParseContext parseContext8 = null;
                HashMap hashMap4 = null;
                int i11 = 0;
                int i12 = 0;
                while (true) {
                    try {
                        FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                        if (i12 >= fieldDeserializerArr.length || i11 >= 16) {
                            i2 = i12;
                            z = false;
                            cls = null;
                            fieldDeserializer = null;
                            fieldInfo = null;
                            jSONField = null;
                        } else {
                            try {
                                fieldDeserializer = fieldDeserializerArr[i12];
                                fieldInfo = fieldDeserializer.fieldInfo;
                                i2 = i12;
                                Class<?> cls12 = fieldInfo.fieldClass;
                                jSONField = fieldInfo.getAnnotation();
                                if (jSONField != null) {
                                    cls10 = cls12;
                                    if (fieldDeserializer instanceof DefaultFieldDeserializer) {
                                        z = ((DefaultFieldDeserializer) fieldDeserializer).customDeserilizer;
                                        cls = cls10;
                                    }
                                } else {
                                    cls10 = cls12;
                                }
                                cls = cls10;
                                z = false;
                            } catch (Throwable th4) {
                                th2 = th4;
                                th = th2;
                                parseContext6 = parseContext8;
                                parseContext = parseContext7;
                                if (parseContext6 != null) {
                                }
                                defaultJSONParser.setContext(parseContext);
                                throw th;
                            }
                        }
                        if (fieldDeserializer != null) {
                            iArr2 = iArr4;
                            try {
                                char[] cArr = fieldInfo.name_chars;
                                if (z && jSONLexerBase.matchField(cArr)) {
                                    obj4 = obj3;
                                } else {
                                    obj4 = obj3;
                                    if (cls != Integer.TYPE && cls != Integer.class) {
                                        if (cls != Long.TYPE && cls != Long.class) {
                                            try {
                                                if (cls == String.class) {
                                                    scanFieldBigInteger = jSONLexerBase.scanFieldString(cArr);
                                                    if (jSONLexerBase.matchStat <= 0) {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i11 + 1;
                                                            str = str4;
                                                            parseContext2 = parseContext8;
                                                            parseContext3 = parseContext7;
                                                            hashMap = hashMap4;
                                                            obj6 = obj4;
                                                        }
                                                        obj5 = scanFieldBigInteger;
                                                        cls2 = cls;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                            try {
                                                                scanSymbol = jSONLexerBase.scanSymbol(defaultJSONParser.symbolTable);
                                                                if (scanSymbol == null) {
                                                                    i5 = i11;
                                                                    try {
                                                                        int i13 = jSONLexerBase.token();
                                                                        obj7 = obj5;
                                                                        if (i13 == 13) {
                                                                            jSONLexerBase.nextToken(16);
                                                                            i6 = i13;
                                                                            break;
                                                                        } else if (i13 == 16) {
                                                                        }
                                                                    } catch (Throwable th5) {
                                                                        th = th5;
                                                                        parseContext6 = parseContext8;
                                                                        parseContext = parseContext7;
                                                                        obj3 = obj4;
                                                                        if (parseContext6 != null) {
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext);
                                                                        throw th;
                                                                    }
                                                                } else {
                                                                    obj7 = obj5;
                                                                    i5 = i11;
                                                                }
                                                                if ("$ref" == scanSymbol && parseContext7 != null) {
                                                                    jSONLexerBase.nextTokenWithColon(4);
                                                                    if (jSONLexerBase.token() != 4) {
                                                                        throw new JSONException("illegal ref, " + JSONToken.name(i7));
                                                                    }
                                                                    String stringVal3 = jSONLexerBase.stringVal();
                                                                    if ("@".equals(stringVal3)) {
                                                                        t = (T) parseContext7.object;
                                                                    } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(stringVal3)) {
                                                                        ParseContext parseContext9 = parseContext7.parent;
                                                                        if (parseContext9.object != null) {
                                                                            t = (T) parseContext9.object;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext9, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            t = (T) obj4;
                                                                        }
                                                                    } else if (Operators.DOLLAR_STR.equals(stringVal3)) {
                                                                        ParseContext parseContext10 = parseContext7;
                                                                        while (parseContext10.parent != null) {
                                                                            parseContext10 = parseContext10.parent;
                                                                        }
                                                                        if (parseContext10.object != null) {
                                                                            t = (T) parseContext10.object;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext10, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            t = (T) obj4;
                                                                        }
                                                                    } else {
                                                                        if (stringVal3.indexOf(92) > 0) {
                                                                            StringBuilder sb2 = new StringBuilder();
                                                                            int i14 = 0;
                                                                            while (i14 < stringVal3.length()) {
                                                                                char charAt = stringVal3.charAt(i14);
                                                                                if (charAt == '\\') {
                                                                                    i14++;
                                                                                    charAt = stringVal3.charAt(i14);
                                                                                }
                                                                                sb2.append(charAt);
                                                                                i14++;
                                                                            }
                                                                            stringVal3 = sb2.toString();
                                                                        }
                                                                        Object resolveReference = defaultJSONParser.resolveReference(stringVal3);
                                                                        if (resolveReference != null) {
                                                                            t = (T) resolveReference;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext7, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            t = (T) obj4;
                                                                        }
                                                                    }
                                                                    jSONLexerBase.nextToken(13);
                                                                    if (jSONLexerBase.token() == 13) {
                                                                        jSONLexerBase.nextToken(16);
                                                                        defaultJSONParser.setContext(parseContext7, t, obj);
                                                                        if (parseContext8 != null) {
                                                                            parseContext8.object = t;
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext7);
                                                                        return t;
                                                                    }
                                                                    throw new JSONException("illegal ref");
                                                                } else if ((str4 == null || !str4.equals(scanSymbol)) && JSON.DEFAULT_TYPE_KEY != scanSymbol) {
                                                                    obj8 = obj4;
                                                                    r3 = 13;
                                                                } else {
                                                                    jSONLexerBase.nextTokenWithColon(4);
                                                                    if (jSONLexerBase.token() != 4) {
                                                                        throw new JSONException("syntax error");
                                                                    }
                                                                    String stringVal4 = jSONLexerBase.stringVal();
                                                                    jSONLexerBase.nextToken(16);
                                                                    if (!stringVal4.equals(this.beanInfo.typeName) && !defaultJSONParser.isEnabled(Feature.IgnoreAutoType)) {
                                                                        ObjectDeserializer seeAlso2 = getSeeAlso(config, this.beanInfo, stringVal4);
                                                                        if (seeAlso2 != null) {
                                                                            Class<?> cls13 = null;
                                                                            break;
                                                                        }
                                                                        Class<?> cls14 = TypeUtils.getClass(type);
                                                                        ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler = this.autoTypeCheckHandler;
                                                                        Class<?> handler = autoTypeCheckHandler != null ? autoTypeCheckHandler.handler(stringVal4, cls14, jSONLexerBase.getFeatures()) : null;
                                                                        if (handler != null || (!stringVal4.equals("java.util.HashMap") && !stringVal4.equals("java.util.LinkedHashMap"))) {
                                                                            break;
                                                                        }
                                                                        if (jSONLexerBase.token() == 13) {
                                                                            jSONLexerBase.nextToken();
                                                                            i6 = handler;
                                                                            break;
                                                                        }
                                                                        obj3 = obj4;
                                                                        i4 = i2;
                                                                        obj6 = obj3;
                                                                        str = str4;
                                                                        parseContext2 = parseContext8;
                                                                        parseContext3 = parseContext7;
                                                                        i3 = i5;
                                                                        hashMap = hashMap4;
                                                                    }
                                                                    obj3 = obj4;
                                                                    int i15 = 13;
                                                                    if (jSONLexerBase.token() == 13) {
                                                                        jSONLexerBase.nextToken();
                                                                        break;
                                                                    }
                                                                    i4 = i2;
                                                                    obj6 = obj3;
                                                                    str = str4;
                                                                    parseContext2 = parseContext8;
                                                                    parseContext3 = parseContext7;
                                                                    i3 = i5;
                                                                    hashMap = hashMap4;
                                                                }
                                                            } catch (Throwable th6) {
                                                                th2 = th6;
                                                                obj3 = obj4;
                                                                th = th2;
                                                                parseContext6 = parseContext8;
                                                                parseContext = parseContext7;
                                                                if (parseContext6 != null) {
                                                                }
                                                                defaultJSONParser.setContext(parseContext);
                                                                throw th;
                                                            }
                                                        } else {
                                                            obj7 = obj5;
                                                            i5 = i11;
                                                            obj8 = obj4;
                                                            r3 = 13;
                                                            scanSymbol = null;
                                                        }
                                                        if (obj8 == null || hashMap4 != null) {
                                                            str2 = str4;
                                                            cls3 = r3;
                                                        } else {
                                                            obj8 = createInstance((DefaultJSONParser) defaultJSONParser, type);
                                                            if (obj8 == null) {
                                                                str2 = str4;
                                                                HashMap hashMap5 = new HashMap(this.fieldDeserializers.length);
                                                                hashMap4 = hashMap5;
                                                                hashMap3 = hashMap5;
                                                            } else {
                                                                str2 = str4;
                                                                hashMap3 = r3;
                                                            }
                                                            parseContext8 = defaultJSONParser.setContext(parseContext7, obj8, obj);
                                                            cls3 = hashMap3;
                                                            if (iArr2 == null) {
                                                                int[] iArr5 = new int[(this.fieldDeserializers.length / 32) + 1];
                                                                parseContext2 = parseContext8;
                                                                hashMap2 = hashMap4;
                                                                obj9 = obj8;
                                                                iArr3 = iArr5;
                                                                cls4 = iArr5;
                                                                if (z2) {
                                                                    if (z3) {
                                                                        Class<?> cls15 = cls2;
                                                                        if (obj9 == null) {
                                                                            hashMap2.put(fieldInfo.name, obj7);
                                                                            cls7 = cls4;
                                                                        } else {
                                                                            Object obj10 = obj7;
                                                                            if (obj10 == null) {
                                                                                Class<String> cls16 = Integer.TYPE;
                                                                                cls7 = cls16;
                                                                                if (cls15 != cls16) {
                                                                                    Class<String> cls17 = Long.TYPE;
                                                                                    cls7 = cls17;
                                                                                    if (cls15 != cls17) {
                                                                                        Class<String> cls18 = Float.TYPE;
                                                                                        cls7 = cls18;
                                                                                        if (cls15 != cls18) {
                                                                                            Class<String> cls19 = Double.TYPE;
                                                                                            cls7 = cls19;
                                                                                            if (cls15 != cls19) {
                                                                                                Class<String> cls20 = Boolean.TYPE;
                                                                                                cls7 = cls20;
                                                                                                if (cls15 != cls20) {
                                                                                                    fieldDeserializer.setValue(obj9, obj10);
                                                                                                    cls7 = cls20;
                                                                                                }
                                                                                            }
                                                                                        }
                                                                                    }
                                                                                }
                                                                            } else {
                                                                                int i16 = String.class;
                                                                                if (cls15 == String.class) {
                                                                                    int i17 = String.class;
                                                                                    if ((i & Feature.TrimStringFieldValue.mask) == 0) {
                                                                                        int i18 = this.beanInfo.parserFeatures;
                                                                                        int i19 = Feature.TrimStringFieldValue.mask;
                                                                                        int i20 = i18 & i19;
                                                                                        i17 = i19;
                                                                                        if (i20 == 0) {
                                                                                            int i21 = fieldInfo.parserFeatures;
                                                                                            int i22 = Feature.TrimStringFieldValue.mask;
                                                                                            int i23 = i21 & i22;
                                                                                            i17 = i22;
                                                                                            i16 = i22;
                                                                                        }
                                                                                    }
                                                                                    str3 = ((String) obj10).trim();
                                                                                    cls6 = i17;
                                                                                    fieldDeserializer.setValue(obj9, str3);
                                                                                    cls7 = cls6;
                                                                                }
                                                                                str3 = obj10;
                                                                                cls6 = i16;
                                                                                fieldDeserializer.setValue(obj9, str3);
                                                                                cls7 = cls6;
                                                                            }
                                                                        }
                                                                        if (iArr3 != null) {
                                                                            int i24 = i2 / 32;
                                                                            int i25 = iArr3[i24];
                                                                            iArr3[i24] = (1 << (i2 % 32)) | i25;
                                                                            cls8 = i25;
                                                                        } else {
                                                                            cls8 = cls7;
                                                                        }
                                                                        cls9 = cls8;
                                                                        if (jSONLexerBase.matchStat == 4) {
                                                                            hashMap = hashMap2;
                                                                            obj6 = obj9;
                                                                            parseContext4 = parseContext7;
                                                                            b = 0;
                                                                            int i26 = cls8;
                                                                            break;
                                                                        }
                                                                    } else {
                                                                        try {
                                                                            fieldDeserializer.parseField(defaultJSONParser, obj9, type, hashMap2);
                                                                            cls9 = cls4;
                                                                        } catch (Throwable th7) {
                                                                            th = th7;
                                                                            obj3 = obj9;
                                                                            parseContext = parseContext7;
                                                                            parseContext6 = parseContext2;
                                                                            if (parseContext6 != null) {
                                                                            }
                                                                            defaultJSONParser.setContext(parseContext);
                                                                            throw th;
                                                                        }
                                                                    }
                                                                    i4 = i2;
                                                                    obj6 = obj9;
                                                                    parseContext4 = parseContext7;
                                                                    i3 = i5;
                                                                    str = str2;
                                                                    b = 0;
                                                                    i8 = 13;
                                                                    hashMap = hashMap2;
                                                                    cls5 = cls9;
                                                                    try {
                                                                        if (jSONLexerBase.token() != 16) {
                                                                            parseContext5 = parseContext4;
                                                                            parseContext = parseContext5;
                                                                            parseContext7 = parseContext;
                                                                            i12 = i4 + 1;
                                                                            str4 = str;
                                                                            i11 = i3;
                                                                            iArr4 = iArr3;
                                                                            obj3 = obj6;
                                                                            hashMap4 = hashMap;
                                                                            parseContext8 = parseContext2;
                                                                        } else if (jSONLexerBase.token() == i8) {
                                                                            break;
                                                                        } else {
                                                                            parseContext = parseContext4;
                                                                            if (jSONLexerBase.token() == 18 || jSONLexerBase.token() == 1) {
                                                                                break;
                                                                            }
                                                                            parseContext7 = parseContext;
                                                                            i12 = i4 + 1;
                                                                            str4 = str;
                                                                            i11 = i3;
                                                                            iArr4 = iArr3;
                                                                            obj3 = obj6;
                                                                            hashMap4 = hashMap;
                                                                            parseContext8 = parseContext2;
                                                                        }
                                                                    } catch (Throwable th8) {
                                                                        th3 = th8;
                                                                        parseContext = parseContext4;
                                                                        th = th3;
                                                                        obj3 = obj6;
                                                                        parseContext6 = parseContext2;
                                                                        if (parseContext6 != null) {
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext);
                                                                        throw th;
                                                                    }
                                                                } else {
                                                                    i3 = i5;
                                                                    String str5 = scanSymbol;
                                                                    i4 = i2;
                                                                    hashMap = hashMap2;
                                                                    str = str2;
                                                                    obj6 = obj9;
                                                                    b = 0;
                                                                    i8 = 13;
                                                                    parseContext4 = parseContext7;
                                                                    if (parseField(defaultJSONParser, str5, obj9, type, hashMap2 == null ? new HashMap(this.fieldDeserializers.length) : hashMap2, iArr3)) {
                                                                        cls5 = str5;
                                                                        if (jSONLexerBase.token() == 17) {
                                                                            throw new JSONException("syntax error, unexpect token ':'");
                                                                        }
                                                                        if (jSONLexerBase.token() != 16) {
                                                                        }
                                                                    } else {
                                                                        try {
                                                                            if (jSONLexerBase.token() == 13) {
                                                                                break;
                                                                            }
                                                                            parseContext5 = parseContext4;
                                                                            parseContext = parseContext5;
                                                                            parseContext7 = parseContext;
                                                                            i12 = i4 + 1;
                                                                            str4 = str;
                                                                            i11 = i3;
                                                                            iArr4 = iArr3;
                                                                            obj3 = obj6;
                                                                            hashMap4 = hashMap;
                                                                            parseContext8 = parseContext2;
                                                                        } catch (Throwable th9) {
                                                                            th = th9;
                                                                            obj3 = obj6;
                                                                            parseContext6 = parseContext2;
                                                                            parseContext = parseContext4;
                                                                            if (parseContext6 != null) {
                                                                            }
                                                                            defaultJSONParser.setContext(parseContext);
                                                                            throw th;
                                                                        }
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap4;
                                                        iArr3 = iArr2;
                                                        obj9 = obj8;
                                                        cls4 = cls3;
                                                        if (z2) {
                                                        }
                                                    }
                                                    obj5 = scanFieldBigInteger;
                                                    cls2 = cls;
                                                    z2 = true;
                                                    z3 = true;
                                                    if (z2) {
                                                    }
                                                    if (obj8 == null) {
                                                    }
                                                    str2 = str4;
                                                    cls3 = r3;
                                                    parseContext2 = parseContext8;
                                                    hashMap2 = hashMap4;
                                                    iArr3 = iArr2;
                                                    obj9 = obj8;
                                                    cls4 = cls3;
                                                    if (z2) {
                                                    }
                                                } else if (cls == Date.class && fieldInfo.format == null) {
                                                    scanFieldBigInteger = jSONLexerBase.scanFieldDate(cArr);
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        obj5 = scanFieldBigInteger;
                                                        cls2 = cls;
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj8 == null) {
                                                        }
                                                        str2 = str4;
                                                        cls3 = r3;
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap4;
                                                        iArr3 = iArr2;
                                                        obj9 = obj8;
                                                        cls4 = cls3;
                                                        if (z2) {
                                                        }
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i11 + 1;
                                                            str = str4;
                                                            parseContext2 = parseContext8;
                                                            parseContext3 = parseContext7;
                                                            hashMap = hashMap4;
                                                            obj6 = obj4;
                                                        }
                                                        obj5 = scanFieldBigInteger;
                                                        cls2 = cls;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj8 == null) {
                                                        }
                                                        str2 = str4;
                                                        cls3 = r3;
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap4;
                                                        iArr3 = iArr2;
                                                        obj9 = obj8;
                                                        cls4 = cls3;
                                                        if (z2) {
                                                        }
                                                    }
                                                } else if (cls == BigDecimal.class) {
                                                    scanFieldBigInteger = jSONLexerBase.scanFieldDecimal(cArr);
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        obj5 = scanFieldBigInteger;
                                                        cls2 = cls;
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj8 == null) {
                                                        }
                                                        str2 = str4;
                                                        cls3 = r3;
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap4;
                                                        iArr3 = iArr2;
                                                        obj9 = obj8;
                                                        cls4 = cls3;
                                                        if (z2) {
                                                        }
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i11 + 1;
                                                            str = str4;
                                                            parseContext2 = parseContext8;
                                                            parseContext3 = parseContext7;
                                                            hashMap = hashMap4;
                                                            obj6 = obj4;
                                                        }
                                                        obj5 = scanFieldBigInteger;
                                                        cls2 = cls;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj8 == null) {
                                                        }
                                                        str2 = str4;
                                                        cls3 = r3;
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap4;
                                                        iArr3 = iArr2;
                                                        obj9 = obj8;
                                                        cls4 = cls3;
                                                        if (z2) {
                                                        }
                                                    }
                                                } else {
                                                    if (cls == BigInteger.class) {
                                                        scanFieldBigInteger = jSONLexerBase.scanFieldBigInteger(cArr);
                                                        if (jSONLexerBase.matchStat > 0) {
                                                            obj5 = scanFieldBigInteger;
                                                            cls2 = cls;
                                                            z2 = true;
                                                            z3 = true;
                                                            if (z2) {
                                                            }
                                                            if (obj8 == null) {
                                                            }
                                                            str2 = str4;
                                                            cls3 = r3;
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap4;
                                                            iArr3 = iArr2;
                                                            obj9 = obj8;
                                                            cls4 = cls3;
                                                            if (z2) {
                                                            }
                                                        } else {
                                                            if (jSONLexerBase.matchStat == -2) {
                                                            }
                                                            obj5 = scanFieldBigInteger;
                                                            cls2 = cls;
                                                            z2 = false;
                                                            z3 = false;
                                                            if (z2) {
                                                            }
                                                            if (obj8 == null) {
                                                            }
                                                            str2 = str4;
                                                            cls3 = r3;
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap4;
                                                            iArr3 = iArr2;
                                                            obj9 = obj8;
                                                            cls4 = cls3;
                                                            if (z2) {
                                                            }
                                                        }
                                                    } else {
                                                        if (cls != Boolean.TYPE && cls != Boolean.class) {
                                                            if (cls != Float.TYPE && cls != Float.class) {
                                                                if (cls != Double.TYPE && cls != Double.class) {
                                                                    if (!cls.isEnum() || !(defaultJSONParser.getConfig().getDeserializer(cls) instanceof EnumDeserializer) || (jSONField != null && jSONField.deserializeUsing() != Void.class)) {
                                                                        if (cls == int[].class) {
                                                                            obj5 = jSONLexerBase.scanFieldIntArray(cArr);
                                                                            if (jSONLexerBase.matchStat <= 0) {
                                                                                if (jSONLexerBase.matchStat == -2) {
                                                                                }
                                                                                cls2 = cls;
                                                                                z2 = false;
                                                                                z3 = false;
                                                                            }
                                                                            cls2 = cls;
                                                                            z2 = true;
                                                                            z3 = true;
                                                                        } else if (cls == float[].class) {
                                                                            obj5 = jSONLexerBase.scanFieldFloatArray(cArr);
                                                                            if (jSONLexerBase.matchStat > 0) {
                                                                                cls2 = cls;
                                                                                z2 = true;
                                                                                z3 = true;
                                                                            } else {
                                                                                if (jSONLexerBase.matchStat == -2) {
                                                                                }
                                                                                cls2 = cls;
                                                                                z2 = false;
                                                                                z3 = false;
                                                                            }
                                                                        } else if (cls == float[][].class) {
                                                                            obj5 = jSONLexerBase.scanFieldFloatArray2(cArr);
                                                                            if (jSONLexerBase.matchStat > 0) {
                                                                                cls2 = cls;
                                                                                z2 = true;
                                                                                z3 = true;
                                                                            } else {
                                                                                if (jSONLexerBase.matchStat == -2) {
                                                                                }
                                                                                cls2 = cls;
                                                                                z2 = false;
                                                                                z3 = false;
                                                                            }
                                                                        } else if (!jSONLexerBase.matchField(cArr)) {
                                                                            i5 = i11;
                                                                            obj3 = obj4;
                                                                            i4 = i2;
                                                                            obj6 = obj3;
                                                                            str = str4;
                                                                            parseContext2 = parseContext8;
                                                                            parseContext3 = parseContext7;
                                                                            i3 = i5;
                                                                            hashMap = hashMap4;
                                                                        }
                                                                        if (z2) {
                                                                        }
                                                                        if (obj8 == null) {
                                                                        }
                                                                        str2 = str4;
                                                                        cls3 = r3;
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap4;
                                                                        iArr3 = iArr2;
                                                                        obj9 = obj8;
                                                                        cls4 = cls3;
                                                                        if (z2) {
                                                                        }
                                                                    } else if (fieldDeserializer instanceof DefaultFieldDeserializer) {
                                                                        obj5 = scanEnum(jSONLexerBase, cArr, ((DefaultFieldDeserializer) fieldDeserializer).fieldValueDeserilizer);
                                                                        if (jSONLexerBase.matchStat > 0) {
                                                                            z2 = true;
                                                                            z3 = true;
                                                                        } else if (jSONLexerBase.matchStat != -2) {
                                                                            z2 = false;
                                                                            z3 = false;
                                                                        }
                                                                        cls2 = cls;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj8 == null) {
                                                                        }
                                                                        str2 = str4;
                                                                        cls3 = r3;
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap4;
                                                                        iArr3 = iArr2;
                                                                        obj9 = obj8;
                                                                        cls4 = cls3;
                                                                        if (z2) {
                                                                        }
                                                                    }
                                                                }
                                                                double scanFieldDouble = jSONLexerBase.scanFieldDouble(cArr);
                                                                if (scanFieldDouble == 0.0d) {
                                                                    cls2 = cls;
                                                                    if (jSONLexerBase.matchStat == 5) {
                                                                        obj5 = null;
                                                                        if (jSONLexerBase.matchStat <= 0) {
                                                                            if (jSONLexerBase.matchStat == -2) {
                                                                            }
                                                                            z2 = false;
                                                                            z3 = false;
                                                                            if (z2) {
                                                                            }
                                                                            if (obj8 == null) {
                                                                            }
                                                                            str2 = str4;
                                                                            cls3 = r3;
                                                                            parseContext2 = parseContext8;
                                                                            hashMap2 = hashMap4;
                                                                            iArr3 = iArr2;
                                                                            obj9 = obj8;
                                                                            cls4 = cls3;
                                                                            if (z2) {
                                                                            }
                                                                        }
                                                                        z2 = true;
                                                                        z3 = true;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj8 == null) {
                                                                        }
                                                                        str2 = str4;
                                                                        cls3 = r3;
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap4;
                                                                        iArr3 = iArr2;
                                                                        obj9 = obj8;
                                                                        cls4 = cls3;
                                                                        if (z2) {
                                                                        }
                                                                    }
                                                                } else {
                                                                    cls2 = cls;
                                                                }
                                                                obj5 = Double.valueOf(scanFieldDouble);
                                                                if (jSONLexerBase.matchStat <= 0) {
                                                                }
                                                                z2 = true;
                                                                z3 = true;
                                                                if (z2) {
                                                                }
                                                                if (obj8 == null) {
                                                                }
                                                                str2 = str4;
                                                                cls3 = r3;
                                                                parseContext2 = parseContext8;
                                                                hashMap2 = hashMap4;
                                                                iArr3 = iArr2;
                                                                obj9 = obj8;
                                                                cls4 = cls3;
                                                                if (z2) {
                                                                }
                                                            }
                                                            cls2 = cls;
                                                            float scanFieldFloat = jSONLexerBase.scanFieldFloat(cArr);
                                                            obj5 = (scanFieldFloat == 0.0f && jSONLexerBase.matchStat == 5) ? null : Float.valueOf(scanFieldFloat);
                                                            if (jSONLexerBase.matchStat > 0) {
                                                                z2 = true;
                                                                z3 = true;
                                                                if (z2) {
                                                                }
                                                                if (obj8 == null) {
                                                                }
                                                                str2 = str4;
                                                                cls3 = r3;
                                                                parseContext2 = parseContext8;
                                                                hashMap2 = hashMap4;
                                                                iArr3 = iArr2;
                                                                obj9 = obj8;
                                                                cls4 = cls3;
                                                                if (z2) {
                                                                }
                                                            } else {
                                                                if (jSONLexerBase.matchStat == -2) {
                                                                }
                                                                z2 = false;
                                                                z3 = false;
                                                                if (z2) {
                                                                }
                                                                if (obj8 == null) {
                                                                }
                                                                str2 = str4;
                                                                cls3 = r3;
                                                                parseContext2 = parseContext8;
                                                                hashMap2 = hashMap4;
                                                                iArr3 = iArr2;
                                                                obj9 = obj8;
                                                                cls4 = cls3;
                                                                if (z2) {
                                                                }
                                                            }
                                                        }
                                                        cls2 = cls;
                                                        obj5 = jSONLexerBase.matchStat == 5 ? null : Boolean.valueOf(jSONLexerBase.scanFieldBoolean(cArr));
                                                        if (jSONLexerBase.matchStat > 0) {
                                                            z2 = true;
                                                            z3 = true;
                                                            if (z2) {
                                                            }
                                                            if (obj8 == null) {
                                                            }
                                                            str2 = str4;
                                                            cls3 = r3;
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap4;
                                                            iArr3 = iArr2;
                                                            obj9 = obj8;
                                                            cls4 = cls3;
                                                            if (z2) {
                                                            }
                                                        } else {
                                                            if (jSONLexerBase.matchStat == -2) {
                                                            }
                                                            z2 = false;
                                                            z3 = false;
                                                            if (z2) {
                                                            }
                                                            if (obj8 == null) {
                                                            }
                                                            str2 = str4;
                                                            cls3 = r3;
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap4;
                                                            iArr3 = iArr2;
                                                            obj9 = obj8;
                                                            cls4 = cls3;
                                                            if (z2) {
                                                            }
                                                        }
                                                    }
                                                    i4 = i2;
                                                    i3 = i11 + 1;
                                                    str = str4;
                                                    parseContext2 = parseContext8;
                                                    parseContext3 = parseContext7;
                                                    hashMap = hashMap4;
                                                    obj6 = obj4;
                                                }
                                                parseContext7 = parseContext;
                                                i12 = i4 + 1;
                                                str4 = str;
                                                i11 = i3;
                                                iArr4 = iArr3;
                                                obj3 = obj6;
                                                hashMap4 = hashMap;
                                                parseContext8 = parseContext2;
                                            } catch (Throwable th10) {
                                                th3 = th10;
                                                th = th3;
                                                obj3 = obj6;
                                                parseContext6 = parseContext2;
                                                if (parseContext6 != null) {
                                                }
                                                defaultJSONParser.setContext(parseContext);
                                                throw th;
                                            }
                                            iArr3 = iArr2;
                                            parseContext = parseContext3;
                                        }
                                        cls2 = cls;
                                        long scanFieldLong = jSONLexerBase.scanFieldLong(cArr);
                                        obj5 = (scanFieldLong == 0 && jSONLexerBase.matchStat == 5) ? null : Long.valueOf(scanFieldLong);
                                        if (jSONLexerBase.matchStat > 0) {
                                            z2 = true;
                                            z3 = true;
                                            if (z2) {
                                            }
                                            if (obj8 == null) {
                                            }
                                            str2 = str4;
                                            cls3 = r3;
                                            parseContext2 = parseContext8;
                                            hashMap2 = hashMap4;
                                            iArr3 = iArr2;
                                            obj9 = obj8;
                                            cls4 = cls3;
                                            if (z2) {
                                            }
                                        } else {
                                            if (jSONLexerBase.matchStat == -2) {
                                                i4 = i2;
                                                i3 = i11 + 1;
                                                str = str4;
                                                parseContext2 = parseContext8;
                                                parseContext3 = parseContext7;
                                                hashMap = hashMap4;
                                                obj6 = obj4;
                                                iArr3 = iArr2;
                                                parseContext = parseContext3;
                                                parseContext7 = parseContext;
                                                i12 = i4 + 1;
                                                str4 = str;
                                                i11 = i3;
                                                iArr4 = iArr3;
                                                obj3 = obj6;
                                                hashMap4 = hashMap;
                                                parseContext8 = parseContext2;
                                            }
                                            z2 = false;
                                            z3 = false;
                                            if (z2) {
                                            }
                                            if (obj8 == null) {
                                            }
                                            str2 = str4;
                                            cls3 = r3;
                                            parseContext2 = parseContext8;
                                            hashMap2 = hashMap4;
                                            iArr3 = iArr2;
                                            obj9 = obj8;
                                            cls4 = cls3;
                                            if (z2) {
                                            }
                                        }
                                    }
                                    cls2 = cls;
                                    int scanFieldInt = jSONLexerBase.scanFieldInt(cArr);
                                    obj5 = (scanFieldInt == 0 && jSONLexerBase.matchStat == 5) ? null : Integer.valueOf(scanFieldInt);
                                    if (jSONLexerBase.matchStat > 0) {
                                        z2 = true;
                                        z3 = true;
                                        if (z2) {
                                        }
                                        if (obj8 == null) {
                                        }
                                        str2 = str4;
                                        cls3 = r3;
                                        parseContext2 = parseContext8;
                                        hashMap2 = hashMap4;
                                        iArr3 = iArr2;
                                        obj9 = obj8;
                                        cls4 = cls3;
                                        if (z2) {
                                        }
                                    }
                                }
                                cls2 = cls;
                                obj5 = null;
                                z2 = true;
                                z3 = false;
                                if (z2) {
                                }
                                if (obj8 == null) {
                                }
                                str2 = str4;
                                cls3 = r3;
                                parseContext2 = parseContext8;
                                hashMap2 = hashMap4;
                                iArr3 = iArr2;
                                obj9 = obj8;
                                cls4 = cls3;
                                if (z2) {
                                }
                            } catch (Throwable th11) {
                                th2 = th11;
                                th = th2;
                                parseContext6 = parseContext8;
                                parseContext = parseContext7;
                                if (parseContext6 != null) {
                                }
                                defaultJSONParser.setContext(parseContext);
                                throw th;
                            }
                        } else {
                            obj4 = obj3;
                            iArr2 = iArr4;
                        }
                        cls2 = cls;
                        obj5 = null;
                        z2 = false;
                        z3 = false;
                        if (z2) {
                        }
                        if (obj8 == null) {
                        }
                        str2 = str4;
                        cls3 = r3;
                        parseContext2 = parseContext8;
                        hashMap2 = hashMap4;
                        iArr3 = iArr2;
                        obj9 = obj8;
                        cls4 = cls3;
                        if (z2) {
                        }
                    } catch (Throwable th12) {
                        th = th12;
                        parseContext = parseContext7;
                    }
                }
            } catch (Throwable th13) {
                parseContext = parseContext7;
                obj3 = obj2;
                th = th13;
            }
        } catch (Throwable th14) {
            obj3 = obj2;
            th = th14;
        }
    }

    protected Enum scanEnum(JSONLexerBase jSONLexerBase, char[] cArr, ObjectDeserializer objectDeserializer) {
        EnumDeserializer enumDeserializer = objectDeserializer instanceof EnumDeserializer ? (EnumDeserializer) objectDeserializer : null;
        if (enumDeserializer == null) {
            jSONLexerBase.matchStat = -1;
            return null;
        }
        long scanEnumSymbol = jSONLexerBase.scanEnumSymbol(cArr);
        if (jSONLexerBase.matchStat > 0) {
            Enum enumByHashCode = enumDeserializer.getEnumByHashCode(scanEnumSymbol);
            if (enumByHashCode == null) {
                if (scanEnumSymbol == TypeUtils.fnv1a_64_magic_hashcode) {
                    return null;
                }
                if (jSONLexerBase.isEnabled(Feature.ErrorOnEnumNotMatch)) {
                    throw new JSONException("not match enum value, " + enumDeserializer.enumClass);
                }
            }
            return enumByHashCode;
        }
        return null;
    }

    public boolean parseField(DefaultJSONParser defaultJSONParser, String str, Object obj, Type type, Map<String, Object> map) {
        return parseField(defaultJSONParser, str, obj, type, map, null);
    }

    /* JADX WARN: Removed duplicated region for block: B:111:0x020f  */
    /* JADX WARN: Removed duplicated region for block: B:59:0x0125  */
    /* JADX WARN: Type inference failed for: r19v0 */
    /* JADX WARN: Type inference failed for: r19v1, types: [boolean, int] */
    /* JADX WARN: Type inference failed for: r19v3 */
    /* JADX WARN: Type inference failed for: r19v4 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean parseField(DefaultJSONParser defaultJSONParser, String str, Object obj, Type type, Map<String, Object> map, int[] iArr) {
        FieldDeserializer fieldDeserializer;
        FieldDeserializer fieldDeserializer2;
        JSONLexer jSONLexer;
        ?? r19;
        FieldDeserializer fieldDeserializer3;
        FieldDeserializer fieldDeserializer4;
        Field[] fieldArr;
        JSONLexer jSONLexer2 = defaultJSONParser.lexer;
        int i = Feature.DisableFieldSmartMatch.mask;
        int i2 = Feature.InitStringFieldAsEmpty.mask;
        if (jSONLexer2.isEnabled(i) || (i & this.beanInfo.parserFeatures) != 0) {
            fieldDeserializer = getFieldDeserializer(str);
        } else if (jSONLexer2.isEnabled(i2) || (this.beanInfo.parserFeatures & i2) != 0) {
            fieldDeserializer = smartMatch(str);
        } else {
            fieldDeserializer = smartMatch(str, iArr);
        }
        int i3 = Feature.SupportNonPublicField.mask;
        if (fieldDeserializer != null || (!jSONLexer2.isEnabled(i3) && (i3 & this.beanInfo.parserFeatures) == 0)) {
            fieldDeserializer2 = fieldDeserializer;
        } else {
            if (this.extraFieldDeserializers == null) {
                ConcurrentHashMap concurrentHashMap = new ConcurrentHashMap(1, 0.75f, 1);
                for (Class<?> cls = this.clazz; cls != null && cls != Object.class; cls = cls.getSuperclass()) {
                    Field[] declaredFields = cls.getDeclaredFields();
                    int length = declaredFields.length;
                    int i4 = 0;
                    while (i4 < length) {
                        Field field = declaredFields[i4];
                        String name = field.getName();
                        if (getFieldDeserializer(name) == null) {
                            int modifiers = field.getModifiers();
                            if ((modifiers & 16) == 0 && (modifiers & 8) == 0) {
                                fieldDeserializer4 = fieldDeserializer;
                                JSONField jSONField = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                                if (jSONField != null) {
                                    String name2 = jSONField.name();
                                    fieldArr = declaredFields;
                                    if (!"".equals(name2)) {
                                        name = name2;
                                    }
                                } else {
                                    fieldArr = declaredFields;
                                }
                                concurrentHashMap.put(name, field);
                                i4++;
                                fieldDeserializer = fieldDeserializer4;
                                declaredFields = fieldArr;
                            }
                        }
                        fieldDeserializer4 = fieldDeserializer;
                        fieldArr = declaredFields;
                        i4++;
                        fieldDeserializer = fieldDeserializer4;
                        declaredFields = fieldArr;
                    }
                }
                fieldDeserializer2 = fieldDeserializer;
                this.extraFieldDeserializers = concurrentHashMap;
            } else {
                fieldDeserializer2 = fieldDeserializer;
            }
            Object obj2 = this.extraFieldDeserializers.get(str);
            if (obj2 != null) {
                if (obj2 instanceof FieldDeserializer) {
                    fieldDeserializer3 = (FieldDeserializer) obj2;
                    jSONLexer = jSONLexer2;
                    r19 = 1;
                } else {
                    Field field2 = (Field) obj2;
                    field2.setAccessible(true);
                    r19 = 1;
                    jSONLexer = jSONLexer2;
                    fieldDeserializer3 = new DefaultFieldDeserializer(defaultJSONParser.getConfig(), this.clazz, new FieldInfo(str, field2.getDeclaringClass(), field2.getType(), field2.getGenericType(), field2, 0, 0, 0));
                    this.extraFieldDeserializers.put(str, fieldDeserializer3);
                }
                if (fieldDeserializer3 != null) {
                    if (!jSONLexer.isEnabled(Feature.IgnoreNotMatch)) {
                        throw new JSONException("setter not found, class " + this.clazz.getName() + ", property " + str);
                    }
                    int i5 = 0;
                    int i6 = -1;
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                        if (i5 >= fieldDeserializerArr.length) {
                            break;
                        }
                        FieldDeserializer fieldDeserializer5 = fieldDeserializerArr[i5];
                        FieldInfo fieldInfo = fieldDeserializer5.fieldInfo;
                        if (fieldInfo.unwrapped && (fieldDeserializer5 instanceof DefaultFieldDeserializer)) {
                            if (fieldInfo.field != null) {
                                DefaultFieldDeserializer defaultFieldDeserializer = (DefaultFieldDeserializer) fieldDeserializer5;
                                ObjectDeserializer fieldValueDeserilizer = defaultFieldDeserializer.getFieldValueDeserilizer(defaultJSONParser.getConfig());
                                if (fieldValueDeserilizer instanceof JavaBeanDeserializer) {
                                    FieldDeserializer fieldDeserializer6 = ((JavaBeanDeserializer) fieldValueDeserilizer).getFieldDeserializer(str);
                                    if (fieldDeserializer6 != null) {
                                        try {
                                            Object obj3 = fieldInfo.field.get(obj);
                                            if (obj3 == null) {
                                                obj3 = ((JavaBeanDeserializer) fieldValueDeserilizer).createInstance(defaultJSONParser, fieldInfo.fieldType);
                                                fieldDeserializer5.setValue(obj, obj3);
                                            }
                                            jSONLexer.nextTokenWithColon(defaultFieldDeserializer.getFastMatchToken());
                                            fieldDeserializer6.parseField(defaultJSONParser, obj3, type, map);
                                            i6 = i5;
                                        } catch (Exception e) {
                                            throw new JSONException("parse unwrapped field error.", e);
                                        }
                                    } else {
                                        continue;
                                    }
                                } else if (fieldValueDeserilizer instanceof MapDeserializer) {
                                    MapDeserializer mapDeserializer = (MapDeserializer) fieldValueDeserilizer;
                                    try {
                                        Map<Object, Object> map2 = (Map) fieldInfo.field.get(obj);
                                        if (map2 == null) {
                                            map2 = mapDeserializer.createMap(fieldInfo.fieldType);
                                            fieldDeserializer5.setValue(obj, map2);
                                        }
                                        jSONLexer.nextTokenWithColon();
                                        map2.put(str, defaultJSONParser.parse(str));
                                        i6 = i5;
                                    } catch (Exception e2) {
                                        throw new JSONException("parse unwrapped field error.", e2);
                                    }
                                } else {
                                    continue;
                                }
                            } else if (fieldInfo.method.getParameterTypes().length == 2) {
                                jSONLexer.nextTokenWithColon();
                                Object parse = defaultJSONParser.parse(str);
                                try {
                                    Method method = fieldInfo.method;
                                    Object[] objArr = new Object[2];
                                    objArr[0] = str;
                                    objArr[r19] = parse;
                                    method.invoke(obj, objArr);
                                    i6 = i5;
                                } catch (Exception e3) {
                                    throw new JSONException("parse unwrapped field error.", e3);
                                }
                            } else {
                                continue;
                            }
                        }
                        i5++;
                    }
                    if (i6 == -1) {
                        defaultJSONParser.parseExtra(obj, str);
                        return false;
                    }
                    if (iArr != null) {
                        int i7 = i6 / 32;
                        iArr[i7] = iArr[i7] | (r19 << (i6 % 32));
                    }
                    return r19;
                }
                JSONLexer jSONLexer3 = jSONLexer;
                int i8 = 0;
                while (true) {
                    FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                    if (i8 >= fieldDeserializerArr2.length) {
                        i8 = -1;
                        break;
                    } else if (fieldDeserializerArr2[i8] == fieldDeserializer3) {
                        break;
                    } else {
                        i8++;
                    }
                }
                if (i8 != -1 && iArr != null && str.startsWith("_") && isSetFlag(i8, iArr)) {
                    defaultJSONParser.parseExtra(obj, str);
                    return false;
                }
                jSONLexer3.nextTokenWithColon(fieldDeserializer3.getFastMatchToken());
                fieldDeserializer3.parseField(defaultJSONParser, obj, type, map);
                if (iArr != null) {
                    int i9 = i8 / 32;
                    iArr[i9] = iArr[i9] | (r19 << (i8 % 32));
                }
                return r19;
            }
        }
        jSONLexer = jSONLexer2;
        r19 = 1;
        fieldDeserializer3 = fieldDeserializer2;
        if (fieldDeserializer3 != null) {
        }
    }

    public FieldDeserializer smartMatch(String str) {
        return smartMatch(str, null);
    }

    public FieldDeserializer smartMatch(String str, int[] iArr) {
        boolean z;
        if (str == null) {
            return null;
        }
        FieldDeserializer fieldDeserializer = getFieldDeserializer(str, iArr);
        if (fieldDeserializer == null) {
            int i = 0;
            if (this.smartMatchHashArray == null) {
                long[] jArr = new long[this.sortedFieldDeserializers.length];
                int i2 = 0;
                while (true) {
                    FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                    if (i2 >= fieldDeserializerArr.length) {
                        break;
                    }
                    jArr[i2] = fieldDeserializerArr[i2].fieldInfo.nameHashCode;
                    i2++;
                }
                Arrays.sort(jArr);
                this.smartMatchHashArray = jArr;
            }
            int binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_lower(str));
            if (binarySearch < 0) {
                binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(str));
            }
            if (binarySearch < 0) {
                z = str.startsWith("is");
                if (z) {
                    binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(str.substring(2)));
                }
            } else {
                z = false;
            }
            if (binarySearch >= 0) {
                if (this.smartMatchHashArrayMapping == null) {
                    short[] sArr = new short[this.smartMatchHashArray.length];
                    Arrays.fill(sArr, (short) -1);
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                        if (i >= fieldDeserializerArr2.length) {
                            break;
                        }
                        int binarySearch2 = Arrays.binarySearch(this.smartMatchHashArray, fieldDeserializerArr2[i].fieldInfo.nameHashCode);
                        if (binarySearch2 >= 0) {
                            sArr[binarySearch2] = (short) i;
                        }
                        i++;
                    }
                    this.smartMatchHashArrayMapping = sArr;
                }
                short s = this.smartMatchHashArrayMapping[binarySearch];
                if (s != -1 && !isSetFlag(s, iArr)) {
                    fieldDeserializer = this.sortedFieldDeserializers[s];
                }
            }
            if (fieldDeserializer != null) {
                FieldInfo fieldInfo = fieldDeserializer.fieldInfo;
                if ((fieldInfo.parserFeatures & Feature.DisableFieldSmartMatch.mask) != 0) {
                    return null;
                }
                Class<?> cls = fieldInfo.fieldClass;
                if (z && cls != Boolean.TYPE && cls != Boolean.class) {
                    return null;
                }
            }
        }
        return fieldDeserializer;
    }

    private Object createFactoryInstance(ParserConfig parserConfig, Object obj) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        return this.beanInfo.factoryMethod.invoke(null, obj);
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x006b, code lost:
        if (com.alibaba.fastjson.JSONValidator.from(r6).validate() != false) goto L131;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x007f, code lost:
        if (r6.method != null) goto L124;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x0081, code lost:
        r9 = r7.getType();
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x0087, code lost:
        if (r9 != java.lang.Boolean.TYPE) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x008b, code lost:
        if (r4 != java.lang.Boolean.FALSE) goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x008d, code lost:
        r7.setBoolean(r0, false);
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x0093, code lost:
        if (r4 != java.lang.Boolean.TRUE) goto L117;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x0095, code lost:
        r7.setBoolean(r0, true);
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x009b, code lost:
        if (r9 != java.lang.Integer.TYPE) goto L27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x009f, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L110;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x00a1, code lost:
        r7.setInt(r0, ((java.lang.Number) r4).intValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x00ae, code lost:
        if (r9 != java.lang.Long.TYPE) goto L30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x00b2, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L103;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x00b4, code lost:
        r7.setLong(r0, ((java.lang.Number) r4).longValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x00c3, code lost:
        if (r9 != java.lang.Float.TYPE) goto L33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:50:0x00c7, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L86;
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x00c9, code lost:
        r7.setFloat(r0, ((java.lang.Number) r4).floatValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x00d6, code lost:
        if ((r4 instanceof java.lang.String) == false) goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:54:0x00d8, code lost:
        r4 = (java.lang.String) r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x00de, code lost:
        if (r4.length() > 10) goto L95;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x00e0, code lost:
        r4 = com.alibaba.fastjson.util.TypeUtils.parseFloat(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x00e5, code lost:
        r4 = java.lang.Float.parseFloat(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x00e9, code lost:
        r7.setFloat(r0, r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x00f0, code lost:
        if (r9 != java.lang.Double.TYPE) goto L36;
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x00f4, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L69;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x00f6, code lost:
        r7.setDouble(r0, ((java.lang.Number) r4).doubleValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x0103, code lost:
        if ((r4 instanceof java.lang.String) == false) goto L79;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x0105, code lost:
        r4 = (java.lang.String) r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x010b, code lost:
        if (r4.length() > 10) goto L78;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x010d, code lost:
        r4 = com.alibaba.fastjson.util.TypeUtils.parseDouble(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x0112, code lost:
        r4 = java.lang.Double.parseDouble(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0116, code lost:
        r7.setDouble(r0, r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x011b, code lost:
        if (r4 == null) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x0121, code lost:
        if (r8 != r4.getClass()) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x0123, code lost:
        r7.set(r0, r4);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public Object createInstance(Map<String, Object> map, ParserConfig parserConfig) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        boolean z;
        Integer num;
        Object cast;
        String jSONString;
        if (this.beanInfo.creatorConstructor == null && this.beanInfo.factoryMethod == null) {
            Object createInstance = createInstance((DefaultJSONParser) null, this.clazz);
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                Object value = entry.getValue();
                FieldDeserializer smartMatch = smartMatch(entry.getKey());
                if (smartMatch != null) {
                    FieldInfo fieldInfo = smartMatch.fieldInfo;
                    Field field = smartMatch.fieldInfo.field;
                    Type type = fieldInfo.fieldType;
                    Class<?> cls = fieldInfo.fieldClass;
                    JSONField annotation = fieldInfo.getAnnotation();
                    if (fieldInfo.declaringClass != null && (!cls.isInstance(value) || (annotation != null && annotation.deserializeUsing() != Void.class))) {
                        if (value instanceof String) {
                            jSONString = (String) value;
                        }
                        jSONString = JSON.toJSONString(value);
                        smartMatch.parseField(new DefaultJSONParser(jSONString), createInstance, type, null);
                    } else {
                        String str = fieldInfo.format;
                        if (str != null && type == Date.class) {
                            cast = TypeUtils.castToDate(value, str);
                        } else if (str != null && (type instanceof Class) && ((Class) type).getName().equals("java.time.LocalDateTime")) {
                            cast = Jdk8DateCodec.castToLocalDateTime(value, str);
                        } else if (type instanceof ParameterizedType) {
                            cast = TypeUtils.cast(value, (ParameterizedType) type, parserConfig);
                        } else {
                            cast = TypeUtils.cast(value, type, parserConfig);
                        }
                        smartMatch.setValue(createInstance, cast);
                    }
                }
            }
            if (this.beanInfo.buildMethod != null) {
                try {
                    return this.beanInfo.buildMethod.invoke(createInstance, null);
                } catch (Exception e) {
                    throw new JSONException("build object error", e);
                }
            }
            return createInstance;
        }
        FieldInfo[] fieldInfoArr = this.beanInfo.fields;
        int length = fieldInfoArr.length;
        Object[] objArr = new Object[length];
        HashMap hashMap = null;
        for (int i = 0; i < length; i++) {
            FieldInfo fieldInfo2 = fieldInfoArr[i];
            boolean z2 = map.get(fieldInfo2.name);
            if (z2 == null) {
                Class<?> cls2 = fieldInfo2.fieldClass;
                if (cls2 == Integer.TYPE) {
                    z2 = 0;
                } else if (cls2 == Long.TYPE) {
                    z2 = 0L;
                } else if (cls2 == Short.TYPE) {
                    z2 = (short) 0;
                } else if (cls2 == Byte.TYPE) {
                    z2 = (byte) 0;
                } else if (cls2 == Float.TYPE) {
                    z2 = Float.valueOf(0.0f);
                } else if (cls2 == Double.TYPE) {
                    z2 = Double.valueOf(0.0d);
                } else if (cls2 == Character.TYPE) {
                    z2 = '0';
                } else if (cls2 == Boolean.TYPE) {
                    z2 = false;
                }
                if (hashMap == null) {
                    hashMap = new HashMap();
                }
                hashMap.put(fieldInfo2.name, Integer.valueOf(i));
            }
            objArr[i] = z2;
        }
        if (hashMap != null) {
            for (Map.Entry<String, Object> entry2 : map.entrySet()) {
                Object value2 = entry2.getValue();
                FieldDeserializer smartMatch2 = smartMatch(entry2.getKey());
                if (smartMatch2 != null && (num = (Integer) hashMap.get(smartMatch2.fieldInfo.name)) != null) {
                    objArr[num.intValue()] = value2;
                }
            }
        }
        if (this.beanInfo.creatorConstructor != null) {
            if (this.beanInfo.f4kotlin) {
                z = false;
                for (int i2 = 0; i2 < length; i2++) {
                    Object obj = objArr[i2];
                    if (obj == null) {
                        if (this.beanInfo.fields != null && i2 < this.beanInfo.fields.length && this.beanInfo.fields[i2].fieldClass == String.class) {
                            z = true;
                        }
                    } else if (obj.getClass() != this.beanInfo.fields[i2].fieldClass) {
                        objArr[i2] = TypeUtils.cast(obj, (Class<Object>) this.beanInfo.fields[i2].fieldClass, parserConfig);
                    }
                }
            } else {
                z = false;
            }
            if (z && this.beanInfo.kotlinDefaultConstructor != null) {
                try {
                    Object newInstance = this.beanInfo.kotlinDefaultConstructor.newInstance(null);
                    for (int i3 = 0; i3 < length; i3++) {
                        Object obj2 = objArr[i3];
                        if (obj2 != null && this.beanInfo.fields != null && i3 < this.beanInfo.fields.length) {
                            this.beanInfo.fields[i3].set(newInstance, obj2);
                        }
                    }
                    return newInstance;
                } catch (Exception e2) {
                    throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e2);
                }
            }
            try {
                return this.beanInfo.creatorConstructor.newInstance(objArr);
            } catch (Exception e3) {
                throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e3);
            }
        } else if (this.beanInfo.factoryMethod != null) {
            try {
                return this.beanInfo.factoryMethod.invoke(null, objArr);
            } catch (Exception e4) {
                throw new JSONException("create factory method error, " + this.beanInfo.factoryMethod.toString(), e4);
            }
        } else {
            return null;
        }
    }

    public Type getFieldType(int i) {
        return this.sortedFieldDeserializers[i].fieldInfo.fieldType;
    }

    protected Object parseRest(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i) {
        return parseRest(defaultJSONParser, type, obj, obj2, i, new int[0]);
    }

    protected Object parseRest(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i, int[] iArr) {
        return deserialze(defaultJSONParser, type, obj, obj2, i, iArr);
    }

    protected static JavaBeanDeserializer getSeeAlso(ParserConfig parserConfig, JavaBeanInfo javaBeanInfo, String str) {
        if (javaBeanInfo.jsonType == null) {
            return null;
        }
        for (Class<?> cls : javaBeanInfo.jsonType.seeAlso()) {
            ObjectDeserializer deserializer = parserConfig.getDeserializer(cls);
            if (deserializer instanceof JavaBeanDeserializer) {
                JavaBeanDeserializer javaBeanDeserializer = (JavaBeanDeserializer) deserializer;
                JavaBeanInfo javaBeanInfo2 = javaBeanDeserializer.beanInfo;
                if (javaBeanInfo2.typeName.equals(str)) {
                    return javaBeanDeserializer;
                }
                JavaBeanDeserializer seeAlso = getSeeAlso(parserConfig, javaBeanInfo2, str);
                if (seeAlso != null) {
                    return seeAlso;
                }
            }
        }
        return null;
    }

    protected static void parseArray(Collection collection, ObjectDeserializer objectDeserializer, DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        JSONLexerBase jSONLexerBase = (JSONLexerBase) defaultJSONParser.lexer;
        int i = jSONLexerBase.token();
        if (i == 8) {
            jSONLexerBase.nextToken(16);
            jSONLexerBase.token();
            return;
        }
        if (i != 14) {
            defaultJSONParser.throwException(i);
        }
        if (jSONLexerBase.getCurrent() == '[') {
            jSONLexerBase.next();
            jSONLexerBase.setToken(14);
        } else {
            jSONLexerBase.nextToken(14);
        }
        if (jSONLexerBase.token() == 15) {
            jSONLexerBase.nextToken();
            return;
        }
        int i2 = 0;
        while (true) {
            collection.add(objectDeserializer.deserialze(defaultJSONParser, type, Integer.valueOf(i2)));
            i2++;
            if (jSONLexerBase.token() != 16) {
                break;
            } else if (jSONLexerBase.getCurrent() == '[') {
                jSONLexerBase.next();
                jSONLexerBase.setToken(14);
            } else {
                jSONLexerBase.nextToken(14);
            }
        }
        int i3 = jSONLexerBase.token();
        if (i3 != 15) {
            defaultJSONParser.throwException(i3);
        }
        if (jSONLexerBase.getCurrent() == ',') {
            jSONLexerBase.next();
            jSONLexerBase.setToken(16);
            return;
        }
        jSONLexerBase.nextToken(16);
    }
}
