package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.lang.reflect.WildcardType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
/* loaded from: classes.dex */
public class JavaBeanSerializer extends SerializeFilterable implements ObjectSerializer {
    protected final SerializeBeanInfo beanInfo;
    protected final FieldSerializer[] getters;
    private volatile transient long[] hashArray;
    private volatile transient short[] hashArrayMapping;
    protected final FieldSerializer[] sortedGetters;

    public JavaBeanSerializer(Class<?> cls) {
        this(cls, (Map<String, String>) null);
    }

    public JavaBeanSerializer(Class<?> cls, String... strArr) {
        this(cls, createAliasMap(strArr));
    }

    static Map<String, String> createAliasMap(String... strArr) {
        HashMap hashMap = new HashMap();
        for (String str : strArr) {
            hashMap.put(str, str);
        }
        return hashMap;
    }

    public JSONType getJSONType() {
        return this.beanInfo.jsonType;
    }

    public Class<?> getType() {
        return this.beanInfo.beanType;
    }

    public JavaBeanSerializer(Class<?> cls, Map<String, String> map) {
        this(TypeUtils.buildBeanInfo(cls, map, null));
    }

    public JavaBeanSerializer(SerializeBeanInfo serializeBeanInfo) {
        this.beanInfo = serializeBeanInfo;
        this.sortedGetters = new FieldSerializer[serializeBeanInfo.sortedFields.length];
        int i = 0;
        while (true) {
            FieldSerializer[] fieldSerializerArr = this.sortedGetters;
            if (i >= fieldSerializerArr.length) {
                break;
            }
            fieldSerializerArr[i] = new FieldSerializer(serializeBeanInfo.beanType, serializeBeanInfo.sortedFields[i]);
            i++;
        }
        if (serializeBeanInfo.fields == serializeBeanInfo.sortedFields) {
            this.getters = this.sortedGetters;
        } else {
            this.getters = new FieldSerializer[serializeBeanInfo.fields.length];
            int i2 = 0;
            while (true) {
                if (i2 >= this.getters.length) {
                    break;
                }
                FieldSerializer fieldSerializer = getFieldSerializer(serializeBeanInfo.fields[i2].name);
                if (fieldSerializer != null) {
                    this.getters[i2] = fieldSerializer;
                    i2++;
                } else {
                    FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                    System.arraycopy(fieldSerializerArr2, 0, this.getters, 0, fieldSerializerArr2.length);
                    break;
                }
            }
        }
        if (serializeBeanInfo.jsonType != null) {
            for (Class<? extends SerializeFilter> cls : serializeBeanInfo.jsonType.serialzeFilters()) {
                try {
                    addFilter(cls.getConstructor(null).newInstance(null));
                } catch (Exception unused) {
                }
            }
        }
    }

    public void writeDirectNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    public void writeAsArray(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    public void writeAsArrayNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i, false);
    }

    public void writeNoneASM(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i, false);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0102, code lost:
        if (r13.fieldTransient != false) goto L55;
     */
    /* JADX WARN: Removed duplicated region for block: B:102:0x015d  */
    /* JADX WARN: Removed duplicated region for block: B:103:0x0163  */
    /* JADX WARN: Removed duplicated region for block: B:299:0x03f2 A[Catch: Exception -> 0x039e, all -> 0x0508, TryCatch #3 {all -> 0x0508, blocks: (B:271:0x0398, B:330:0x0468, B:332:0x046c, B:334:0x0470, B:337:0x0479, B:339:0x0481, B:340:0x0489, B:342:0x048f, B:278:0x03ac, B:279:0x03af, B:281:0x03b5, B:283:0x03c1, B:290:0x03d6, B:295:0x03e0, B:299:0x03f2, B:302:0x03fc, B:305:0x0406, B:307:0x040e, B:308:0x041b, B:310:0x0424, B:312:0x042b, B:313:0x042f, B:315:0x0436, B:316:0x043a, B:317:0x043e, B:319:0x0443, B:320:0x0447, B:321:0x044b, B:323:0x044f, B:325:0x0453, B:328:0x0461, B:329:0x0465, B:296:0x03ea, B:350:0x04a6, B:375:0x04f9, B:377:0x0501, B:383:0x050e), top: B:434:0x0398 }] */
    /* JADX WARN: Removed duplicated region for block: B:329:0x0465 A[Catch: Exception -> 0x039e, all -> 0x0508, TryCatch #3 {all -> 0x0508, blocks: (B:271:0x0398, B:330:0x0468, B:332:0x046c, B:334:0x0470, B:337:0x0479, B:339:0x0481, B:340:0x0489, B:342:0x048f, B:278:0x03ac, B:279:0x03af, B:281:0x03b5, B:283:0x03c1, B:290:0x03d6, B:295:0x03e0, B:299:0x03f2, B:302:0x03fc, B:305:0x0406, B:307:0x040e, B:308:0x041b, B:310:0x0424, B:312:0x042b, B:313:0x042f, B:315:0x0436, B:316:0x043a, B:317:0x043e, B:319:0x0443, B:320:0x0447, B:321:0x044b, B:323:0x044f, B:325:0x0453, B:328:0x0461, B:329:0x0465, B:296:0x03ea, B:350:0x04a6, B:375:0x04f9, B:377:0x0501, B:383:0x050e), top: B:434:0x0398 }] */
    /* JADX WARN: Removed duplicated region for block: B:332:0x046c A[Catch: Exception -> 0x039e, all -> 0x0508, TryCatch #3 {all -> 0x0508, blocks: (B:271:0x0398, B:330:0x0468, B:332:0x046c, B:334:0x0470, B:337:0x0479, B:339:0x0481, B:340:0x0489, B:342:0x048f, B:278:0x03ac, B:279:0x03af, B:281:0x03b5, B:283:0x03c1, B:290:0x03d6, B:295:0x03e0, B:299:0x03f2, B:302:0x03fc, B:305:0x0406, B:307:0x040e, B:308:0x041b, B:310:0x0424, B:312:0x042b, B:313:0x042f, B:315:0x0436, B:316:0x043a, B:317:0x043e, B:319:0x0443, B:320:0x0447, B:321:0x044b, B:323:0x044f, B:325:0x0453, B:328:0x0461, B:329:0x0465, B:296:0x03ea, B:350:0x04a6, B:375:0x04f9, B:377:0x0501, B:383:0x050e), top: B:434:0x0398 }] */
    /* JADX WARN: Removed duplicated region for block: B:336:0x0478  */
    /* JADX WARN: Removed duplicated region for block: B:337:0x0479 A[Catch: Exception -> 0x039e, all -> 0x0508, TryCatch #3 {all -> 0x0508, blocks: (B:271:0x0398, B:330:0x0468, B:332:0x046c, B:334:0x0470, B:337:0x0479, B:339:0x0481, B:340:0x0489, B:342:0x048f, B:278:0x03ac, B:279:0x03af, B:281:0x03b5, B:283:0x03c1, B:290:0x03d6, B:295:0x03e0, B:299:0x03f2, B:302:0x03fc, B:305:0x0406, B:307:0x040e, B:308:0x041b, B:310:0x0424, B:312:0x042b, B:313:0x042f, B:315:0x0436, B:316:0x043a, B:317:0x043e, B:319:0x0443, B:320:0x0447, B:321:0x044b, B:323:0x044f, B:325:0x0453, B:328:0x0461, B:329:0x0465, B:296:0x03ea, B:350:0x04a6, B:375:0x04f9, B:377:0x0501, B:383:0x050e), top: B:434:0x0398 }] */
    /* JADX WARN: Removed duplicated region for block: B:372:0x04f0  */
    /* JADX WARN: Removed duplicated region for block: B:383:0x050e A[Catch: all -> 0x0508, Exception -> 0x050a, TRY_LEAVE, TryCatch #1 {Exception -> 0x050a, blocks: (B:375:0x04f9, B:377:0x0501, B:383:0x050e), top: B:430:0x04f9 }] */
    /* JADX WARN: Removed duplicated region for block: B:405:0x055e A[Catch: all -> 0x05df, TRY_ENTER, TryCatch #18 {all -> 0x05df, blocks: (B:402:0x053c, B:405:0x055e, B:413:0x05ae, B:415:0x05b4, B:416:0x05cc, B:418:0x05d0, B:422:0x05d9, B:423:0x05de, B:407:0x0573, B:409:0x0577, B:411:0x057d, B:412:0x0598), top: B:450:0x053c }] */
    /* JADX WARN: Removed duplicated region for block: B:406:0x0571  */
    /* JADX WARN: Removed duplicated region for block: B:415:0x05b4 A[Catch: all -> 0x05df, TryCatch #18 {all -> 0x05df, blocks: (B:402:0x053c, B:405:0x055e, B:413:0x05ae, B:415:0x05b4, B:416:0x05cc, B:418:0x05d0, B:422:0x05d9, B:423:0x05de, B:407:0x0573, B:409:0x0577, B:411:0x057d, B:412:0x0598), top: B:450:0x053c }] */
    /* JADX WARN: Removed duplicated region for block: B:418:0x05d0 A[Catch: all -> 0x05df, TryCatch #18 {all -> 0x05df, blocks: (B:402:0x053c, B:405:0x055e, B:413:0x05ae, B:415:0x05b4, B:416:0x05cc, B:418:0x05d0, B:422:0x05d9, B:423:0x05de, B:407:0x0573, B:409:0x0577, B:411:0x057d, B:412:0x0598), top: B:450:0x053c }] */
    /* JADX WARN: Removed duplicated region for block: B:420:0x05d6  */
    /* JADX WARN: Removed duplicated region for block: B:421:0x05d7  */
    /* JADX WARN: Removed duplicated region for block: B:430:0x04f9 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:435:0x00d7 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:450:0x053c A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x00c0  */
    /* JADX WARN: Removed duplicated region for block: B:56:0x00c2  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i, boolean z) throws IOException {
        FieldSerializer[] fieldSerializerArr;
        JSONSerializer jSONSerializer2;
        Exception exc;
        SerialContext serialContext;
        Object obj3;
        FieldSerializer fieldSerializer;
        Throwable th;
        Throwable th2;
        FieldInfo fieldInfo;
        int i2;
        char c;
        char c2;
        boolean z2;
        int i3;
        FieldSerializer fieldSerializer2;
        SerialContext serialContext2;
        FieldSerializer[] fieldSerializerArr2;
        FieldSerializer fieldSerializer3;
        Field field;
        FieldInfo fieldInfo2;
        String str;
        FieldSerializer[] fieldSerializerArr3;
        Class<?> cls;
        char c3;
        boolean z3;
        Object propertyValueDirect;
        char c4;
        Map map;
        Class<?> cls2;
        JSONSerializer jSONSerializer3 = jSONSerializer;
        Object obj4 = obj;
        Type type2 = type;
        SerializeWriter serializeWriter = jSONSerializer3.out;
        if (obj4 == null) {
            serializeWriter.writeNull();
        } else if (!writeReference(jSONSerializer3, obj4, i)) {
            if (serializeWriter.sortField) {
                fieldSerializerArr = this.sortedGetters;
            } else {
                fieldSerializerArr = this.getters;
            }
            FieldSerializer[] fieldSerializerArr4 = fieldSerializerArr;
            SerialContext serialContext3 = jSONSerializer3.context;
            if (!this.beanInfo.beanType.isEnum()) {
                jSONSerializer.setContext(serialContext3, obj, obj2, this.beanInfo.features, i);
            }
            boolean isWriteAsArray = isWriteAsArray(jSONSerializer3, i);
            char c5 = isWriteAsArray ? Operators.ARRAY_START : Operators.BLOCK_START;
            char c6 = isWriteAsArray ? Operators.ARRAY_END : Operators.BLOCK_END;
            if (!z) {
                try {
                    try {
                        serializeWriter.append(c5);
                    } catch (Exception e) {
                        exc = e;
                        serialContext = serialContext3;
                        jSONSerializer2 = jSONSerializer3;
                        obj3 = obj4;
                        fieldSerializer = null;
                        String str2 = "write javaBean error, fastjson version 1.2.83";
                        if (obj3 != null) {
                        }
                        if (obj2 == null) {
                        }
                        if (exc.getMessage() != null) {
                        }
                        if (exc instanceof InvocationTargetException) {
                        }
                        throw new JSONException(str2, r17 != null ? exc : r17);
                    }
                } catch (Throwable th3) {
                    th = th3;
                    serialContext = serialContext3;
                    jSONSerializer2 = jSONSerializer3;
                    jSONSerializer2.context = serialContext;
                    throw th;
                }
            }
            try {
                try {
                    if (fieldSerializerArr4.length > 0 && serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                        jSONSerializer.incrementIndent();
                        jSONSerializer.println();
                    }
                    i2 = this.beanInfo.features & SerializerFeature.WriteClassName.mask;
                    c = Operators.ARRAY_SEPRATOR;
                } catch (Exception e2) {
                    serialContext = serialContext3;
                    jSONSerializer2 = jSONSerializer3;
                    obj3 = obj4;
                    exc = e2;
                    fieldSerializer = null;
                    String str22 = "write javaBean error, fastjson version 1.2.83";
                    if (obj3 != null) {
                        try {
                            str22 = "write javaBean error, fastjson version 1.2.83, class " + obj.getClass().getName();
                        } catch (Throwable th4) {
                            th2 = th4;
                            th = th2;
                            jSONSerializer2.context = serialContext;
                            throw th;
                        }
                    }
                    if (obj2 == null) {
                        str22 = str22 + ", fieldName : " + obj2;
                    } else if (fieldSerializer != null && fieldSerializer.fieldInfo != null) {
                        str22 = fieldSerializer.fieldInfo.method != null ? str22 + ", method : " + fieldInfo.method.getName() : str22 + ", fieldName : " + fieldSerializer.fieldInfo.name;
                    }
                    if (exc.getMessage() != null) {
                        str22 = str22 + ", " + exc.getMessage();
                    }
                    Throwable cause = exc instanceof InvocationTargetException ? exc.getCause() : null;
                    throw new JSONException(str22, cause != null ? exc : cause);
                }
            } catch (Throwable th5) {
                th2 = th5;
                serialContext = serialContext3;
                jSONSerializer2 = jSONSerializer3;
            }
            try {
                if (i2 != 0 || (SerializerFeature.WriteClassName.mask & i) != 0 || jSONSerializer3.isWriteClassName(type2, obj4)) {
                    Class<?> cls3 = obj.getClass();
                    if (cls3 != ((cls3 == type2 || !(type2 instanceof WildcardType)) ? type2 : TypeUtils.getClass(type))) {
                        writeClassName(jSONSerializer3, this.beanInfo.typeKey, obj4);
                        c2 = Operators.ARRAY_SEPRATOR;
                        boolean isEnabled = serializeWriter.isEnabled(SerializerFeature.WriteClassName);
                        boolean z4 = writeBefore(jSONSerializer3, obj4, c2) != ',';
                        boolean isEnabled2 = serializeWriter.isEnabled(SerializerFeature.SkipTransientField);
                        boolean isEnabled3 = serializeWriter.isEnabled(SerializerFeature.IgnoreNonFieldGetter);
                        z2 = z4;
                        FieldSerializer fieldSerializer4 = null;
                        i3 = 0;
                        while (i3 < fieldSerializerArr4.length) {
                            try {
                                try {
                                    try {
                                        fieldSerializer3 = fieldSerializerArr4[i3];
                                        field = fieldSerializer3.fieldInfo.field;
                                        fieldInfo2 = fieldSerializer3.fieldInfo;
                                        str = fieldInfo2.name;
                                        fieldSerializerArr3 = fieldSerializerArr4;
                                        cls = fieldInfo2.fieldClass;
                                        fieldSerializer2 = fieldSerializer4;
                                    } catch (Throwable th6) {
                                        th = th6;
                                        serialContext2 = serialContext3;
                                        jSONSerializer2 = jSONSerializer3;
                                    }
                                } catch (Exception e3) {
                                    e = e3;
                                    fieldSerializer2 = fieldSerializer4;
                                }
                            } catch (Exception e4) {
                                e = e4;
                                fieldSerializer2 = fieldSerializer4;
                                serialContext = serialContext3;
                                jSONSerializer2 = jSONSerializer3;
                                obj3 = obj4;
                            }
                            try {
                                int i4 = i3;
                                boolean isEnabled4 = SerializerFeature.isEnabled(serializeWriter.features, fieldInfo2.serialzeFeatures, SerializerFeature.UseSingleQuotes);
                                boolean z5 = serializeWriter.quoteFieldNames && !isEnabled4;
                                if (isEnabled2) {
                                    try {
                                    } catch (Exception e5) {
                                        exc = e5;
                                        serialContext = serialContext3;
                                        jSONSerializer2 = jSONSerializer3;
                                        obj3 = obj4;
                                        fieldSerializer = fieldSerializer2;
                                        String str222 = "write javaBean error, fastjson version 1.2.83";
                                        if (obj3 != null) {
                                        }
                                        if (obj2 == null) {
                                        }
                                        if (exc.getMessage() != null) {
                                        }
                                        if (exc instanceof InvocationTargetException) {
                                        }
                                        throw new JSONException(str222, cause != null ? exc : cause);
                                    }
                                }
                                if (!isEnabled3 || field != null) {
                                    if (applyName(jSONSerializer3, obj4, str) && applyLabel(jSONSerializer3, fieldInfo2.label)) {
                                        z3 = false;
                                    } else {
                                        z3 = isWriteAsArray ? true : true;
                                    }
                                    if (!str.equals(this.beanInfo.typeKey) || !jSONSerializer3.isWriteClassName(type2, obj4)) {
                                        if (!z3) {
                                            try {
                                                propertyValueDirect = fieldSerializer3.getPropertyValueDirect(obj4);
                                            } catch (InvocationTargetException e6) {
                                                try {
                                                    if (!serializeWriter.isEnabled(SerializerFeature.IgnoreErrorGetter)) {
                                                        fieldSerializer = fieldSerializer3;
                                                        serialContext2 = serialContext3;
                                                        jSONSerializer2 = jSONSerializer3;
                                                        try {
                                                            throw e6;
                                                        } catch (Exception e7) {
                                                            e = e7;
                                                            obj3 = obj;
                                                            exc = e;
                                                            serialContext = serialContext2;
                                                            String str2222 = "write javaBean error, fastjson version 1.2.83";
                                                            if (obj3 != null) {
                                                            }
                                                            if (obj2 == null) {
                                                            }
                                                            if (exc.getMessage() != null) {
                                                            }
                                                            if (exc instanceof InvocationTargetException) {
                                                            }
                                                            throw new JSONException(str2222, cause != null ? exc : cause);
                                                        }
                                                    }
                                                    fieldSerializer2 = fieldSerializer3;
                                                } catch (Exception e8) {
                                                    e = e8;
                                                    fieldSerializer = fieldSerializer3;
                                                    serialContext2 = serialContext3;
                                                    jSONSerializer2 = jSONSerializer3;
                                                }
                                            }
                                            if (apply(jSONSerializer3, obj4, str, propertyValueDirect)) {
                                                c3 = c6;
                                                serialContext2 = serialContext3;
                                                jSONSerializer2 = jSONSerializer3;
                                            } else {
                                                String str3 = propertyValueDirect;
                                                if (cls == String.class) {
                                                    str3 = propertyValueDirect;
                                                    str3 = propertyValueDirect;
                                                    if (AbsoluteConst.XML_TRIM.equals(fieldInfo2.format) && propertyValueDirect != null) {
                                                        str3 = ((String) propertyValueDirect).trim();
                                                    }
                                                }
                                                Object obj5 = str3;
                                                String processKey = processKey(jSONSerializer3, obj4, str, obj5);
                                                c3 = c6;
                                                serialContext2 = serialContext3;
                                                try {
                                                    Object processValue = processValue(jSONSerializer, fieldSerializer3.fieldContext, obj, str, obj5, i);
                                                    if (processValue == null) {
                                                        int i5 = fieldInfo2.serialzeFeatures;
                                                        JSONField annotation = fieldInfo2.getAnnotation();
                                                        if (this.beanInfo.jsonType != null) {
                                                            i5 |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                        }
                                                        if (annotation != null && !"".equals(annotation.defaultValue())) {
                                                            processValue = annotation.defaultValue();
                                                        } else if (cls == Boolean.class) {
                                                            int i6 = SerializerFeature.WriteNullBooleanAsFalse.mask;
                                                            int i7 = SerializerFeature.WriteMapNullValue.mask | i6;
                                                            if (!isWriteAsArray && (i5 & i7) == 0 && (i7 & serializeWriter.features) == 0) {
                                                                jSONSerializer2 = jSONSerializer;
                                                            } else if ((i5 & i6) != 0) {
                                                                processValue = false;
                                                            } else if ((i6 & serializeWriter.features) != 0 && (i5 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                processValue = false;
                                                            }
                                                        } else if (cls == String.class) {
                                                            int i8 = SerializerFeature.WriteNullStringAsEmpty.mask;
                                                            int i9 = SerializerFeature.WriteMapNullValue.mask | i8;
                                                            if (!isWriteAsArray && (i5 & i9) == 0 && (i9 & serializeWriter.features) == 0) {
                                                                jSONSerializer2 = jSONSerializer;
                                                            } else {
                                                                if ((i5 & i8) == 0) {
                                                                    if ((i8 & serializeWriter.features) != 0 && (i5 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                    }
                                                                }
                                                                processValue = "";
                                                            }
                                                        } else if (Number.class.isAssignableFrom(cls)) {
                                                            int i10 = SerializerFeature.WriteNullNumberAsZero.mask;
                                                            int i11 = SerializerFeature.WriteMapNullValue.mask | i10;
                                                            if (!isWriteAsArray && (i5 & i11) == 0 && (i11 & serializeWriter.features) == 0) {
                                                                jSONSerializer2 = jSONSerializer;
                                                            } else if ((i5 & i10) != 0) {
                                                                processValue = 0;
                                                            } else if ((i10 & serializeWriter.features) != 0 && (i5 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                processValue = 0;
                                                            }
                                                        } else if (Collection.class.isAssignableFrom(cls)) {
                                                            int i12 = SerializerFeature.WriteNullListAsEmpty.mask;
                                                            int i13 = SerializerFeature.WriteMapNullValue.mask | i12;
                                                            if (!isWriteAsArray && (i5 & i13) == 0 && (i13 & serializeWriter.features) == 0) {
                                                                jSONSerializer2 = jSONSerializer;
                                                            } else if ((i5 & i12) != 0) {
                                                                processValue = Collections.emptyList();
                                                            } else if ((i12 & serializeWriter.features) != 0 && (i5 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                processValue = Collections.emptyList();
                                                            }
                                                        } else if (!isWriteAsArray && !fieldSerializer3.writeNull && !serializeWriter.isEnabled(SerializerFeature.WriteMapNullValue.mask) && (i5 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                            jSONSerializer2 = jSONSerializer;
                                                        }
                                                    }
                                                    if (processValue == null || ((!serializeWriter.notWriteDefaultValue && (fieldInfo2.serialzeFeatures & SerializerFeature.NotWriteDefaultValue.mask) == 0 && (this.beanInfo.features & SerializerFeature.NotWriteDefaultValue.mask) == 0) || (((cls2 = fieldInfo2.fieldClass) != Byte.TYPE || !(processValue instanceof Byte) || ((Byte) processValue).byteValue() != 0) && ((cls2 != Short.TYPE || !(processValue instanceof Short) || ((Short) processValue).shortValue() != 0) && ((cls2 != Integer.TYPE || !(processValue instanceof Integer) || ((Integer) processValue).intValue() != 0) && ((cls2 != Long.TYPE || !(processValue instanceof Long) || ((Long) processValue).longValue() != 0) && ((cls2 != Float.TYPE || !(processValue instanceof Float) || ((Float) processValue).floatValue() != 0.0f) && ((cls2 != Double.TYPE || !(processValue instanceof Double) || ((Double) processValue).doubleValue() != 0.0d) && (cls2 != Boolean.TYPE || !(processValue instanceof Boolean) || ((Boolean) processValue).booleanValue()))))))))) {
                                                        if (z2) {
                                                            if (!fieldInfo2.unwrapped || !(processValue instanceof Map) || ((Map) processValue).size() != 0) {
                                                                serializeWriter.write(44);
                                                                if (serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                                                                    jSONSerializer.println();
                                                                }
                                                            }
                                                        }
                                                        if (processKey != str) {
                                                            if (!isWriteAsArray) {
                                                                serializeWriter.writeFieldName(processKey, true);
                                                            }
                                                            jSONSerializer2 = jSONSerializer;
                                                            c = Operators.ARRAY_SEPRATOR;
                                                            try {
                                                                try {
                                                                    jSONSerializer2.write(processValue);
                                                                } catch (Throwable th7) {
                                                                    th = th7;
                                                                    th = th;
                                                                    serialContext = serialContext2;
                                                                    jSONSerializer2.context = serialContext;
                                                                    throw th;
                                                                }
                                                            } catch (Exception e9) {
                                                                e = e9;
                                                                obj3 = obj;
                                                                exc = e;
                                                                fieldSerializer = fieldSerializer2;
                                                                serialContext = serialContext2;
                                                                String str22222 = "write javaBean error, fastjson version 1.2.83";
                                                                if (obj3 != null) {
                                                                }
                                                                if (obj2 == null) {
                                                                }
                                                                if (exc.getMessage() != null) {
                                                                }
                                                                if (exc instanceof InvocationTargetException) {
                                                                }
                                                                throw new JSONException(str22222, cause != null ? exc : cause);
                                                            }
                                                        } else {
                                                            jSONSerializer2 = jSONSerializer;
                                                            c = Operators.ARRAY_SEPRATOR;
                                                            if (obj5 != processValue) {
                                                                if (!isWriteAsArray) {
                                                                    fieldSerializer3.writePrefix(jSONSerializer2);
                                                                }
                                                                jSONSerializer2.write(processValue);
                                                            } else {
                                                                if (!isWriteAsArray) {
                                                                    boolean isAssignableFrom = Map.class.isAssignableFrom(cls);
                                                                    boolean z6 = !(cls.isPrimitive() || cls.getName().startsWith("java.")) || cls == Object.class;
                                                                    if (isEnabled || !fieldInfo2.unwrapped || (!isAssignableFrom && !z6)) {
                                                                        if (z5) {
                                                                            c4 = 0;
                                                                            serializeWriter.write(fieldInfo2.name_chars, 0, fieldInfo2.name_chars.length);
                                                                        } else {
                                                                            c4 = 0;
                                                                            fieldSerializer3.writePrefix(jSONSerializer2);
                                                                        }
                                                                        if (isWriteAsArray) {
                                                                            JSONField annotation2 = fieldInfo2.getAnnotation();
                                                                            if (cls == String.class && (annotation2 == null || annotation2.serializeUsing() == Void.class)) {
                                                                                if (processValue == null) {
                                                                                    int i14 = fieldSerializer3.features;
                                                                                    if (this.beanInfo.jsonType != null) {
                                                                                        i14 |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                                                    }
                                                                                    if ((serializeWriter.features & SerializerFeature.WriteNullStringAsEmpty.mask) != 0 && (SerializerFeature.WriteMapNullValue.mask & i14) == 0) {
                                                                                        serializeWriter.writeString("");
                                                                                    } else if ((i14 & SerializerFeature.WriteNullStringAsEmpty.mask) != 0) {
                                                                                        serializeWriter.writeString("");
                                                                                    } else {
                                                                                        serializeWriter.writeNull();
                                                                                    }
                                                                                } else {
                                                                                    String str4 = (String) processValue;
                                                                                    if (isEnabled4) {
                                                                                        serializeWriter.writeStringWithSingleQuote(str4);
                                                                                    } else {
                                                                                        serializeWriter.writeStringWithDoubleQuote(str4, c4);
                                                                                    }
                                                                                }
                                                                            } else if (fieldInfo2.unwrapped && (processValue instanceof Map) && ((Map) processValue).size() == 0) {
                                                                                fieldSerializer4 = fieldSerializer2;
                                                                                z2 = false;
                                                                                i3 = i4 + 1;
                                                                                obj4 = obj;
                                                                                type2 = type;
                                                                                jSONSerializer3 = jSONSerializer2;
                                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                                c6 = c3;
                                                                                serialContext3 = serialContext2;
                                                                            } else {
                                                                                fieldSerializer3.writeValue(jSONSerializer2, processValue);
                                                                            }
                                                                        } else {
                                                                            fieldSerializer3.writeValue(jSONSerializer2, processValue);
                                                                        }
                                                                        if (fieldInfo2.unwrapped && (processValue instanceof Map)) {
                                                                            map = (Map) processValue;
                                                                            if (map.size() != 0) {
                                                                                if (!jSONSerializer2.isEnabled(SerializerFeature.WriteMapNullValue)) {
                                                                                    for (Object obj6 : map.values()) {
                                                                                        if (obj6 != null) {
                                                                                        }
                                                                                    }
                                                                                }
                                                                            }
                                                                            fieldSerializer4 = fieldSerializer2;
                                                                            i3 = i4 + 1;
                                                                            obj4 = obj;
                                                                            type2 = type;
                                                                            jSONSerializer3 = jSONSerializer2;
                                                                            fieldSerializerArr4 = fieldSerializerArr3;
                                                                            c6 = c3;
                                                                            serialContext3 = serialContext2;
                                                                        }
                                                                        fieldSerializer4 = fieldSerializer2;
                                                                        z2 = true;
                                                                        i3 = i4 + 1;
                                                                        obj4 = obj;
                                                                        type2 = type;
                                                                        jSONSerializer3 = jSONSerializer2;
                                                                        fieldSerializerArr4 = fieldSerializerArr3;
                                                                        c6 = c3;
                                                                        serialContext3 = serialContext2;
                                                                    }
                                                                }
                                                                c4 = 0;
                                                                if (isWriteAsArray) {
                                                                }
                                                                if (fieldInfo2.unwrapped) {
                                                                    map = (Map) processValue;
                                                                    if (map.size() != 0) {
                                                                    }
                                                                    fieldSerializer4 = fieldSerializer2;
                                                                    i3 = i4 + 1;
                                                                    obj4 = obj;
                                                                    type2 = type;
                                                                    jSONSerializer3 = jSONSerializer2;
                                                                    fieldSerializerArr4 = fieldSerializerArr3;
                                                                    c6 = c3;
                                                                    serialContext3 = serialContext2;
                                                                }
                                                                fieldSerializer4 = fieldSerializer2;
                                                                z2 = true;
                                                                i3 = i4 + 1;
                                                                obj4 = obj;
                                                                type2 = type;
                                                                jSONSerializer3 = jSONSerializer2;
                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                c6 = c3;
                                                                serialContext3 = serialContext2;
                                                            }
                                                        }
                                                        if (fieldInfo2.unwrapped) {
                                                        }
                                                        fieldSerializer4 = fieldSerializer2;
                                                        z2 = true;
                                                        i3 = i4 + 1;
                                                        obj4 = obj;
                                                        type2 = type;
                                                        jSONSerializer3 = jSONSerializer2;
                                                        fieldSerializerArr4 = fieldSerializerArr3;
                                                        c6 = c3;
                                                        serialContext3 = serialContext2;
                                                    }
                                                    jSONSerializer2 = jSONSerializer;
                                                } catch (Exception e10) {
                                                    e = e10;
                                                    jSONSerializer2 = jSONSerializer;
                                                } catch (Throwable th8) {
                                                    th = th8;
                                                    jSONSerializer2 = jSONSerializer;
                                                }
                                            }
                                            c = Operators.ARRAY_SEPRATOR;
                                            fieldSerializer4 = fieldSerializer2;
                                            i3 = i4 + 1;
                                            obj4 = obj;
                                            type2 = type;
                                            jSONSerializer3 = jSONSerializer2;
                                            fieldSerializerArr4 = fieldSerializerArr3;
                                            c6 = c3;
                                            serialContext3 = serialContext2;
                                        }
                                        propertyValueDirect = null;
                                        if (apply(jSONSerializer3, obj4, str, propertyValueDirect)) {
                                        }
                                        c = Operators.ARRAY_SEPRATOR;
                                        fieldSerializer4 = fieldSerializer2;
                                        i3 = i4 + 1;
                                        obj4 = obj;
                                        type2 = type;
                                        jSONSerializer3 = jSONSerializer2;
                                        fieldSerializerArr4 = fieldSerializerArr3;
                                        c6 = c3;
                                        serialContext3 = serialContext2;
                                    }
                                }
                                c3 = c6;
                                serialContext2 = serialContext3;
                                jSONSerializer2 = jSONSerializer3;
                                c = Operators.ARRAY_SEPRATOR;
                                fieldSerializer4 = fieldSerializer2;
                                i3 = i4 + 1;
                                obj4 = obj;
                                type2 = type;
                                jSONSerializer3 = jSONSerializer2;
                                fieldSerializerArr4 = fieldSerializerArr3;
                                c6 = c3;
                                serialContext3 = serialContext2;
                            } catch (Exception e11) {
                                e = e11;
                                serialContext2 = serialContext3;
                                jSONSerializer2 = jSONSerializer3;
                                obj3 = obj;
                                exc = e;
                                fieldSerializer = fieldSerializer2;
                                serialContext = serialContext2;
                                String str222222 = "write javaBean error, fastjson version 1.2.83";
                                if (obj3 != null) {
                                }
                                if (obj2 == null) {
                                }
                                if (exc.getMessage() != null) {
                                }
                                if (exc instanceof InvocationTargetException) {
                                }
                                throw new JSONException(str222222, cause != null ? exc : cause);
                            }
                        }
                        fieldSerializer2 = fieldSerializer4;
                        char c7 = c6;
                        serialContext2 = serialContext3;
                        jSONSerializer2 = jSONSerializer3;
                        fieldSerializerArr2 = fieldSerializerArr4;
                        obj3 = obj;
                        if (!z2) {
                            c = 0;
                        }
                        writeAfter(jSONSerializer2, obj3, c);
                        if (fieldSerializerArr2.length > 0) {
                            try {
                                if (serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                                    jSONSerializer.decrementIdent();
                                    jSONSerializer.println();
                                }
                            } catch (Exception e12) {
                                e = e12;
                                exc = e;
                                fieldSerializer = fieldSerializer2;
                                serialContext = serialContext2;
                                String str2222222 = "write javaBean error, fastjson version 1.2.83";
                                if (obj3 != null) {
                                }
                                if (obj2 == null) {
                                }
                                if (exc.getMessage() != null) {
                                }
                                if (exc instanceof InvocationTargetException) {
                                }
                                throw new JSONException(str2222222, cause != null ? exc : cause);
                            }
                        }
                        if (!z) {
                            serializeWriter.append(c7);
                        }
                        jSONSerializer2.context = serialContext2;
                        return;
                    }
                }
                writeAfter(jSONSerializer2, obj3, c);
                if (fieldSerializerArr2.length > 0) {
                }
                if (!z) {
                }
                jSONSerializer2.context = serialContext2;
                return;
            } catch (Exception e13) {
                e = e13;
                serialContext = serialContext2;
                exc = e;
                fieldSerializer = fieldSerializer2;
                String str22222222 = "write javaBean error, fastjson version 1.2.83";
                if (obj3 != null) {
                }
                if (obj2 == null) {
                }
                if (exc.getMessage() != null) {
                }
                if (exc instanceof InvocationTargetException) {
                }
                throw new JSONException(str22222222, cause != null ? exc : cause);
            } catch (Throwable th9) {
                th2 = th9;
                serialContext = serialContext2;
                th = th2;
                jSONSerializer2.context = serialContext;
                throw th;
            }
            c2 = 0;
            boolean isEnabled5 = serializeWriter.isEnabled(SerializerFeature.WriteClassName);
            if (writeBefore(jSONSerializer3, obj4, c2) != ',') {
            }
            boolean isEnabled22 = serializeWriter.isEnabled(SerializerFeature.SkipTransientField);
            boolean isEnabled32 = serializeWriter.isEnabled(SerializerFeature.IgnoreNonFieldGetter);
            z2 = z4;
            FieldSerializer fieldSerializer42 = null;
            i3 = 0;
            while (i3 < fieldSerializerArr4.length) {
            }
            fieldSerializer2 = fieldSerializer42;
            char c72 = c6;
            serialContext2 = serialContext3;
            jSONSerializer2 = jSONSerializer3;
            fieldSerializerArr2 = fieldSerializerArr4;
            obj3 = obj;
            if (!z2) {
            }
        }
    }

    protected void writeClassName(JSONSerializer jSONSerializer, String str, Object obj) {
        if (str == null) {
            str = jSONSerializer.config.typeKey;
        }
        jSONSerializer.out.writeFieldName(str, false);
        String str2 = this.beanInfo.typeName;
        if (str2 == null) {
            Class<?> cls = obj.getClass();
            if (TypeUtils.isProxy(cls)) {
                cls = cls.getSuperclass();
            }
            str2 = cls.getName();
        }
        jSONSerializer.write(str2);
    }

    public boolean writeReference(JSONSerializer jSONSerializer, Object obj, int i) {
        SerialContext serialContext = jSONSerializer.context;
        int i2 = SerializerFeature.DisableCircularReferenceDetect.mask;
        if (serialContext != null && (serialContext.features & i2) == 0 && (i & i2) == 0 && jSONSerializer.references != null && jSONSerializer.references.containsKey(obj)) {
            jSONSerializer.writeReference(obj);
            return true;
        }
        return false;
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer) {
        return isWriteAsArray(jSONSerializer, 0);
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer, int i) {
        int i2 = SerializerFeature.BeanToArray.mask;
        return ((this.beanInfo.features & i2) == 0 && !jSONSerializer.out.beanToArray && (i & i2) == 0) ? false : true;
    }

    public Object getFieldValue(Object obj, String str) {
        FieldSerializer fieldSerializer = getFieldSerializer(str);
        if (fieldSerializer == null) {
            throw new JSONException("field not found. " + str);
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e) {
            throw new JSONException("getFieldValue error." + str, e);
        } catch (InvocationTargetException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        }
    }

    public Object getFieldValue(Object obj, String str, long j, boolean z) {
        FieldSerializer fieldSerializer = getFieldSerializer(j);
        if (fieldSerializer == null) {
            if (z) {
                throw new JSONException("field not found. " + str);
            }
            return null;
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e) {
            throw new JSONException("getFieldValue error." + str, e);
        } catch (InvocationTargetException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        }
    }

    public FieldSerializer getFieldSerializer(String str) {
        if (str == null) {
            return null;
        }
        int length = this.sortedGetters.length - 1;
        int i = 0;
        while (i <= length) {
            int i2 = (i + length) >>> 1;
            int compareTo = this.sortedGetters[i2].fieldInfo.name.compareTo(str);
            if (compareTo < 0) {
                i = i2 + 1;
            } else if (compareTo <= 0) {
                return this.sortedGetters[i2];
            } else {
                length = i2 - 1;
            }
        }
        return null;
    }

    public FieldSerializer getFieldSerializer(long j) {
        PropertyNamingStrategy[] propertyNamingStrategyArr;
        int binarySearch;
        if (this.hashArray == null) {
            propertyNamingStrategyArr = PropertyNamingStrategy.values();
            long[] jArr = new long[this.sortedGetters.length * propertyNamingStrategyArr.length];
            int i = 0;
            int i2 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr = this.sortedGetters;
                if (i >= fieldSerializerArr.length) {
                    break;
                }
                String str = fieldSerializerArr[i].fieldInfo.name;
                jArr[i2] = TypeUtils.fnv1a_64(str);
                i2++;
                for (PropertyNamingStrategy propertyNamingStrategy : propertyNamingStrategyArr) {
                    String translate = propertyNamingStrategy.translate(str);
                    if (!str.equals(translate)) {
                        jArr[i2] = TypeUtils.fnv1a_64(translate);
                        i2++;
                    }
                }
                i++;
            }
            Arrays.sort(jArr, 0, i2);
            this.hashArray = new long[i2];
            System.arraycopy(jArr, 0, this.hashArray, 0, i2);
        } else {
            propertyNamingStrategyArr = null;
        }
        int binarySearch2 = Arrays.binarySearch(this.hashArray, j);
        if (binarySearch2 < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            if (propertyNamingStrategyArr == null) {
                propertyNamingStrategyArr = PropertyNamingStrategy.values();
            }
            short[] sArr = new short[this.hashArray.length];
            Arrays.fill(sArr, (short) -1);
            int i3 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                if (i3 >= fieldSerializerArr2.length) {
                    break;
                }
                String str2 = fieldSerializerArr2[i3].fieldInfo.name;
                int binarySearch3 = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(str2));
                if (binarySearch3 >= 0) {
                    sArr[binarySearch3] = (short) i3;
                }
                for (PropertyNamingStrategy propertyNamingStrategy2 : propertyNamingStrategyArr) {
                    String translate2 = propertyNamingStrategy2.translate(str2);
                    if (!str2.equals(translate2) && (binarySearch = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(translate2))) >= 0) {
                        sArr[binarySearch] = (short) i3;
                    }
                }
                i3++;
            }
            this.hashArrayMapping = sArr;
        }
        short s = this.hashArrayMapping[binarySearch2];
        if (s != -1) {
            return this.sortedGetters[s];
        }
        return null;
    }

    public List<Object> getFieldValues(Object obj) throws Exception {
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            arrayList.add(fieldSerializer.getPropertyValue(obj));
        }
        return arrayList;
    }

    public List<Object> getObjectFieldValues(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            Class<?> cls = fieldSerializer.fieldInfo.fieldClass;
            if (!cls.isPrimitive() && !cls.getName().startsWith("java.lang.")) {
                arrayList.add(fieldSerializer.getPropertyValue(obj));
            }
        }
        return arrayList;
    }

    public int getSize(Object obj) throws Exception {
        int i = 0;
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                i++;
            }
        }
        return i;
    }

    public Set<String> getFieldNames(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        HashSet hashSet = new HashSet();
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                hashSet.add(fieldSerializer.fieldInfo.name);
            }
        }
        return hashSet;
    }

    public Map<String, Object> getFieldValuesMap(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        LinkedHashMap linkedHashMap = new LinkedHashMap(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            boolean isEnabled = SerializerFeature.isEnabled(fieldSerializer.features, SerializerFeature.SkipTransientField);
            FieldInfo fieldInfo = fieldSerializer.fieldInfo;
            if (!isEnabled || fieldInfo == null || !fieldInfo.fieldTransient) {
                if (fieldSerializer.fieldInfo.unwrapped) {
                    Object json = JSON.toJSON(fieldSerializer.getPropertyValue(obj));
                    if (json instanceof Map) {
                        linkedHashMap.putAll((Map) json);
                    } else {
                        linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                    }
                } else {
                    linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                }
            }
        }
        return linkedHashMap;
    }

    protected BeanContext getBeanContext(int i) {
        return this.sortedGetters[i].fieldContext;
    }

    protected Type getFieldType(int i) {
        return this.sortedGetters[i].fieldInfo.fieldType;
    }

    protected char writeBefore(JSONSerializer jSONSerializer, Object obj, char c) {
        if (jSONSerializer.beforeFilters != null) {
            for (BeforeFilter beforeFilter : jSONSerializer.beforeFilters) {
                c = beforeFilter.writeBefore(jSONSerializer, obj, c);
            }
        }
        if (this.beforeFilters != null) {
            for (BeforeFilter beforeFilter2 : this.beforeFilters) {
                c = beforeFilter2.writeBefore(jSONSerializer, obj, c);
            }
        }
        return c;
    }

    protected char writeAfter(JSONSerializer jSONSerializer, Object obj, char c) {
        if (jSONSerializer.afterFilters != null) {
            for (AfterFilter afterFilter : jSONSerializer.afterFilters) {
                c = afterFilter.writeAfter(jSONSerializer, obj, c);
            }
        }
        if (this.afterFilters != null) {
            for (AfterFilter afterFilter2 : this.afterFilters) {
                c = afterFilter2.writeAfter(jSONSerializer, obj, c);
            }
        }
        return c;
    }

    protected boolean applyLabel(JSONSerializer jSONSerializer, String str) {
        if (jSONSerializer.labelFilters != null) {
            for (LabelFilter labelFilter : jSONSerializer.labelFilters) {
                if (!labelFilter.apply(str)) {
                    return false;
                }
            }
        }
        if (this.labelFilters != null) {
            for (LabelFilter labelFilter2 : this.labelFilters) {
                if (!labelFilter2.apply(str)) {
                    return false;
                }
            }
            return true;
        }
        return true;
    }
}
