package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONCreator;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONPOJOBuilder;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IApp;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
/* loaded from: classes.dex */
public class JavaBeanInfo {
    public final Method buildMethod;
    public final Class<?> builderClass;
    public final Class<?> clazz;
    public final Constructor<?> creatorConstructor;
    public Type[] creatorConstructorParameterTypes;
    public String[] creatorConstructorParameters;
    public final Constructor<?> defaultConstructor;
    public final int defaultConstructorParameterSize;
    public final Method factoryMethod;
    public final FieldInfo[] fields;
    public final JSONType jsonType;

    /* renamed from: kotlin  reason: collision with root package name */
    public boolean f4kotlin;
    public Constructor<?> kotlinDefaultConstructor;
    public String[] orders;
    public final int parserFeatures;
    public final FieldInfo[] sortedFields;
    public final String typeKey;
    public final String typeName;

    public JavaBeanInfo(Class<?> cls, Class<?> cls2, Constructor<?> constructor, Constructor<?> constructor2, Method method, Method method2, JSONType jSONType, List<FieldInfo> list) {
        JSONField jSONField;
        String[] strArr;
        this.clazz = cls;
        this.builderClass = cls2;
        this.defaultConstructor = constructor;
        this.creatorConstructor = constructor2;
        this.factoryMethod = method;
        this.parserFeatures = TypeUtils.getParserFeatures(cls);
        this.buildMethod = method2;
        this.jsonType = jSONType;
        if (jSONType != null) {
            String typeName = jSONType.typeName();
            String typeKey = jSONType.typeKey();
            this.typeKey = typeKey.length() <= 0 ? null : typeKey;
            if (typeName.length() != 0) {
                this.typeName = typeName;
            } else {
                this.typeName = cls.getName();
            }
            String[] orders = jSONType.orders();
            this.orders = orders.length == 0 ? null : orders;
        } else {
            this.typeName = cls.getName();
            this.typeKey = null;
            this.orders = null;
        }
        FieldInfo[] fieldInfoArr = new FieldInfo[list.size()];
        this.fields = fieldInfoArr;
        list.toArray(fieldInfoArr);
        FieldInfo[] fieldInfoArr2 = new FieldInfo[fieldInfoArr.length];
        int i = 0;
        if (this.orders != null) {
            LinkedHashMap linkedHashMap = new LinkedHashMap(list.size());
            for (FieldInfo fieldInfo : fieldInfoArr) {
                linkedHashMap.put(fieldInfo.name, fieldInfo);
            }
            int i2 = 0;
            for (String str : this.orders) {
                FieldInfo fieldInfo2 = (FieldInfo) linkedHashMap.get(str);
                if (fieldInfo2 != null) {
                    fieldInfoArr2[i2] = fieldInfo2;
                    linkedHashMap.remove(str);
                    i2++;
                }
            }
            for (FieldInfo fieldInfo3 : linkedHashMap.values()) {
                fieldInfoArr2[i2] = fieldInfo3;
                i2++;
            }
        } else {
            System.arraycopy(fieldInfoArr, 0, fieldInfoArr2, 0, fieldInfoArr.length);
            Arrays.sort(fieldInfoArr2);
        }
        this.sortedFields = Arrays.equals(this.fields, fieldInfoArr2) ? this.fields : fieldInfoArr2;
        if (constructor != null) {
            this.defaultConstructorParameterSize = constructor.getParameterTypes().length;
        } else if (method != null) {
            this.defaultConstructorParameterSize = method.getParameterTypes().length;
        } else {
            this.defaultConstructorParameterSize = 0;
        }
        if (constructor2 != null) {
            this.creatorConstructorParameterTypes = constructor2.getParameterTypes();
            boolean isKotlin = TypeUtils.isKotlin(cls);
            this.f4kotlin = isKotlin;
            if (isKotlin) {
                this.creatorConstructorParameters = TypeUtils.getKoltinConstructorParameters(cls);
                try {
                    this.kotlinDefaultConstructor = cls.getConstructor(null);
                } catch (Throwable unused) {
                }
                Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor2);
                for (int i3 = 0; i3 < this.creatorConstructorParameters.length && i3 < parameterAnnotations.length; i3++) {
                    Annotation[] annotationArr = parameterAnnotations[i3];
                    int length = annotationArr.length;
                    int i4 = 0;
                    while (true) {
                        if (i4 >= length) {
                            jSONField = null;
                            break;
                        }
                        Annotation annotation = annotationArr[i4];
                        if (annotation instanceof JSONField) {
                            jSONField = (JSONField) annotation;
                            break;
                        }
                        i4++;
                    }
                    if (jSONField != null) {
                        String name = jSONField.name();
                        if (name.length() > 0) {
                            this.creatorConstructorParameters[i3] = name;
                        }
                    }
                }
                return;
            }
            if (this.creatorConstructorParameterTypes.length == this.fields.length) {
                while (true) {
                    Type[] typeArr = this.creatorConstructorParameterTypes;
                    if (i >= typeArr.length) {
                        return;
                    }
                    if (typeArr[i] != this.fields[i].fieldClass) {
                        break;
                    }
                    i++;
                }
            }
            this.creatorConstructorParameters = ASMUtils.lookupParameterNames(constructor2);
        }
    }

    private static FieldInfo getField(List<FieldInfo> list, String str) {
        for (FieldInfo fieldInfo : list) {
            if (fieldInfo.name.equals(str)) {
                return fieldInfo;
            }
            Field field = fieldInfo.field;
            if (field != null && fieldInfo.getAnnotation() != null && field.getName().equals(str)) {
                return fieldInfo;
            }
        }
        return null;
    }

    static boolean add(List<FieldInfo> list, FieldInfo fieldInfo) {
        for (int size = list.size() - 1; size >= 0; size--) {
            FieldInfo fieldInfo2 = list.get(size);
            if (fieldInfo2.name.equals(fieldInfo.name) && (!fieldInfo2.getOnly || fieldInfo.getOnly)) {
                if (fieldInfo2.fieldClass.isAssignableFrom(fieldInfo.fieldClass)) {
                    list.set(size, fieldInfo);
                    return true;
                } else if (fieldInfo2.compareTo(fieldInfo) < 0) {
                    list.set(size, fieldInfo);
                    return true;
                } else {
                    return false;
                }
            }
        }
        list.add(fieldInfo);
        return true;
    }

    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy) {
        return build(cls, type, propertyNamingStrategy, false, TypeUtils.compatibleWithJavaBean, false);
    }

    private static Map<TypeVariable, Type> buildGenericInfo(Class<?> cls) {
        Class<? super Object> superclass = cls.getSuperclass();
        HashMap hashMap = null;
        if (superclass == null) {
            return null;
        }
        while (true) {
            Class<? super Object> cls2 = superclass;
            Class<?> cls3 = cls;
            cls = cls2;
            if (cls == null || cls == Object.class) {
                break;
            }
            if (cls3.getGenericSuperclass() instanceof ParameterizedType) {
                Type[] actualTypeArguments = ((ParameterizedType) cls3.getGenericSuperclass()).getActualTypeArguments();
                TypeVariable<Class<?>>[] typeParameters = cls.getTypeParameters();
                for (int i = 0; i < actualTypeArguments.length; i++) {
                    if (hashMap == null) {
                        hashMap = new HashMap();
                    }
                    if (hashMap.containsKey(actualTypeArguments[i])) {
                        hashMap.put(typeParameters[i], hashMap.get(actualTypeArguments[i]));
                    } else {
                        hashMap.put(typeParameters[i], actualTypeArguments[i]);
                    }
                }
            }
            superclass = cls.getSuperclass();
        }
        return hashMap;
    }

    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean z, boolean z2) {
        return build(cls, type, propertyNamingStrategy, z, z2, false);
    }

    /* JADX WARN: Code restructure failed: missing block: B:337:0x06ec, code lost:
        if (r0.length() < 4) goto L182;
     */
    /* JADX WARN: Code restructure failed: missing block: B:394:0x081c, code lost:
        if (r3 == null) goto L251;
     */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:124:0x0258  */
    /* JADX WARN: Removed duplicated region for block: B:303:0x061f  */
    /* JADX WARN: Removed duplicated region for block: B:405:0x085a  */
    /* JADX WARN: Removed duplicated region for block: B:412:0x0889  */
    /* JADX WARN: Removed duplicated region for block: B:423:0x090d  */
    /* JADX WARN: Removed duplicated region for block: B:426:0x0922  */
    /* JADX WARN: Removed duplicated region for block: B:431:0x0971  */
    /* JADX WARN: Removed duplicated region for block: B:487:0x0aab  */
    /* JADX WARN: Removed duplicated region for block: B:48:0x00bf  */
    /* JADX WARN: Removed duplicated region for block: B:515:0x0952 A[EDGE_INSN: B:515:0x0952->B:429:0x0952 ?: BREAK  , SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:91:0x01a6  */
    /* JADX WARN: Type inference failed for: r10v11 */
    /* JADX WARN: Type inference failed for: r10v12, types: [com.alibaba.fastjson.annotation.JSONField] */
    /* JADX WARN: Type inference failed for: r7v20, types: [java.util.List, java.util.ArrayList] */
    /* JADX WARN: Type inference failed for: r7v6 */
    /* JADX WARN: Type inference failed for: r7v7, types: [java.util.List] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean z, boolean z2, boolean z3) {
        Constructor<?> defaultConstructor;
        Constructor<?> constructor;
        ArrayList arrayList;
        PropertyNamingStrategy propertyNamingStrategy2;
        Method[] methodArr;
        Constructor<?> constructor2;
        String str;
        Field[] fieldArr;
        Class<?> cls2;
        JSONType jSONType;
        PropertyNamingStrategy propertyNamingStrategy3;
        Method[] methodArr2;
        Field field;
        int length;
        int i;
        String str2;
        int i2;
        int length2;
        int i3;
        JSONField jSONField;
        String propertyNameByMethodName;
        Field[] fieldArr2;
        Field field2;
        Field[] fieldArr3;
        int i4;
        String str3;
        int i5;
        Method[] methodArr3;
        int i6;
        int i7;
        Field field3;
        ?? r7;
        int i8;
        Class<?> cls3;
        Field[] fieldArr4;
        String propertyNameByMethodName2;
        Field field4;
        Field[] fieldArr5;
        String str4;
        Class<?> cls4;
        Method[] methodArr4;
        int i9;
        int i10;
        JSONField jSONField2;
        PropertyNamingStrategy propertyNamingStrategy4;
        PropertyNamingStrategy propertyNamingStrategy5;
        Field field5;
        int i11;
        int i12;
        Method[] methodArr5;
        String str5;
        String str6;
        Field[] fieldArr6;
        Class<?> cls5;
        JSONType jSONType2;
        PropertyNamingStrategy propertyNamingStrategy6;
        int i13;
        Method[] methodArr6;
        int i14;
        int i15;
        int i16;
        String str7;
        StringBuilder sb;
        String str8;
        String str9;
        char charAt;
        Constructor<?> constructor3;
        String[] strArr;
        String[] lookupParameterNames;
        JSONField jSONField3;
        int of;
        int i17;
        int i18;
        JSONField jSONField4;
        String str10;
        int i19;
        int i20;
        int i21;
        String str11;
        String[] strArr2;
        JSONField jSONField5;
        Field field6;
        String str12;
        int i22;
        int i23;
        int i24;
        Field field7;
        Field field8;
        String[] strArr3;
        Constructor<?> creatorConstructor;
        PropertyNamingStrategy naming;
        Class<?> cls6 = cls;
        boolean z4 = z3;
        JSONType jSONType3 = (JSONType) TypeUtils.getAnnotation(cls6, JSONType.class);
        PropertyNamingStrategy propertyNamingStrategy7 = (jSONType3 == null || (naming = jSONType3.naming()) == null || naming == PropertyNamingStrategy.CamelCase) ? propertyNamingStrategy : naming;
        Class<?> builderClass = getBuilderClass(cls6, jSONType3);
        Field[] declaredFields = cls.getDeclaredFields();
        Method[] methods = cls.getMethods();
        Map<TypeVariable, Type> buildGenericInfo = buildGenericInfo(cls);
        boolean isKotlin = TypeUtils.isKotlin(cls);
        Constructor<?>[] declaredConstructors = cls.getDeclaredConstructors();
        if (!isKotlin || declaredConstructors.length == 1) {
            if (builderClass == null) {
                defaultConstructor = getDefaultConstructor(cls6, declaredConstructors);
            } else {
                defaultConstructor = getDefaultConstructor(builderClass, builderClass.getDeclaredConstructors());
            }
            constructor = defaultConstructor;
        } else {
            constructor = null;
        }
        ArrayList arrayList2 = new ArrayList();
        Method method = null;
        Method method2 = null;
        if (z) {
            for (Class<?> cls7 = cls6; cls7 != null; cls7 = cls7.getSuperclass()) {
                computeFields(cls6, type, propertyNamingStrategy7, arrayList2, cls7.getDeclaredFields());
            }
            if (constructor != null) {
                TypeUtils.setAccessible(constructor);
            }
            return new JavaBeanInfo(cls, builderClass, constructor, null, null, null, jSONType3, arrayList2);
        }
        boolean z5 = cls.isInterface() || Modifier.isAbstract(cls.getModifiers());
        if ((constructor == null && builderClass == null) || z5) {
            Type mixInAnnotations = JSON.getMixInAnnotations(cls);
            if ((mixInAnnotations instanceof Class) && (creatorConstructor = getCreatorConstructor(((Class) mixInAnnotations).getConstructors())) != null) {
                try {
                    constructor3 = cls6.getConstructor(creatorConstructor.getParameterTypes());
                } catch (NoSuchMethodException unused) {
                }
                if (constructor3 == null) {
                    constructor3 = getCreatorConstructor(declaredConstructors);
                }
                constructor2 = constructor3;
                if (constructor2 == null && !z5) {
                    TypeUtils.setAccessible(constructor2);
                    Class<?>[] parameterTypes = constructor2.getParameterTypes();
                    if (parameterTypes.length > 0) {
                        String[] strArr4 = null;
                        int i25 = 0;
                        for (Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor2); i25 < parameterTypes.length && i25 < parameterAnnotations.length; parameterAnnotations = parameterAnnotations) {
                            Annotation[] annotationArr = parameterAnnotations[i25];
                            int length3 = annotationArr.length;
                            int i26 = 0;
                            while (true) {
                                if (i26 >= length3) {
                                    jSONField5 = null;
                                    break;
                                }
                                Annotation annotation = annotationArr[i26];
                                Annotation[] annotationArr2 = annotationArr;
                                if (annotation instanceof JSONField) {
                                    jSONField5 = (JSONField) annotation;
                                    break;
                                }
                                i26++;
                                annotationArr = annotationArr2;
                            }
                            Class<?> cls8 = parameterTypes[i25];
                            Type type2 = constructor2.getGenericParameterTypes()[i25];
                            if (jSONField5 != null) {
                                field6 = TypeUtils.getField(cls6, jSONField5.name(), declaredFields);
                                i22 = jSONField5.ordinal();
                                i23 = SerializerFeature.of(jSONField5.serialzeFeatures());
                                i24 = Feature.of(jSONField5.parseFeatures());
                                str12 = jSONField5.name();
                            } else {
                                field6 = null;
                                str12 = null;
                                i22 = 0;
                                i23 = 0;
                                i24 = 0;
                            }
                            if (str12 == null || str12.length() == 0) {
                                if (strArr4 == null) {
                                    strArr4 = ASMUtils.lookupParameterNames(constructor2);
                                }
                                str12 = strArr4[i25];
                            }
                            if (field6 == null) {
                                if (strArr4 == null) {
                                    if (isKotlin) {
                                        strArr4 = TypeUtils.getKoltinConstructorParameters(cls);
                                    } else {
                                        strArr4 = ASMUtils.lookupParameterNames(constructor2);
                                    }
                                }
                                field7 = field6;
                                if (strArr4.length > i25) {
                                    strArr3 = strArr4;
                                    field8 = TypeUtils.getField(cls6, strArr4[i25], declaredFields);
                                    ArrayList arrayList3 = arrayList2;
                                    add(arrayList3, new FieldInfo(str12, cls, cls8, type2, field8, i22, i23, i24));
                                    i25++;
                                    parameterTypes = parameterTypes;
                                    methods = methods;
                                    arrayList2 = arrayList3;
                                    propertyNamingStrategy7 = propertyNamingStrategy7;
                                    strArr4 = strArr3;
                                }
                            } else {
                                field7 = field6;
                            }
                            field8 = field7;
                            strArr3 = strArr4;
                            ArrayList arrayList32 = arrayList2;
                            add(arrayList32, new FieldInfo(str12, cls, cls8, type2, field8, i22, i23, i24));
                            i25++;
                            parameterTypes = parameterTypes;
                            methods = methods;
                            arrayList2 = arrayList32;
                            propertyNamingStrategy7 = propertyNamingStrategy7;
                            strArr4 = strArr3;
                        }
                    }
                    arrayList = arrayList2;
                    propertyNamingStrategy2 = propertyNamingStrategy7;
                    methodArr = methods;
                } else {
                    arrayList = arrayList2;
                    propertyNamingStrategy2 = propertyNamingStrategy7;
                    methodArr = methods;
                    method2 = getFactoryMethod(cls6, methodArr, z4);
                    if (method2 == null) {
                        TypeUtils.setAccessible(method2);
                        Class<?>[] parameterTypes2 = method2.getParameterTypes();
                        if (parameterTypes2.length > 0) {
                            Annotation[][] parameterAnnotations2 = TypeUtils.getParameterAnnotations(method2);
                            String[] strArr5 = null;
                            int i27 = 0;
                            while (i27 < parameterTypes2.length) {
                                Annotation[] annotationArr3 = parameterAnnotations2[i27];
                                int length4 = annotationArr3.length;
                                int i28 = 0;
                                while (true) {
                                    if (i28 >= length4) {
                                        jSONField4 = null;
                                        break;
                                    }
                                    Annotation annotation2 = annotationArr3[i28];
                                    if (annotation2 instanceof JSONField) {
                                        jSONField4 = (JSONField) annotation2;
                                        break;
                                    }
                                    i28++;
                                }
                                if (jSONField4 == null && (!z4 || !TypeUtils.isJacksonCreator(method2))) {
                                    throw new JSONException("illegal json creator");
                                }
                                if (jSONField4 != null) {
                                    str10 = jSONField4.name();
                                    int ordinal = jSONField4.ordinal();
                                    int of2 = SerializerFeature.of(jSONField4.serialzeFeatures());
                                    i21 = Feature.of(jSONField4.parseFeatures());
                                    i19 = ordinal;
                                    i20 = of2;
                                } else {
                                    str10 = null;
                                    i19 = 0;
                                    i20 = 0;
                                    i21 = 0;
                                }
                                if (str10 == null || str10.length() == 0) {
                                    if (strArr5 == null) {
                                        strArr5 = ASMUtils.lookupParameterNames(method2);
                                    }
                                    str11 = strArr5[i27];
                                    strArr2 = strArr5;
                                } else {
                                    strArr2 = strArr5;
                                    str11 = str10;
                                }
                                add(arrayList, new FieldInfo(str11, cls, parameterTypes2[i27], method2.getGenericParameterTypes()[i27], TypeUtils.getField(cls6, str11, declaredFields), i19, i20, i21));
                                i27++;
                                z4 = z3;
                                parameterTypes2 = parameterTypes2;
                                strArr5 = strArr2;
                            }
                            return new JavaBeanInfo(cls, builderClass, null, null, method2, null, jSONType3, arrayList);
                        }
                    } else if (!z5) {
                        String name = cls.getName();
                        if (isKotlin && declaredConstructors.length > 0) {
                            String[] koltinConstructorParameters = TypeUtils.getKoltinConstructorParameters(cls);
                            Constructor<?> kotlinConstructor = TypeUtils.getKotlinConstructor(declaredConstructors, koltinConstructorParameters);
                            TypeUtils.setAccessible(kotlinConstructor);
                            constructor2 = kotlinConstructor;
                            strArr = koltinConstructorParameters;
                        } else {
                            int length5 = declaredConstructors.length;
                            int i29 = 0;
                            strArr = null;
                            while (true) {
                                if (i29 >= length5) {
                                    break;
                                }
                                Constructor<?> constructor4 = declaredConstructors[i29];
                                Class<?>[] parameterTypes3 = constructor4.getParameterTypes();
                                if (name.equals("org.springframework.security.web.authentication.WebAuthenticationDetails")) {
                                    if (parameterTypes3.length == 2 && parameterTypes3[0] == String.class && parameterTypes3[1] == String.class) {
                                        constructor4.setAccessible(true);
                                        strArr = ASMUtils.lookupParameterNames(constructor4);
                                        constructor2 = constructor4;
                                        break;
                                    }
                                } else if (name.equals("org.springframework.security.web.authentication.preauth.PreAuthenticatedAuthenticationToken")) {
                                    if (parameterTypes3.length == 3 && parameterTypes3[0] == Object.class && parameterTypes3[1] == Object.class && parameterTypes3[2] == Collection.class) {
                                        constructor4.setAccessible(true);
                                        strArr = new String[]{"principal", "credentials", "authorities"};
                                        constructor2 = constructor4;
                                        break;
                                    }
                                } else {
                                    if (name.equals("org.springframework.security.core.authority.SimpleGrantedAuthority")) {
                                        if (parameterTypes3.length == 1 && parameterTypes3[0] == String.class) {
                                            strArr = new String[]{IApp.ConfigProperty.CONFIG_AUTHORITY};
                                            constructor2 = constructor4;
                                            break;
                                        }
                                    } else if (((constructor4.getModifiers() & 1) != 0) && (lookupParameterNames = ASMUtils.lookupParameterNames(constructor4)) != null && lookupParameterNames.length != 0 && (constructor2 == null || strArr == null || lookupParameterNames.length > strArr.length)) {
                                        constructor2 = constructor4;
                                        strArr = lookupParameterNames;
                                    }
                                    i29++;
                                }
                                i29++;
                            }
                        }
                        Class<?>[] parameterTypes4 = strArr != null ? constructor2.getParameterTypes() : null;
                        if (strArr != null && parameterTypes4.length == strArr.length) {
                            Annotation[][] parameterAnnotations3 = TypeUtils.getParameterAnnotations(constructor2);
                            int i30 = 0;
                            while (i30 < parameterTypes4.length) {
                                Annotation[] annotationArr4 = parameterAnnotations3[i30];
                                String str13 = strArr[i30];
                                int length6 = annotationArr4.length;
                                int i31 = 0;
                                while (true) {
                                    if (i31 >= length6) {
                                        jSONField3 = null;
                                        break;
                                    }
                                    Annotation annotation3 = annotationArr4[i31];
                                    if (annotation3 instanceof JSONField) {
                                        jSONField3 = (JSONField) annotation3;
                                        break;
                                    }
                                    i31++;
                                }
                                Class<?> cls9 = parameterTypes4[i30];
                                Type type3 = constructor2.getGenericParameterTypes()[i30];
                                Field field9 = TypeUtils.getField(cls6, str13, declaredFields);
                                if (field9 != null && jSONField3 == null) {
                                    jSONField3 = (JSONField) TypeUtils.getAnnotation(field9, JSONField.class);
                                }
                                if (jSONField3 == null) {
                                    if ("org.springframework.security.core.userdetails.User".equals(name) && Constants.Value.PASSWORD.equals(str13)) {
                                        of = Feature.InitStringFieldAsEmpty.mask;
                                        i18 = 0;
                                        i17 = 0;
                                    } else {
                                        i18 = 0;
                                        i17 = 0;
                                        of = 0;
                                    }
                                } else {
                                    String name2 = jSONField3.name();
                                    if (name2.length() != 0) {
                                        str13 = name2;
                                    }
                                    int ordinal2 = jSONField3.ordinal();
                                    int of3 = SerializerFeature.of(jSONField3.serialzeFeatures());
                                    of = Feature.of(jSONField3.parseFeatures());
                                    i17 = of3;
                                    i18 = ordinal2;
                                }
                                add(arrayList, new FieldInfo(str13, cls, cls9, type3, field9, i18, i17, of));
                                i30++;
                                name = name;
                                strArr = strArr;
                                parameterTypes4 = parameterTypes4;
                            }
                            if (!isKotlin && !cls.getName().equals("javax.servlet.http.Cookie")) {
                                return new JavaBeanInfo(cls, builderClass, null, constructor2, null, null, jSONType3, arrayList);
                            }
                        } else {
                            throw new JSONException("default constructor not found. " + cls6);
                        }
                    }
                }
            }
            constructor3 = null;
            if (constructor3 == null) {
            }
            constructor2 = constructor3;
            if (constructor2 == null) {
            }
            arrayList = arrayList2;
            propertyNamingStrategy2 = propertyNamingStrategy7;
            methodArr = methods;
            method2 = getFactoryMethod(cls6, methodArr, z4);
            if (method2 == null) {
            }
        } else {
            arrayList = arrayList2;
            propertyNamingStrategy2 = propertyNamingStrategy7;
            methodArr = methods;
            constructor2 = null;
        }
        if (constructor != null) {
            TypeUtils.setAccessible(constructor);
        }
        String str14 = "set";
        if (builderClass == null) {
            str = "set";
            fieldArr = declaredFields;
            cls2 = builderClass;
            jSONType = jSONType3;
            propertyNamingStrategy3 = propertyNamingStrategy2;
            methodArr2 = methodArr;
        } else {
            JSONPOJOBuilder jSONPOJOBuilder = (JSONPOJOBuilder) TypeUtils.getAnnotation(builderClass, JSONPOJOBuilder.class);
            String withPrefix = jSONPOJOBuilder != null ? jSONPOJOBuilder.withPrefix() : null;
            if (withPrefix == null) {
                withPrefix = "with";
            }
            String str15 = withPrefix;
            Method[] methods2 = builderClass.getMethods();
            int length7 = methods2.length;
            int i32 = 0;
            while (i32 < length7) {
                Method method3 = methods2[i32];
                if (!Modifier.isStatic(method3.getModifiers()) && method3.getReturnType().equals(builderClass)) {
                    JSONField jSONField6 = (JSONField) TypeUtils.getAnnotation(method3, JSONField.class);
                    if (jSONField6 == null) {
                        jSONField6 = TypeUtils.getSuperMethodAnnotation(cls6, method3);
                    }
                    JSONField jSONField7 = jSONField6;
                    if (jSONField7 == null) {
                        i11 = i32;
                        i12 = length7;
                        methodArr5 = methods2;
                        str5 = str15;
                        str6 = str14;
                        fieldArr6 = declaredFields;
                        cls5 = builderClass;
                        jSONType2 = jSONType3;
                        propertyNamingStrategy6 = propertyNamingStrategy2;
                        i13 = 3;
                        methodArr6 = methodArr;
                        i14 = 0;
                        i15 = 0;
                        i16 = 0;
                    } else if (jSONField7.deserialize()) {
                        int ordinal3 = jSONField7.ordinal();
                        int of4 = SerializerFeature.of(jSONField7.serialzeFeatures());
                        int of5 = Feature.of(jSONField7.parseFeatures());
                        if (jSONField7.name().length() != 0) {
                            i11 = i32;
                            i12 = length7;
                            methodArr5 = methods2;
                            fieldArr6 = declaredFields;
                            cls5 = builderClass;
                            jSONType2 = jSONType3;
                            propertyNamingStrategy6 = propertyNamingStrategy2;
                            methodArr6 = methodArr;
                            add(arrayList, new FieldInfo(jSONField7.name(), method3, null, cls, type, ordinal3, of4, of5, jSONField7, null, null, buildGenericInfo));
                            str8 = str15;
                            str9 = str14;
                            i32 = i11 + 1;
                            cls6 = cls;
                            methodArr = methodArr6;
                            str15 = str8;
                            jSONType3 = jSONType2;
                            length7 = i12;
                            methods2 = methodArr5;
                            declaredFields = fieldArr6;
                            builderClass = cls5;
                            propertyNamingStrategy2 = propertyNamingStrategy6;
                            str14 = str9;
                        } else {
                            i11 = i32;
                            i12 = length7;
                            methodArr5 = methods2;
                            str5 = str15;
                            str6 = str14;
                            fieldArr6 = declaredFields;
                            cls5 = builderClass;
                            jSONType2 = jSONType3;
                            propertyNamingStrategy6 = propertyNamingStrategy2;
                            i13 = 3;
                            methodArr6 = methodArr;
                            i14 = ordinal3;
                            i15 = of4;
                            i16 = of5;
                        }
                    }
                    String name3 = method3.getName();
                    String str16 = str6;
                    if (name3.startsWith(str16) && name3.length() > i13) {
                        sb = new StringBuilder(name3.substring(i13));
                    } else if (str5.length() == 0) {
                        sb = new StringBuilder(name3);
                    } else {
                        str7 = str5;
                        if (name3.startsWith(str7) && name3.length() > str7.length()) {
                            sb = new StringBuilder(name3.substring(str7.length()));
                            charAt = sb.charAt(0);
                            if (str7.length() != 0 || Character.isUpperCase(charAt)) {
                                sb.setCharAt(0, Character.toLowerCase(charAt));
                                str8 = str7;
                                str9 = str16;
                                add(arrayList, new FieldInfo(sb.toString(), method3, null, cls, type, i14, i15, i16, jSONField7, null, null, buildGenericInfo));
                                i32 = i11 + 1;
                                cls6 = cls;
                                methodArr = methodArr6;
                                str15 = str8;
                                jSONType3 = jSONType2;
                                length7 = i12;
                                methods2 = methodArr5;
                                declaredFields = fieldArr6;
                                builderClass = cls5;
                                propertyNamingStrategy2 = propertyNamingStrategy6;
                                str14 = str9;
                            }
                        }
                        str8 = str7;
                        str9 = str16;
                        i32 = i11 + 1;
                        cls6 = cls;
                        methodArr = methodArr6;
                        str15 = str8;
                        jSONType3 = jSONType2;
                        length7 = i12;
                        methods2 = methodArr5;
                        declaredFields = fieldArr6;
                        builderClass = cls5;
                        propertyNamingStrategy2 = propertyNamingStrategy6;
                        str14 = str9;
                    }
                    str7 = str5;
                    charAt = sb.charAt(0);
                    if (str7.length() != 0) {
                    }
                    sb.setCharAt(0, Character.toLowerCase(charAt));
                    str8 = str7;
                    str9 = str16;
                    add(arrayList, new FieldInfo(sb.toString(), method3, null, cls, type, i14, i15, i16, jSONField7, null, null, buildGenericInfo));
                    i32 = i11 + 1;
                    cls6 = cls;
                    methodArr = methodArr6;
                    str15 = str8;
                    jSONType3 = jSONType2;
                    length7 = i12;
                    methods2 = methodArr5;
                    declaredFields = fieldArr6;
                    builderClass = cls5;
                    propertyNamingStrategy2 = propertyNamingStrategy6;
                    str14 = str9;
                }
                i11 = i32;
                i12 = length7;
                methodArr5 = methods2;
                str9 = str14;
                fieldArr6 = declaredFields;
                cls5 = builderClass;
                jSONType2 = jSONType3;
                propertyNamingStrategy6 = propertyNamingStrategy2;
                str8 = str15;
                methodArr6 = methodArr;
                i32 = i11 + 1;
                cls6 = cls;
                methodArr = methodArr6;
                str15 = str8;
                jSONType3 = jSONType2;
                length7 = i12;
                methods2 = methodArr5;
                declaredFields = fieldArr6;
                builderClass = cls5;
                propertyNamingStrategy2 = propertyNamingStrategy6;
                str14 = str9;
            }
            str = str14;
            fieldArr = declaredFields;
            cls2 = builderClass;
            jSONType = jSONType3;
            propertyNamingStrategy3 = propertyNamingStrategy2;
            methodArr2 = methodArr;
            if (cls2 != null) {
                JSONPOJOBuilder jSONPOJOBuilder2 = (JSONPOJOBuilder) TypeUtils.getAnnotation(cls2, JSONPOJOBuilder.class);
                String buildMethod = jSONPOJOBuilder2 != null ? jSONPOJOBuilder2.buildMethod() : null;
                field = null;
                try {
                    method = cls2.getMethod((buildMethod == null || buildMethod.length() == 0) ? "build" : "build", null);
                } catch (NoSuchMethodException | SecurityException unused2) {
                }
                if (method == null) {
                    try {
                        method = cls2.getMethod("create", null);
                    } catch (NoSuchMethodException | SecurityException unused3) {
                    }
                }
                if (method == null) {
                    throw new JSONException("buildMethod not found.");
                }
                TypeUtils.setAccessible(method);
                length = methodArr2.length;
                i = 0;
                while (true) {
                    str2 = "get";
                    i2 = 4;
                    if (i < length) {
                        break;
                    }
                    Method method4 = methodArr2[i];
                    String name4 = method4.getName();
                    if (!Modifier.isStatic(method4.getModifiers())) {
                        Class<?> returnType = method4.getReturnType();
                        if ((returnType.equals(Void.TYPE) || returnType.equals(method4.getDeclaringClass())) && method4.getDeclaringClass() != Object.class) {
                            Class<?>[] parameterTypes5 = method4.getParameterTypes();
                            if (parameterTypes5.length != 0 && parameterTypes5.length <= 2) {
                                JSONField jSONField8 = (JSONField) TypeUtils.getAnnotation(method4, JSONField.class);
                                int i33 = 0;
                                int i34 = 0;
                                int i35 = 0;
                                if (jSONField8 != null && parameterTypes5.length == 2 && parameterTypes5[0] == String.class && parameterTypes5[1] == Object.class) {
                                    i6 = i;
                                    i7 = length;
                                    field5 = field;
                                    add(arrayList, new FieldInfo("", method4, null, cls, type, 0, 0, 0, jSONField8, null, null, buildGenericInfo));
                                } else {
                                    i6 = i;
                                    i7 = length;
                                    field3 = field;
                                    field5 = field3;
                                    if (parameterTypes5.length == 1) {
                                        if (jSONField8 == null) {
                                            jSONField8 = TypeUtils.getSuperMethodAnnotation(cls, method4);
                                        }
                                        if (jSONField8 == null) {
                                            field5 = field3;
                                        }
                                        if (jSONField8 != null) {
                                            field5 = field3;
                                            if (jSONField8.deserialize()) {
                                                i33 = jSONField8.ordinal();
                                                int of6 = SerializerFeature.of(jSONField8.serialzeFeatures());
                                                int of7 = Feature.of(jSONField8.parseFeatures());
                                                if (jSONField8.name().length() != 0) {
                                                    add(arrayList, new FieldInfo(jSONField8.name(), method4, null, cls, type, i33, of6, of7, jSONField8, null, null, buildGenericInfo));
                                                    field5 = field3;
                                                } else {
                                                    i35 = of7;
                                                    i34 = of6;
                                                }
                                            }
                                        }
                                        String str17 = str;
                                        if ((jSONField8 != null || name4.startsWith(str17)) && cls2 == null) {
                                            char charAt2 = name4.charAt(3);
                                            if (isKotlin) {
                                                r7 = new ArrayList();
                                                for (int i36 = 0; i36 < methodArr2.length; i36++) {
                                                    if (methodArr2[i36].getName().startsWith("get")) {
                                                        r7.add(methodArr2[i36].getName());
                                                    }
                                                }
                                            } else {
                                                r7 = field3;
                                            }
                                            if (Character.isUpperCase(charAt2) || charAt2 > 512) {
                                                i8 = 1;
                                                cls3 = cls;
                                                fieldArr4 = fieldArr;
                                                if (isKotlin) {
                                                    propertyNameByMethodName2 = TypeUtils.getPropertyNameByMethodName("g" + name4.substring(1));
                                                } else if (TypeUtils.compatibleWithJavaBean) {
                                                    propertyNameByMethodName2 = TypeUtils.decapitalize(name4.substring(3));
                                                } else {
                                                    propertyNameByMethodName2 = TypeUtils.getPropertyNameByMethodName(name4);
                                                }
                                            } else {
                                                if (charAt2 != '_') {
                                                    i8 = 1;
                                                    cls3 = cls;
                                                    fieldArr4 = fieldArr;
                                                    if (charAt2 == 'f') {
                                                        propertyNameByMethodName2 = name4.substring(3);
                                                    } else if (name4.length() >= 5 && Character.isUpperCase(name4.charAt(4))) {
                                                        propertyNameByMethodName2 = TypeUtils.decapitalize(name4.substring(3));
                                                    } else {
                                                        propertyNameByMethodName2 = name4.substring(3);
                                                        field4 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr4);
                                                    }
                                                } else if (isKotlin) {
                                                    StringBuilder sb2 = new StringBuilder("g");
                                                    i8 = 1;
                                                    sb2.append(name4.substring(1));
                                                    propertyNameByMethodName2 = r7.contains(sb2.toString()) ? name4.substring(3) : "is" + name4.substring(3);
                                                    cls3 = cls;
                                                    fieldArr4 = fieldArr;
                                                    field4 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr4);
                                                } else {
                                                    i8 = 1;
                                                    cls3 = cls;
                                                    fieldArr4 = fieldArr;
                                                    String substring = name4.substring(4);
                                                    Field field10 = TypeUtils.getField(cls3, substring, fieldArr4);
                                                    if (field10 != null || (field10 = TypeUtils.getField(cls3, (propertyNameByMethodName2 = name4.substring(3)), fieldArr4)) == null) {
                                                        propertyNameByMethodName2 = substring;
                                                    }
                                                    field4 = field10;
                                                }
                                                if (field4 == null) {
                                                    field4 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr4);
                                                }
                                                if (field4 == null && parameterTypes5[0] == Boolean.TYPE) {
                                                    field4 = TypeUtils.getField(cls3, "is" + Character.toUpperCase(propertyNameByMethodName2.charAt(0)) + propertyNameByMethodName2.substring(i8), fieldArr4);
                                                }
                                                if (field4 == null) {
                                                    JSONField jSONField9 = (JSONField) TypeUtils.getAnnotation(field4, JSONField.class);
                                                    if (jSONField9 != null) {
                                                        if (jSONField9.deserialize()) {
                                                            i33 = jSONField9.ordinal();
                                                            int of8 = SerializerFeature.of(jSONField9.serialzeFeatures());
                                                            int of9 = Feature.of(jSONField9.parseFeatures());
                                                            if (jSONField9.name().length() != 0) {
                                                                fieldArr5 = fieldArr4;
                                                                methodArr4 = methodArr2;
                                                                str4 = str17;
                                                                add(arrayList, new FieldInfo(jSONField9.name(), method4, field4, cls, type, i33, of8, of9, jSONField8, jSONField9, null, buildGenericInfo));
                                                                cls4 = cls2;
                                                                propertyNamingStrategy5 = propertyNamingStrategy3;
                                                                i = i6 + 1;
                                                                propertyNamingStrategy3 = propertyNamingStrategy5;
                                                                length = i7;
                                                                field = field3;
                                                                methodArr2 = methodArr4;
                                                                str = str4;
                                                                cls2 = cls4;
                                                                fieldArr = fieldArr5;
                                                            } else {
                                                                fieldArr5 = fieldArr4;
                                                                str4 = str17;
                                                                methodArr4 = methodArr2;
                                                                i9 = of8;
                                                                i10 = of9;
                                                            }
                                                        }
                                                        fieldArr5 = fieldArr4;
                                                        str4 = str17;
                                                        cls4 = cls2;
                                                        methodArr4 = methodArr2;
                                                    } else {
                                                        fieldArr5 = fieldArr4;
                                                        str4 = str17;
                                                        methodArr4 = methodArr2;
                                                        i9 = i34;
                                                        i10 = i35;
                                                    }
                                                    jSONField2 = jSONField9;
                                                } else {
                                                    fieldArr5 = fieldArr4;
                                                    str4 = str17;
                                                    methodArr4 = methodArr2;
                                                    i9 = i34;
                                                    i10 = i35;
                                                    jSONField2 = field3;
                                                }
                                                propertyNamingStrategy4 = propertyNamingStrategy3;
                                                if (propertyNamingStrategy4 != null) {
                                                    propertyNameByMethodName2 = propertyNamingStrategy4.translate(propertyNameByMethodName2);
                                                }
                                                cls4 = cls2;
                                                propertyNamingStrategy5 = propertyNamingStrategy4;
                                                add(arrayList, new FieldInfo(propertyNameByMethodName2, method4, field4, cls, type, i33, i9, i10, jSONField8, jSONField2, null, buildGenericInfo));
                                                i = i6 + 1;
                                                propertyNamingStrategy3 = propertyNamingStrategy5;
                                                length = i7;
                                                field = field3;
                                                methodArr2 = methodArr4;
                                                str = str4;
                                                cls2 = cls4;
                                                fieldArr = fieldArr5;
                                            }
                                            field4 = field3;
                                            if (field4 == null) {
                                            }
                                            if (field4 == null) {
                                                field4 = TypeUtils.getField(cls3, "is" + Character.toUpperCase(propertyNameByMethodName2.charAt(0)) + propertyNameByMethodName2.substring(i8), fieldArr4);
                                            }
                                            if (field4 == null) {
                                            }
                                            propertyNamingStrategy4 = propertyNamingStrategy3;
                                            if (propertyNamingStrategy4 != null) {
                                            }
                                            cls4 = cls2;
                                            propertyNamingStrategy5 = propertyNamingStrategy4;
                                            add(arrayList, new FieldInfo(propertyNameByMethodName2, method4, field4, cls, type, i33, i9, i10, jSONField8, jSONField2, null, buildGenericInfo));
                                            i = i6 + 1;
                                            propertyNamingStrategy3 = propertyNamingStrategy5;
                                            length = i7;
                                            field = field3;
                                            methodArr2 = methodArr4;
                                            str = str4;
                                            cls2 = cls4;
                                            fieldArr = fieldArr5;
                                        } else {
                                            str4 = str17;
                                            cls4 = cls2;
                                            methodArr4 = methodArr2;
                                            fieldArr5 = fieldArr;
                                        }
                                        propertyNamingStrategy5 = propertyNamingStrategy3;
                                        field3 = field3;
                                        i = i6 + 1;
                                        propertyNamingStrategy3 = propertyNamingStrategy5;
                                        length = i7;
                                        field = field3;
                                        methodArr2 = methodArr4;
                                        str = str4;
                                        cls2 = cls4;
                                        fieldArr = fieldArr5;
                                    }
                                }
                                cls4 = cls2;
                                methodArr4 = methodArr2;
                                fieldArr5 = fieldArr;
                                propertyNamingStrategy5 = propertyNamingStrategy3;
                                str4 = str;
                                field3 = field5;
                                i = i6 + 1;
                                propertyNamingStrategy3 = propertyNamingStrategy5;
                                length = i7;
                                field = field3;
                                methodArr2 = methodArr4;
                                str = str4;
                                cls2 = cls4;
                                fieldArr = fieldArr5;
                            }
                        }
                    }
                    i6 = i;
                    i7 = length;
                    field3 = field;
                    cls4 = cls2;
                    methodArr4 = methodArr2;
                    fieldArr5 = fieldArr;
                    propertyNamingStrategy5 = propertyNamingStrategy3;
                    str4 = str;
                    i = i6 + 1;
                    propertyNamingStrategy3 = propertyNamingStrategy5;
                    length = i7;
                    field = field3;
                    methodArr2 = methodArr4;
                    str = str4;
                    cls2 = cls4;
                    fieldArr = fieldArr5;
                }
                Field field11 = field;
                Class<?> cls10 = cls2;
                Field[] fieldArr7 = fieldArr;
                PropertyNamingStrategy propertyNamingStrategy8 = propertyNamingStrategy3;
                computeFields(cls, type, propertyNamingStrategy8, arrayList, cls.getFields());
                Method[] methods3 = cls.getMethods();
                length2 = methods3.length;
                i3 = 0;
                while (i3 < length2) {
                    Method method5 = methods3[i3];
                    String name5 = method5.getName();
                    if (name5.length() >= i2 && !Modifier.isStatic(method5.getModifiers()) && cls10 == null && name5.startsWith(str2) && Character.isUpperCase(name5.charAt(3)) && method5.getParameterTypes().length == 0 && ((Collection.class.isAssignableFrom(method5.getReturnType()) || Map.class.isAssignableFrom(method5.getReturnType()) || AtomicBoolean.class == method5.getReturnType() || AtomicInteger.class == method5.getReturnType() || AtomicLong.class == method5.getReturnType()) && ((jSONField = (JSONField) TypeUtils.getAnnotation(method5, JSONField.class)) == null || !jSONField.deserialize()))) {
                        if (jSONField != null && jSONField.name().length() > 0) {
                            propertyNameByMethodName = jSONField.name();
                            field2 = field11;
                            fieldArr2 = fieldArr7;
                        } else {
                            propertyNameByMethodName = TypeUtils.getPropertyNameByMethodName(name5);
                            fieldArr2 = fieldArr7;
                            Field field12 = TypeUtils.getField(cls, propertyNameByMethodName, fieldArr2);
                            if (field12 != null) {
                                JSONField jSONField10 = (JSONField) TypeUtils.getAnnotation(field12, JSONField.class);
                                if (jSONField10 == null || jSONField10.deserialize()) {
                                    if (Collection.class.isAssignableFrom(method5.getReturnType()) || Map.class.isAssignableFrom(method5.getReturnType())) {
                                        field2 = field12;
                                    }
                                }
                                fieldArr3 = fieldArr2;
                                i4 = i3;
                                str3 = str2;
                                i5 = length2;
                                methodArr3 = methods3;
                            }
                            field2 = field11;
                        }
                        if (propertyNamingStrategy8 != null) {
                            propertyNameByMethodName = propertyNamingStrategy8.translate(propertyNameByMethodName);
                        }
                        String str18 = propertyNameByMethodName;
                        if (getField(arrayList, str18) == null) {
                            fieldArr3 = fieldArr2;
                            i4 = i3;
                            str3 = str2;
                            i5 = length2;
                            methodArr3 = methods3;
                            add(arrayList, new FieldInfo(str18, method5, field2, cls, type, 0, 0, 0, jSONField, null, null, buildGenericInfo));
                            i3 = i4 + 1;
                            length2 = i5;
                            methods3 = methodArr3;
                            str2 = str3;
                            fieldArr7 = fieldArr3;
                            i2 = 4;
                        }
                        fieldArr3 = fieldArr2;
                        i4 = i3;
                        str3 = str2;
                        i5 = length2;
                        methodArr3 = methods3;
                    } else {
                        i4 = i3;
                        str3 = str2;
                        i5 = length2;
                        methodArr3 = methods3;
                        fieldArr3 = fieldArr7;
                    }
                    i3 = i4 + 1;
                    length2 = i5;
                    methods3 = methodArr3;
                    str2 = str3;
                    fieldArr7 = fieldArr3;
                    i2 = 4;
                }
                Field[] fieldArr8 = fieldArr7;
                if (arrayList.size() == 0) {
                    if (TypeUtils.isXmlField(cls) ? true : z) {
                        for (Class<?> cls11 = cls; cls11 != null; cls11 = cls11.getSuperclass()) {
                            computeFields(cls, type, propertyNamingStrategy8, arrayList, fieldArr8);
                        }
                    }
                }
                return new JavaBeanInfo(cls, cls10, constructor, constructor2, method2, method, jSONType, arrayList);
            }
        }
        field = null;
        length = methodArr2.length;
        i = 0;
        while (true) {
            str2 = "get";
            i2 = 4;
            if (i < length) {
            }
            i = i6 + 1;
            propertyNamingStrategy3 = propertyNamingStrategy5;
            length = i7;
            field = field3;
            methodArr2 = methodArr4;
            str = str4;
            cls2 = cls4;
            fieldArr = fieldArr5;
        }
        Field field112 = field;
        Class<?> cls102 = cls2;
        Field[] fieldArr72 = fieldArr;
        PropertyNamingStrategy propertyNamingStrategy82 = propertyNamingStrategy3;
        computeFields(cls, type, propertyNamingStrategy82, arrayList, cls.getFields());
        Method[] methods32 = cls.getMethods();
        length2 = methods32.length;
        i3 = 0;
        while (i3 < length2) {
        }
        Field[] fieldArr82 = fieldArr72;
        if (arrayList.size() == 0) {
        }
        return new JavaBeanInfo(cls, cls102, constructor, constructor2, method2, method, jSONType, arrayList);
    }

    /* JADX WARN: Code restructure failed: missing block: B:18:0x004e, code lost:
        if (java.util.concurrent.atomic.AtomicBoolean.class.equals(r2) == false) goto L5;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static void computeFields(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, List<FieldInfo> list, Field[] fieldArr) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        Map<TypeVariable, Type> buildGenericInfo = buildGenericInfo(cls);
        int length = fieldArr.length;
        int i6 = 0;
        while (i6 < length) {
            Field field = fieldArr[i6];
            int modifiers = field.getModifiers();
            if ((modifiers & 8) == 0) {
                if ((modifiers & 16) != 0) {
                    Class<?> type2 = field.getType();
                    if (!Map.class.isAssignableFrom(type2)) {
                        if (!Collection.class.isAssignableFrom(type2)) {
                            if (!AtomicLong.class.equals(type2)) {
                                if (!AtomicInteger.class.equals(type2)) {
                                }
                            }
                        }
                    }
                }
                Iterator<FieldInfo> it = list.iterator();
                while (true) {
                    if (it.hasNext()) {
                        if (it.next().name.equals(field.getName())) {
                            break;
                        }
                    } else {
                        String name = field.getName();
                        JSONField jSONField = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                        if (jSONField == null) {
                            i = 0;
                            i2 = 0;
                            i3 = 0;
                        } else if (jSONField.deserialize()) {
                            int ordinal = jSONField.ordinal();
                            int of = SerializerFeature.of(jSONField.serialzeFeatures());
                            int of2 = Feature.of(jSONField.parseFeatures());
                            if (jSONField.name().length() != 0) {
                                name = jSONField.name();
                            }
                            i = ordinal;
                            i2 = of;
                            i3 = of2;
                        }
                        if (propertyNamingStrategy != null) {
                            name = propertyNamingStrategy.translate(name);
                        }
                        i4 = i6;
                        i5 = length;
                        add(list, new FieldInfo(name, null, field, cls, type, i, i2, i3, null, jSONField, null, buildGenericInfo));
                    }
                }
            }
            i4 = i6;
            i5 = length;
            i6 = i4 + 1;
            length = i5;
        }
    }

    static Constructor<?> getDefaultConstructor(Class<?> cls, Constructor<?>[] constructorArr) {
        Constructor<?> constructor = null;
        if (Modifier.isAbstract(cls.getModifiers())) {
            return null;
        }
        int length = constructorArr.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            Constructor<?> constructor2 = constructorArr[i];
            if (constructor2.getParameterTypes().length == 0) {
                constructor = constructor2;
                break;
            }
            i++;
        }
        if (constructor == null && cls.isMemberClass() && !Modifier.isStatic(cls.getModifiers())) {
            for (Constructor<?> constructor3 : constructorArr) {
                Class<?>[] parameterTypes = constructor3.getParameterTypes();
                if (parameterTypes.length == 1 && parameterTypes[0].equals(cls.getDeclaringClass())) {
                    return constructor3;
                }
            }
            return constructor;
        }
        return constructor;
    }

    public static Constructor<?> getCreatorConstructor(Constructor[] constructorArr) {
        Constructor constructor = null;
        for (Constructor constructor2 : constructorArr) {
            if (((JSONCreator) constructor2.getAnnotation(JSONCreator.class)) != null) {
                if (constructor != null) {
                    throw new JSONException("multi-JSONCreator");
                }
                constructor = constructor2;
            }
        }
        if (constructor != null) {
            return constructor;
        }
        for (Constructor constructor3 : constructorArr) {
            Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor3);
            if (parameterAnnotations.length != 0) {
                int length = parameterAnnotations.length;
                int i = 0;
                while (true) {
                    if (i < length) {
                        for (Annotation annotation : parameterAnnotations[i]) {
                            if (annotation instanceof JSONField) {
                                break;
                            }
                        }
                    } else if (constructor != null) {
                        throw new JSONException("multi-JSONCreator");
                    } else {
                        constructor = constructor3;
                    }
                    i++;
                }
            }
        }
        return constructor;
    }

    private static Method getFactoryMethod(Class<?> cls, Method[] methodArr, boolean z) {
        Method method = null;
        for (Method method2 : methodArr) {
            if (Modifier.isStatic(method2.getModifiers()) && cls.isAssignableFrom(method2.getReturnType()) && ((JSONCreator) TypeUtils.getAnnotation(method2, JSONCreator.class)) != null) {
                if (method != null) {
                    throw new JSONException("multi-JSONCreator");
                }
                method = method2;
            }
        }
        if (method == null && z) {
            for (Method method3 : methodArr) {
                if (TypeUtils.isJacksonCreator(method3)) {
                    return method3;
                }
            }
            return method;
        }
        return method;
    }

    public static Class<?> getBuilderClass(JSONType jSONType) {
        return getBuilderClass(null, jSONType);
    }

    public static Class<?> getBuilderClass(Class<?> cls, JSONType jSONType) {
        Class<?> builder;
        if (cls != null && cls.getName().equals("org.springframework.security.web.savedrequest.DefaultSavedRequest")) {
            return TypeUtils.loadClass("org.springframework.security.web.savedrequest.DefaultSavedRequest$Builder");
        }
        if (jSONType == null || (builder = jSONType.builder()) == Void.class) {
            return null;
        }
        return builder;
    }
}
