package com.robustel.project.uniplugin.bluetooth.slave;

import android.app.Activity;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothGattCharacteristic;
import android.bluetooth.BluetoothGattDescriptor;
import android.bluetooth.BluetoothGattServer;
import android.bluetooth.BluetoothGattServerCallback;
import android.bluetooth.BluetoothGattService;
import android.bluetooth.BluetoothManager;
import android.bluetooth.le.AdvertiseCallback;
import android.bluetooth.le.AdvertiseData;
import android.bluetooth.le.AdvertiseSettings;
import android.bluetooth.le.BluetoothLeAdvertiser;
import android.content.Context;
import android.os.Build;
import android.os.ParcelUuid;
import androidx.core.app.NotificationCompat;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.robustel.project.uniplugin.bluetooth.slave.utils.ByteUtils;
import com.robustel.project.uniplugin.bluetooth.slave.utils.JsonUtils;
import com.robustel.project.uniplugin.bluetooth.slave.utils.StringUtils;
import com.taobao.weex.common.Constants;
import io.dcloud.feature.uniapp.bridge.UniJSCallback;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.UUID;
/* loaded from: classes.dex */
public class BluetoothSlave {
    private static volatile BluetoothSlave instance;
    private UniJSCallback advertisingJSCallback;
    private BluetoothAdapter bluetoothAdapter;
    private BluetoothGattServer bluetoothGattServer;
    private BluetoothGattServerCallback bluetoothGattServerCallback;
    private BluetoothLeAdvertiser bluetoothLeAdvertiser;
    private BluetoothManager bluetoothManager;
    private UniJSCallback jsCallback;
    private String receiveDataCharsetName;
    private int receiveDataType;
    private Map<String, BluetoothDevice> connectedBluetoothDeviceMap = new HashMap();
    AdvertiseCallback advertiseCallback = new AdvertiseCallback() { // from class: com.robustel.project.uniplugin.bluetooth.slave.BluetoothSlave.2
        @Override // android.bluetooth.le.AdvertiseCallback
        public void onStartSuccess(AdvertiseSettings advertiseSettings) {
            Object modelOrList2Map;
            super.onStartSuccess(advertiseSettings);
            if (BluetoothSlave.this.advertisingJSCallback != null) {
                HashMap hashMap = new HashMap();
                hashMap.put("flag", true);
                hashMap.put("opt", "onStartSuccess");
                if (advertiseSettings != null && (modelOrList2Map = JsonUtils.modelOrList2Map(advertiseSettings)) != null) {
                    hashMap.put("settingsInEffect", modelOrList2Map);
                }
                BluetoothSlave.this.advertisingJSCallback.invoke(hashMap);
                BluetoothSlave.this.advertisingJSCallback = null;
            }
        }

        @Override // android.bluetooth.le.AdvertiseCallback
        public void onStartFailure(int i) {
            super.onStartFailure(i);
            if (BluetoothSlave.this.advertisingJSCallback != null) {
                HashMap hashMap = new HashMap();
                hashMap.put("opt", "onStartFailure");
                hashMap.put("flag", true);
                hashMap.put("errorCode", Integer.valueOf(i));
                BluetoothSlave.this.advertisingJSCallback.invoke(hashMap);
                BluetoothSlave.this.advertisingJSCallback = null;
            }
        }
    };

    public static BluetoothSlave getInstance() {
        if (instance == null) {
            synchronized (BluetoothSlave.class) {
                if (instance == null) {
                    instance = new BluetoothSlave();
                }
            }
        }
        return instance;
    }

    public void releaseResource() {
        if (this.jsCallback != null) {
            this.jsCallback = null;
        }
        Map<String, BluetoothDevice> map = this.connectedBluetoothDeviceMap;
        if (map != null) {
            map.clear();
        }
        if (this.bluetoothGattServerCallback != null) {
            this.bluetoothGattServerCallback = null;
        }
    }

    public void initBluetoothSlave(Context context) {
        this.receiveDataType = -1;
        initGattServer(context);
    }

    public void initGattServer(Context context) {
        if (this.bluetoothGattServer == null) {
            this.bluetoothGattServer = getBluetoothManager(context).openGattServer(context, getBluetoothGattServerCallback());
        }
    }

    public void setSlaveCallback(UniJSCallback uniJSCallback) {
        this.jsCallback = uniJSCallback;
    }

    public void enableBluetooth(Context context) {
        BluetoothManager bluetoothManager = (BluetoothManager) context.getSystemService("bluetooth");
        if (bluetoothManager != null) {
            BluetoothAdapter adapter = bluetoothManager.getAdapter();
            if (adapter.isEnabled()) {
                return;
            }
            adapter.enable();
        }
    }

    public void disableBluetooth(Context context) {
        BluetoothManager bluetoothManager = (BluetoothManager) context.getSystemService("bluetooth");
        if (bluetoothManager != null) {
            BluetoothAdapter adapter = bluetoothManager.getAdapter();
            if (adapter.isEnabled()) {
                adapter.disable();
            }
        }
    }

    public Map isEnable(Context context) {
        BluetoothAdapter adapter;
        BluetoothManager bluetoothManager = (BluetoothManager) context.getSystemService("bluetooth");
        boolean isEnabled = (bluetoothManager == null || (adapter = bluetoothManager.getAdapter()) == null) ? false : adapter.isEnabled();
        HashMap hashMap = new HashMap();
        hashMap.put("isEnable", Boolean.valueOf(isEnabled));
        return hashMap;
    }

    public void setName(JSONObject jSONObject, Context context) {
        BluetoothAdapter adapter;
        String string = jSONObject.getString("name");
        BluetoothManager bluetoothManager = (BluetoothManager) context.getSystemService("bluetooth");
        if (bluetoothManager == null || (adapter = bluetoothManager.getAdapter()) == null) {
            return;
        }
        adapter.setName(string);
    }

    public void disConnectDevice(JSONObject jSONObject, Context context) {
        List<BluetoothDevice> connectedDevices;
        String string = jSONObject.getString("address");
        if (string == null || (connectedDevices = this.bluetoothGattServer.getConnectedDevices()) == null || connectedDevices.size() <= 0 || this.bluetoothGattServer == null) {
            return;
        }
        int size = connectedDevices.size();
        for (int i = 0; i < size; i++) {
            BluetoothDevice bluetoothDevice = connectedDevices.get(i);
            if (bluetoothDevice.getAddress().equals(string)) {
                this.bluetoothGattServer.cancelConnection(bluetoothDevice);
                return;
            }
        }
    }

    public void startAdvertising(JSONObject jSONObject, UniJSCallback uniJSCallback, Context context) {
        initGattServer(context);
        BluetoothAdapter bluetoothAdapter = getBluetoothAdapter(context);
        String string = jSONObject.getString("name");
        if (string != null) {
            bluetoothAdapter.setName(string);
        }
        if (bluetoothAdapter == null) {
            callError(uniJSCallback, -1, "BluetoothAdapter is null");
        } else if (!bluetoothAdapter.isEnabled()) {
            callError(uniJSCallback, -1, "Bluetooth is not enable");
        } else {
            final BluetoothLeAdvertiser bluetoothLeAdvertiser = getBluetoothLeAdvertiser(context);
            if (bluetoothLeAdvertiser == null) {
                callError(uniJSCallback, -1, "BluetoothLeAdvertiser is null");
                return;
            }
            final AdvertiseSettings.Builder builder = new AdvertiseSettings.Builder();
            Integer integer = jSONObject.getInteger("advertiseMode");
            if (integer != null) {
                builder.setAdvertiseMode(integer.intValue());
            }
            Integer integer2 = jSONObject.getInteger("txPowerLevel");
            if (integer2 != null) {
                builder.setTxPowerLevel(integer2.intValue());
            }
            Integer integer3 = jSONObject.getInteger("timeout");
            if (integer3 != null) {
                builder.setTimeout(integer3.intValue());
            }
            Boolean bool = jSONObject.getBoolean("connectable");
            if (bool != null) {
                builder.setConnectable(bool.booleanValue());
            }
            JSONObject jSONObject2 = jSONObject.getJSONObject("advertiseData");
            final AdvertiseData advertiseData = (jSONObject2 == null || jSONObject2.isEmpty()) ? null : getAdvertiseData(jSONObject2);
            JSONObject jSONObject3 = jSONObject.getJSONObject("scanResponse");
            final AdvertiseData advertiseData2 = (jSONObject3 == null || jSONObject3.isEmpty()) ? null : getAdvertiseData(jSONObject3);
            this.advertisingJSCallback = uniJSCallback;
            ((Activity) context).runOnUiThread(new Runnable() { // from class: com.robustel.project.uniplugin.bluetooth.slave.BluetoothSlave.1
                @Override // java.lang.Runnable
                public void run() {
                    bluetoothLeAdvertiser.startAdvertising(builder.build(), advertiseData, advertiseData2, BluetoothSlave.this.advertiseCallback);
                }
            });
        }
    }

    public void stopAdvertising(Context context) {
        BluetoothLeAdvertiser bluetoothLeAdvertiser = getBluetoothLeAdvertiser(context);
        if (bluetoothLeAdvertiser == null) {
            return;
        }
        bluetoothLeAdvertiser.stopAdvertising(this.advertiseCallback);
    }

    public void close() {
        BluetoothGattServer bluetoothGattServer = this.bluetoothGattServer;
        if (bluetoothGattServer != null) {
            bluetoothGattServer.close();
            this.bluetoothGattServer = null;
        }
    }

    public void addService(JSONObject jSONObject, Context context) {
        JSONArray jSONArray;
        JSONArray jSONArray2;
        initGattServer(context);
        String string = jSONObject.getString("uuid");
        BluetoothGattService bluetoothGattService = new BluetoothGattService(UUID.fromString(string), jSONObject.getIntValue("type"));
        JSONArray jSONArray3 = jSONObject.getJSONArray("characteristics");
        if (jSONArray3 != null && jSONArray3.size() > 0) {
            int size = jSONArray3.size();
            int i = 0;
            while (i < size) {
                JSONObject jSONObject2 = jSONArray3.getJSONObject(i);
                if (jSONObject2 == null || jSONObject2.isEmpty()) {
                    jSONArray = jSONArray3;
                } else {
                    String string2 = jSONObject2.getString("uuid");
                    BluetoothGattCharacteristic bluetoothGattCharacteristic = new BluetoothGattCharacteristic(UUID.fromString(string2), jSONObject2.getIntValue("properties"), jSONObject2.getIntValue("permissions"));
                    byte[] bytes = getBytes(jSONObject2, "value");
                    if (bytes != null && bytes.length > 0) {
                        bluetoothGattCharacteristic.setValue(bytes);
                    }
                    JSONArray jSONArray4 = jSONObject2.getJSONArray("descriptors");
                    if (jSONArray4 != null && jSONArray4.size() > 0) {
                        int size2 = jSONArray4.size();
                        int i2 = 0;
                        while (i2 < size2) {
                            JSONObject jSONObject3 = jSONArray4.getJSONObject(i2);
                            if (jSONObject3 == null || jSONObject3.isEmpty()) {
                                jSONArray2 = jSONArray3;
                            } else {
                                String string3 = jSONObject3.getString("uuid");
                                jSONArray2 = jSONArray3;
                                BluetoothGattDescriptor bluetoothGattDescriptor = new BluetoothGattDescriptor(UUID.fromString(string3), jSONObject3.getIntValue("permissions"));
                                byte[] bytes2 = getBytes(jSONObject3, "value");
                                if (bytes2 != null && bytes2.length > 0) {
                                    bluetoothGattDescriptor.setValue(bytes);
                                }
                                bluetoothGattCharacteristic.addDescriptor(bluetoothGattDescriptor);
                            }
                            i2++;
                            jSONArray3 = jSONArray2;
                        }
                    }
                    jSONArray = jSONArray3;
                    bluetoothGattService.addCharacteristic(bluetoothGattCharacteristic);
                }
                i++;
                jSONArray3 = jSONArray;
            }
        }
        this.bluetoothGattServer.addService(bluetoothGattService);
    }

    public void removeService(JSONObject jSONObject, Context context) {
        BluetoothGattService service;
        String string = jSONObject.getString("uuid");
        initGattServer(context);
        BluetoothGattServer bluetoothGattServer = this.bluetoothGattServer;
        if (bluetoothGattServer == null || (service = bluetoothGattServer.getService(UUID.fromString(string))) == null) {
            return;
        }
        this.bluetoothGattServer.removeService(service);
    }

    public void removeAllService(Context context) {
        List<BluetoothGattService> services;
        initGattServer(context);
        BluetoothGattServer bluetoothGattServer = this.bluetoothGattServer;
        if (bluetoothGattServer == null || (services = bluetoothGattServer.getServices()) == null || services.size() <= 0) {
            return;
        }
        for (int i = 0; i < services.size(); i++) {
            this.bluetoothGattServer.removeService(services.get(i));
        }
    }

    public Map sendData(JSONObject jSONObject) {
        String str;
        BluetoothGattCharacteristic bluetoothGattCharacteristic;
        BluetoothGattService bluetoothGattService;
        HashMap hashMap = new HashMap();
        String string = jSONObject.getString("address");
        String string2 = jSONObject.getString("serviceUuid");
        String string3 = jSONObject.getString("characteristicUuid");
        BluetoothDevice bluetoothDevice = this.connectedBluetoothDeviceMap.get(string);
        BluetoothGattServer bluetoothGattServer = this.bluetoothGattServer;
        boolean z = false;
        if (bluetoothGattServer == null) {
            str = "BluetoothGattServer is NULL";
        } else if (bluetoothDevice != null) {
            List<BluetoothGattService> services = bluetoothGattServer.getServices();
            if (services != null && services.size() > 0) {
                int size = services.size();
                int i = 0;
                while (true) {
                    bluetoothGattCharacteristic = null;
                    if (i >= size) {
                        bluetoothGattService = null;
                        break;
                    }
                    bluetoothGattService = services.get(i);
                    if (bluetoothGattService.getUuid().toString().contentEquals(string2)) {
                        break;
                    }
                    i++;
                }
                if (bluetoothGattService != null) {
                    List<BluetoothGattCharacteristic> characteristics = bluetoothGattService.getCharacteristics();
                    if (characteristics != null && characteristics.size() > 0) {
                        int size2 = characteristics.size();
                        int i2 = 0;
                        while (true) {
                            if (i2 >= size2) {
                                break;
                            }
                            BluetoothGattCharacteristic bluetoothGattCharacteristic2 = characteristics.get(i2);
                            if (bluetoothGattCharacteristic2.getUuid().toString().contentEquals(string3)) {
                                bluetoothGattCharacteristic = bluetoothGattCharacteristic2;
                                break;
                            }
                            i2++;
                        }
                        if (bluetoothGattCharacteristic != null) {
                            byte[] bytesFromJSON = getBytesFromJSON(jSONObject, "value");
                            boolean booleanValue = jSONObject.getBooleanValue("comfirm");
                            Boolean bool = jSONObject.getBoolean("notify");
                            Boolean bool2 = jSONObject.getBoolean("notifyAll");
                            bluetoothGattCharacteristic.setValue(bytesFromJSON);
                            boolean notifyCharacteristicChanged = this.bluetoothGattServer.notifyCharacteristicChanged(bluetoothDevice, bluetoothGattCharacteristic, booleanValue);
                            if (bool != null && bool.booleanValue()) {
                                this.bluetoothGattServer.notify();
                            }
                            if (bool2 != null && bool2.booleanValue()) {
                                this.bluetoothGattServer.notifyAll();
                            }
                            hashMap.put("sendResult", Boolean.valueOf(notifyCharacteristicChanged));
                            z = true;
                            str = "";
                        } else {
                            str = "characteristicUuid find no characteristic";
                        }
                    } else {
                        str = "service find no characteristic";
                    }
                } else {
                    str = "serviceUuid find no service";
                }
            } else {
                str = "bluetoothGattServer find no service";
            }
        } else {
            str = "address find no device";
        }
        hashMap.put("flag", Boolean.valueOf(z));
        hashMap.put(NotificationCompat.CATEGORY_MESSAGE, str);
        return hashMap;
    }

    public Map sendResponse(JSONObject jSONObject) {
        String str;
        HashMap hashMap = new HashMap();
        BluetoothDevice bluetoothDevice = this.connectedBluetoothDeviceMap.get(jSONObject.getString("address"));
        boolean z = false;
        if (bluetoothDevice != null) {
            int intValue = jSONObject.getIntValue("requestId");
            int intValue2 = jSONObject.getIntValue("status");
            int intValue3 = jSONObject.getIntValue("offset");
            byte[] bytesFromJSON = getBytesFromJSON(jSONObject, "value");
            BluetoothGattServer bluetoothGattServer = this.bluetoothGattServer;
            if (bluetoothGattServer != null && bytesFromJSON != null) {
                hashMap.put("sendResult", Boolean.valueOf(bluetoothGattServer.sendResponse(bluetoothDevice, intValue, intValue2, intValue3, bytesFromJSON)));
                str = "";
                z = true;
            } else {
                str = "bluetoothGattServer is null Or no add gattService";
            }
        } else {
            str = "address find No device";
        }
        hashMap.put("flag", Boolean.valueOf(z));
        hashMap.put(NotificationCompat.CATEGORY_MESSAGE, str);
        return hashMap;
    }

    public void setReceiveDataDataType(JSONObject jSONObject) {
        Integer integer = jSONObject.getInteger("dataType");
        if (integer != null) {
            this.receiveDataType = integer.intValue();
        }
        String string = jSONObject.getString("charsetName");
        if (string == null || string.length() <= 0) {
            return;
        }
        this.receiveDataCharsetName = string;
    }

    private BluetoothGattServerCallback getBluetoothGattServerCallback() {
        if (this.bluetoothGattServerCallback == null) {
            this.bluetoothGattServerCallback = new BluetoothGattServerCallback() { // from class: com.robustel.project.uniplugin.bluetooth.slave.BluetoothSlave.3
                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onConnectionStateChange(BluetoothDevice bluetoothDevice, int i, int i2) {
                    String address;
                    super.onConnectionStateChange(bluetoothDevice, i, i2);
                    if (i != 0) {
                        String address2 = bluetoothDevice.getAddress();
                        if (address2 != null) {
                            BluetoothSlave.this.connectedBluetoothDeviceMap.remove(address2);
                        }
                    } else if (i2 == 2) {
                        String address3 = bluetoothDevice.getAddress();
                        if (address3 != null) {
                            BluetoothSlave.this.connectedBluetoothDeviceMap.put(address3, bluetoothDevice);
                        }
                    } else if (i2 == 0 && (address = bluetoothDevice.getAddress()) != null) {
                        BluetoothSlave.this.connectedBluetoothDeviceMap.remove(address);
                    }
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("status", Integer.valueOf(i));
                        hashMap.put("newState", Integer.valueOf(i2));
                        hashMap.put("opt", "onConnectionStateChange");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onServiceAdded(int i, BluetoothGattService bluetoothGattService) {
                    super.onServiceAdded(i, bluetoothGattService);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.serviceSaveToMap(bluetoothGattService, hashMap);
                        hashMap.put("status", Integer.valueOf(i));
                        hashMap.put("opt", "onServiceAdded");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onCharacteristicReadRequest(BluetoothDevice bluetoothDevice, int i, int i2, BluetoothGattCharacteristic bluetoothGattCharacteristic) {
                    super.onCharacteristicReadRequest(bluetoothDevice, i, i2, bluetoothGattCharacteristic);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("requestId", Integer.valueOf(i));
                        hashMap.put("offset", Integer.valueOf(i2));
                        BluetoothSlave.this.characteristicSaveToMap(bluetoothGattCharacteristic, hashMap);
                        BluetoothSlave.this.saveBytesToMap(bluetoothGattCharacteristic.getValue(), BluetoothSlave.this.receiveDataType, BluetoothSlave.this.receiveDataCharsetName, hashMap, "value");
                        hashMap.put("opt", "onCharacteristicReadRequest");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onCharacteristicWriteRequest(BluetoothDevice bluetoothDevice, int i, BluetoothGattCharacteristic bluetoothGattCharacteristic, boolean z, boolean z2, int i2, byte[] bArr) {
                    super.onCharacteristicWriteRequest(bluetoothDevice, i, bluetoothGattCharacteristic, z, z2, i2, bArr);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("requestId", Integer.valueOf(i));
                        BluetoothSlave.this.characteristicSaveToMap(bluetoothGattCharacteristic, hashMap);
                        hashMap.put("preparedWrite", Boolean.valueOf(z));
                        hashMap.put("responseNeeded", Boolean.valueOf(z2));
                        hashMap.put("offset", Integer.valueOf(i2));
                        BluetoothSlave bluetoothSlave = BluetoothSlave.this;
                        bluetoothSlave.saveBytesToMap(bArr, bluetoothSlave.receiveDataType, BluetoothSlave.this.receiveDataCharsetName, hashMap, "value");
                        hashMap.put("opt", "onCharacteristicWriteRequest");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onDescriptorReadRequest(BluetoothDevice bluetoothDevice, int i, int i2, BluetoothGattDescriptor bluetoothGattDescriptor) {
                    super.onDescriptorReadRequest(bluetoothDevice, i, i2, bluetoothGattDescriptor);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("requestId", Integer.valueOf(i));
                        hashMap.put("offset", Integer.valueOf(i2));
                        BluetoothSlave.this.descriptorSaveToMap(bluetoothGattDescriptor, hashMap);
                        hashMap.put("opt", "onDescriptorReadRequest");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onDescriptorWriteRequest(BluetoothDevice bluetoothDevice, int i, BluetoothGattDescriptor bluetoothGattDescriptor, boolean z, boolean z2, int i2, byte[] bArr) {
                    super.onDescriptorWriteRequest(bluetoothDevice, i, bluetoothGattDescriptor, z, z2, i2, bArr);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("requestId", Integer.valueOf(i));
                        BluetoothSlave.this.descriptorSaveToMap(bluetoothGattDescriptor, hashMap);
                        hashMap.put("preparedWrite", Boolean.valueOf(z));
                        hashMap.put("responseNeeded", Boolean.valueOf(z2));
                        hashMap.put("offset", Integer.valueOf(i2));
                        BluetoothSlave bluetoothSlave = BluetoothSlave.this;
                        bluetoothSlave.saveBytesToMap(bArr, bluetoothSlave.receiveDataType, BluetoothSlave.this.receiveDataCharsetName, hashMap, "value");
                        hashMap.put("opt", "onDescriptorWriteRequest");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onExecuteWrite(BluetoothDevice bluetoothDevice, int i, boolean z) {
                    super.onExecuteWrite(bluetoothDevice, i, z);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("requestId", Integer.valueOf(i));
                        hashMap.put("execute", Boolean.valueOf(z));
                        hashMap.put("opt", "onExecuteWrite");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onNotificationSent(BluetoothDevice bluetoothDevice, int i) {
                    super.onNotificationSent(bluetoothDevice, i);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("status", Integer.valueOf(i));
                        hashMap.put("opt", "onNotificationSent");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onMtuChanged(BluetoothDevice bluetoothDevice, int i) {
                    super.onMtuChanged(bluetoothDevice, i);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("mtu", Integer.valueOf(i));
                        hashMap.put("opt", "onMtuChanged");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onPhyUpdate(BluetoothDevice bluetoothDevice, int i, int i2, int i3) {
                    super.onPhyUpdate(bluetoothDevice, i, i2, i3);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("txPhy", Integer.valueOf(i));
                        hashMap.put("rxPhy", Integer.valueOf(i2));
                        hashMap.put("status", Integer.valueOf(i3));
                        hashMap.put("opt", "onPhyUpdate");
                        BluetoothSlave.this.jsCallback.invokeAndKeepAlive(hashMap);
                    }
                }

                @Override // android.bluetooth.BluetoothGattServerCallback
                public void onPhyRead(BluetoothDevice bluetoothDevice, int i, int i2, int i3) {
                    super.onPhyRead(bluetoothDevice, i, i2, i3);
                    if (BluetoothSlave.this.jsCallback != null) {
                        HashMap hashMap = new HashMap();
                        BluetoothSlave.this.deviceSaveToMap(bluetoothDevice, hashMap);
                        hashMap.put("txPhy", Integer.valueOf(i));
                        hashMap.put("rxPhy", Integer.valueOf(i2));
                        hashMap.put("status", Integer.valueOf(i3));
                        hashMap.put("opt", "onPhyRead");
                    }
                }
            };
        }
        return this.bluetoothGattServerCallback;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void saveBytesToMap(byte[] bArr, int i, String str, Map map, String str2) {
        if (bArr != null) {
            if (i == 0) {
                map.put(str2, ByteUtils.hexToStr(bArr));
            } else if (i == 1) {
                map.put(str2, StringUtils.byteToString(bArr, str));
            } else {
                map.put(str2, bArr);
            }
        }
    }

    private byte[] getBytesFromJSON(JSONObject jSONObject, String str) {
        Object obj = jSONObject.get(str);
        if (obj == null) {
            return null;
        }
        Integer integer = jSONObject.getInteger("dataType");
        if ((integer != null ? integer.intValue() : -1) == 1) {
            if (obj instanceof String) {
                return StringUtils.stringToByte((String) obj, jSONObject.getString("charsetName"));
            }
            return null;
        } else if (obj != null) {
            if (obj instanceof String) {
                return ByteUtils.hexStrToByteArray((String) obj);
            }
            if (obj instanceof JSONArray) {
                JSONArray jSONArray = (JSONArray) obj;
                byte[] bArr = new byte[jSONArray.size()];
                for (int i = 0; i < jSONArray.size(); i++) {
                    bArr[i] = ByteUtils.intToByte(jSONArray.getIntValue(i));
                }
                return bArr;
            }
            return null;
        } else {
            return null;
        }
    }

    private AdvertiseData getAdvertiseData(JSONObject jSONObject) {
        AdvertiseData.Builder builder = new AdvertiseData.Builder();
        Boolean bool = jSONObject.getBoolean("includeDeviceName");
        if (bool != null) {
            builder.setIncludeDeviceName(bool.booleanValue());
        }
        Boolean bool2 = jSONObject.getBoolean("includeTxPowerLevel");
        if (bool2 != null) {
            builder.setIncludeTxPowerLevel(bool2.booleanValue());
        }
        Integer integer = jSONObject.getInteger("manufacturerId");
        byte[] bytes = getBytes(jSONObject, "manufacturerSpecificData");
        if (integer != null && bytes != null) {
            builder.addManufacturerData(integer.intValue(), bytes);
        }
        JSONArray jSONArray = jSONObject.getJSONArray("serviceUuids");
        if (jSONArray != null && jSONArray.size() > 0) {
            int size = jSONArray.size();
            for (int i = 0; i < size; i++) {
                builder.addServiceUuid(ParcelUuid.fromString(jSONArray.getString(i)));
            }
        }
        String string = jSONObject.getString("serviceDataUuid");
        byte[] bytes2 = getBytes(jSONObject, "serviceData");
        if (string != null && bytes2 != null) {
            builder.addServiceData(ParcelUuid.fromString(string), bytes2);
        }
        return builder.build();
    }

    private BluetoothLeAdvertiser getBluetoothLeAdvertiser(Context context) {
        BluetoothAdapter bluetoothAdapter;
        if (this.bluetoothLeAdvertiser == null && (bluetoothAdapter = getBluetoothAdapter(context)) != null) {
            this.bluetoothLeAdvertiser = bluetoothAdapter.getBluetoothLeAdvertiser();
        }
        return this.bluetoothLeAdvertiser;
    }

    public BluetoothAdapter getBluetoothAdapter(Context context) {
        BluetoothManager bluetoothManager;
        if (this.bluetoothAdapter == null && (bluetoothManager = getBluetoothManager(context)) != null) {
            this.bluetoothAdapter = bluetoothManager.getAdapter();
        }
        return this.bluetoothAdapter;
    }

    public BluetoothManager getBluetoothManager(Context context) {
        if (this.bluetoothManager == null) {
            this.bluetoothManager = (BluetoothManager) context.getSystemService("bluetooth");
        }
        return this.bluetoothManager;
    }

    byte[] getBytes(JSONObject jSONObject, String str) {
        Object obj = jSONObject.get(str);
        if (obj != null) {
            if (obj instanceof String) {
                return ByteUtils.hexStrToByteArray((String) obj);
            }
            if (obj instanceof JSONArray) {
                JSONArray jSONArray = (JSONArray) obj;
                byte[] bArr = new byte[jSONArray.size()];
                for (int i = 0; i < jSONArray.size(); i++) {
                    bArr[i] = ByteUtils.intToByte(jSONArray.getIntValue(i));
                }
                return bArr;
            }
        }
        return null;
    }

    public void callError(UniJSCallback uniJSCallback, Integer num, String str) {
        if (uniJSCallback != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("flag", false);
            if (num != null) {
                hashMap.put("errorCode", num);
            }
            if (str != null) {
                hashMap.put(NotificationCompat.CATEGORY_MESSAGE, str);
            }
            uniJSCallback.invoke(hashMap);
        }
    }

    private Map descriptorToMap(BluetoothGattDescriptor bluetoothGattDescriptor) {
        if (bluetoothGattDescriptor != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("uuid", bluetoothGattDescriptor.getUuid().toString());
            hashMap.put("permissions", Integer.valueOf(bluetoothGattDescriptor.getPermissions()));
            saveBytesToMap(bluetoothGattDescriptor.getValue(), this.receiveDataType, this.receiveDataCharsetName, hashMap, "value");
            return hashMap;
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void descriptorSaveToMap(BluetoothGattDescriptor bluetoothGattDescriptor, Map map) {
        Map descriptorToMap = descriptorToMap(bluetoothGattDescriptor);
        if (descriptorToMap != null) {
            map.put("descriptor", descriptorToMap);
        }
    }

    private Map characteristicToMap(BluetoothGattCharacteristic bluetoothGattCharacteristic) {
        if (bluetoothGattCharacteristic != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("uuid", bluetoothGattCharacteristic.getUuid().toString());
            saveBytesToMap(bluetoothGattCharacteristic.getValue(), this.receiveDataType, this.receiveDataCharsetName, hashMap, "value");
            hashMap.put("instanceId", Integer.valueOf(bluetoothGattCharacteristic.getInstanceId()));
            hashMap.put("properties", Integer.valueOf(bluetoothGattCharacteristic.getProperties()));
            hashMap.put("permissions", Integer.valueOf(bluetoothGattCharacteristic.getPermissions()));
            hashMap.put("writeType", Integer.valueOf(bluetoothGattCharacteristic.getWriteType()));
            List<BluetoothGattDescriptor> descriptors = bluetoothGattCharacteristic.getDescriptors();
            if (descriptors != null && descriptors.size() > 0) {
                int size = descriptors.size();
                ArrayList arrayList = new ArrayList();
                for (int i = 0; i < size; i++) {
                    Map descriptorToMap = descriptorToMap(descriptors.get(i));
                    if (descriptorToMap != null) {
                        arrayList.add(descriptorToMap);
                    }
                }
                hashMap.put("descriptors", arrayList);
            }
            return hashMap;
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void characteristicSaveToMap(BluetoothGattCharacteristic bluetoothGattCharacteristic, Map map) {
        Map characteristicToMap = characteristicToMap(bluetoothGattCharacteristic);
        if (characteristicToMap != null) {
            map.put("characteristic", characteristicToMap);
        }
    }

    private Map serviceToMap(BluetoothGattService bluetoothGattService) {
        if (bluetoothGattService != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("uuid", bluetoothGattService.getUuid().toString());
            hashMap.put("instanceId", Integer.valueOf(bluetoothGattService.getInstanceId()));
            hashMap.put("type", Integer.valueOf(bluetoothGattService.getType()));
            List<BluetoothGattCharacteristic> characteristics = bluetoothGattService.getCharacteristics();
            if (characteristics != null && characteristics.size() > 0) {
                int size = characteristics.size();
                ArrayList arrayList = new ArrayList();
                for (int i = 0; i < size; i++) {
                    Map characteristicToMap = characteristicToMap(characteristics.get(i));
                    if (characteristicToMap != null) {
                        arrayList.add(characteristicToMap);
                    }
                }
                hashMap.put("characteristics", arrayList);
            }
            List<BluetoothGattService> includedServices = bluetoothGattService.getIncludedServices();
            if (includedServices != null && includedServices.size() > 0) {
                int size2 = includedServices.size();
                ArrayList arrayList2 = new ArrayList();
                for (int i2 = 0; i2 < size2; i2++) {
                    Map serviceToMap = serviceToMap(includedServices.get(i2));
                    if (serviceToMap != null) {
                        arrayList2.add(serviceToMap);
                    }
                }
                hashMap.put("includedServices", arrayList2);
            }
            return (Map) JsonUtils.modelOrList2Map(bluetoothGattService);
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void serviceSaveToMap(BluetoothGattService bluetoothGattService, Map map) {
        Map serviceToMap = serviceToMap(bluetoothGattService);
        if (serviceToMap != null) {
            map.put("service", serviceToMap);
        }
    }

    private Map deviceToMap(BluetoothDevice bluetoothDevice) {
        String alias;
        if (bluetoothDevice != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("address", bluetoothDevice.getAddress());
            hashMap.put("name", bluetoothDevice.getName());
            if (Build.VERSION.SDK_INT >= 30) {
                alias = bluetoothDevice.getAlias();
                hashMap.put(Constants.Name.Recycler.LIST_DATA_ITEM, alias);
            }
            hashMap.put("type", Integer.valueOf(bluetoothDevice.getType()));
            hashMap.put("bondState", Integer.valueOf(bluetoothDevice.getBondState()));
            return hashMap;
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void deviceSaveToMap(BluetoothDevice bluetoothDevice, Map map) {
        Map deviceToMap = deviceToMap(bluetoothDevice);
        if (deviceToMap != null) {
            map.put("device", deviceToMap);
        }
    }

    private void bytesSaveToMap(byte[] bArr, Map map) {
        if (bArr != null) {
            map.put("value", bArr);
        }
    }
}
