package com.taobao.weex.devtools.debug;

import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.Process;
import android.provider.Settings;
import android.text.TextUtils;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.alibaba.fastjson.JSON;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.bridge.WXDebugJsBridge;
import com.taobao.weex.common.IWXBridge;
import com.taobao.weex.common.IWXDebugConfig;
import com.taobao.weex.devtools.WeexInspector;
import com.taobao.weex.devtools.common.LogRedirector;
import com.taobao.weex.devtools.common.Util;
import com.taobao.weex.devtools.debug.SocketClient;
import com.taobao.weex.devtools.inspector.MessageHandlingException;
import com.taobao.weex.devtools.inspector.MethodDispatcher;
import com.taobao.weex.devtools.inspector.MismatchedResponseException;
import com.taobao.weex.devtools.inspector.jsonrpc.JsonRpcException;
import com.taobao.weex.devtools.inspector.jsonrpc.JsonRpcPeer;
import com.taobao.weex.devtools.inspector.jsonrpc.PendingRequest;
import com.taobao.weex.devtools.inspector.jsonrpc.protocol.JsonRpcError;
import com.taobao.weex.devtools.inspector.jsonrpc.protocol.JsonRpcRequest;
import com.taobao.weex.devtools.inspector.jsonrpc.protocol.JsonRpcResponse;
import com.taobao.weex.devtools.inspector.protocol.ChromeDevtoolsDomain;
import com.taobao.weex.devtools.json.ObjectMapper;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.BaseInfo;
import java.io.IOException;
import java.util.HashMap;
import org.json.JSONException;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class DebugServerProxy {
    private static final String DEVTOOL_VERSION = "0.16.21";
    private static final String TAG = "DebugServerProxy";
    private Context mContext;
    private Iterable<ChromeDevtoolsDomain> mDomainModules;
    private MethodDispatcher mMethodDispatcher;
    private JsonRpcPeer mPeer;
    private WXDebugBridge mWXBridge;
    private WXDebugJsBridge mWXDebugJsBridge;
    private WXBridgeManager mWXJsManager;
    private SocketClient mWebSocketClient;
    private ObjectMapper mObjectMapper = new ObjectMapper();
    public String mRemoteUrl = WXEnvironment.sRemoteDebugProxyUrl;

    public DebugServerProxy(Context context, IWXDebugConfig iWXDebugConfig) {
        if (context == null) {
            throw new IllegalArgumentException("Context of DebugServerProxy should not be null");
        }
        this.mContext = context;
        SocketClient create = SocketClientFactory.create(this);
        this.mWebSocketClient = create;
        this.mPeer = new JsonRpcPeer(this.mObjectMapper, create);
        if (iWXDebugConfig != null) {
            if (iWXDebugConfig.getWXJSManager() != null) {
                this.mWXJsManager = iWXDebugConfig.getWXJSManager();
            }
            if (iWXDebugConfig.getWXDebugJsBridge() != null) {
                this.mWXDebugJsBridge = iWXDebugConfig.getWXDebugJsBridge();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.taobao.weex.devtools.debug.DebugServerProxy$2  reason: invalid class name */
    /* loaded from: classes.dex */
    public static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$com$taobao$weex$devtools$inspector$jsonrpc$protocol$JsonRpcError$ErrorCode;

        static {
            int[] iArr = new int[JsonRpcError.ErrorCode.values().length];
            $SwitchMap$com$taobao$weex$devtools$inspector$jsonrpc$protocol$JsonRpcError$ErrorCode = iArr;
            try {
                iArr[JsonRpcError.ErrorCode.METHOD_NOT_FOUND.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
        }
    }

    private static void logDispatchException(JsonRpcException jsonRpcException) {
        JsonRpcError errorMessage = jsonRpcException.getErrorMessage();
        if (AnonymousClass2.$SwitchMap$com$taobao$weex$devtools$inspector$jsonrpc$protocol$JsonRpcError$ErrorCode[errorMessage.code.ordinal()] == 1) {
            LogRedirector.d(TAG, "Method not implemented: " + errorMessage.message);
            return;
        }
        LogRedirector.w(TAG, "Error processing remote message", jsonRpcException);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String getDeviceId(Context context) {
        String str = Build.SERIAL;
        return TextUtils.isEmpty(str) ? Settings.Secure.getString(context.getContentResolver(), "android_id") : str;
    }

    public void start() {
        synchronized (DebugServerProxy.class) {
            if (this.mContext == null) {
                new IllegalArgumentException("Context is null").printStackTrace();
                return;
            }
            WXEnvironment.sDebugServerConnectable = true;
            WeexInspector.initializeWithDefaults(this.mContext);
            WXDebugBridge wXDebugBridge = WXDebugBridge.getInstance();
            this.mWXBridge = wXDebugBridge;
            wXDebugBridge.setSession(this.mWebSocketClient);
            this.mWXBridge.setWXDebugJsBridge(this.mWXDebugJsBridge);
            this.mWebSocketClient.connect(this.mRemoteUrl, new SocketClient.Callback() { // from class: com.taobao.weex.devtools.debug.DebugServerProxy.1
                private String getShakeHandsMessage() {
                    HashMap hashMap = new HashMap();
                    hashMap.put("name", WXEnvironment.getApplication().getPackageName() + " : " + Process.myPid());
                    hashMap.put("model", WXEnvironment.SYS_MODEL);
                    hashMap.put("weexVersion", WXEnvironment.WXSDK_VERSION);
                    hashMap.put("devtoolVersion", DebugServerProxy.DEVTOOL_VERSION);
                    HashMap hashMap2 = new HashMap();
                    hashMap2.put("compilerVersion", BaseInfo.uniVersionV3);
                    hashMap.put("uni-app", hashMap2);
                    hashMap.put("platform", WXEnvironment.OS);
                    DebugServerProxy debugServerProxy = DebugServerProxy.this;
                    hashMap.put("deviceId", debugServerProxy.getDeviceId(debugServerProxy.mContext));
                    hashMap.put("network", Boolean.valueOf(WXEnvironment.sDebugNetworkEventReporterEnable));
                    if (WXEnvironment.sLogLevel != null) {
                        hashMap.put("logLevel", "log");
                    }
                    hashMap.put("remoteDebug", Boolean.valueOf(WXEnvironment.sRemoteDebugMode));
                    HashMap hashMap3 = new HashMap();
                    hashMap3.put("id", WXInstanceApm.VALUE_ERROR_CODE_DEFAULT);
                    hashMap3.put("method", "WxDebug.registerDevice");
                    hashMap3.put("params", hashMap);
                    return JSON.toJSONString(hashMap3);
                }

                @Override // com.taobao.weex.devtools.debug.SocketClient.Callback
                public void onSuccess(String str) {
                    synchronized (DebugServerProxy.class) {
                        if (DebugServerProxy.this.mWebSocketClient != null && DebugServerProxy.this.mWebSocketClient.isOpen()) {
                            DebugServerProxy.this.mWebSocketClient.sendText(getShakeHandsMessage());
                            if (DebugServerProxy.this.mWXBridge != null) {
                                DebugServerProxy.this.mWXBridge.onConnected();
                            }
                            DebugServerProxy debugServerProxy = DebugServerProxy.this;
                            debugServerProxy.mDomainModules = new WeexInspector.DefaultInspectorModulesBuilder(debugServerProxy.mContext).finish();
                            DebugServerProxy debugServerProxy2 = DebugServerProxy.this;
                            debugServerProxy2.mMethodDispatcher = new MethodDispatcher(debugServerProxy2.mObjectMapper, DebugServerProxy.this.mDomainModules);
                            Logger.d("haha", "connect debugger server success! " + System.identityHashCode(DebugServerProxy.this.mWebSocketClient));
                            PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "setDebugSocketStatus", null, new Class[]{String.class}, new Object[]{AbsoluteConst.WEEX_DEBUG_CONNECT_SUCCESS});
                            Intent intent = new Intent(AbsoluteConst.WEEX_DEBUG_CONNECT_BROADCAST);
                            intent.putExtra(AbsoluteConst.WEEX_DEBUG_CONNECT_BROADCAST_KEY, AbsoluteConst.WEEX_DEBUG_CONNECT_SUCCESS);
                            LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).sendBroadcast(intent);
                            if (DebugServerProxy.this.mWXJsManager != null) {
                                DebugServerProxy.this.mWXJsManager.initScriptsFramework(null);
                            }
                        }
                    }
                }

                @Override // com.taobao.weex.devtools.debug.SocketClient.Callback
                public void onFailure(Throwable th) {
                    synchronized (DebugServerProxy.class) {
                        if (DebugServerProxy.this.mWXBridge != null) {
                            DebugServerProxy.this.mWXBridge.onDisConnected();
                        }
                        Logger.d("haha", "connect debugger server failure!! " + System.identityHashCode(DebugServerProxy.this.mWebSocketClient));
                        Logger.d("haha", "连接失败信息 = " + th.getMessage());
                        PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "setDebugSocketStatus", null, new Class[]{String.class}, new Object[]{AbsoluteConst.WEEX_DEBUG_CONNECT_FAILED});
                        Intent intent = new Intent(AbsoluteConst.WEEX_DEBUG_CONNECT_BROADCAST);
                        intent.putExtra(AbsoluteConst.WEEX_DEBUG_CONNECT_BROADCAST_KEY, AbsoluteConst.WEEX_DEBUG_CONNECT_FAILED);
                        LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).sendBroadcast(intent);
                        th.printStackTrace();
                    }
                }
            });
        }
    }

    public boolean isActive() {
        SocketClient socketClient = this.mWebSocketClient;
        return socketClient != null && socketClient.isOpen();
    }

    public void stop(boolean z) {
        synchronized (DebugServerProxy.class) {
            SocketClient socketClient = this.mWebSocketClient;
            if (socketClient != null) {
                socketClient.close(0, null);
                this.mWebSocketClient = null;
            }
            this.mWXBridge = null;
            if (z) {
                switchLocalRuntime();
            }
        }
    }

    private void switchLocalRuntime() {
        WXSDKEngine.reload(WXEnvironment.getApplication(), false);
        WXEnvironment.getApplication().sendBroadcast(new Intent().setAction(WXSDKInstance.ACTION_DEBUG_INSTANCE_REFRESH).putExtra("params", ""));
    }

    public IWXBridge getWXBridge() {
        if (this.mWXBridge == null) {
            WXLogUtils.e(TAG, "WXDebugBridge is null!");
        }
        return this.mWXBridge;
    }

    public void handleMessage(String str) {
        try {
            Util.throwIfNull(this.mPeer);
            handleRemoteMessage(this.mPeer, str);
        } catch (Exception e) {
            if (LogRedirector.isLoggable(TAG, 2)) {
                LogRedirector.v(TAG, "Unexpected I/O exception processing message: " + e);
            }
        }
    }

    private void handleRemoteMessage(JsonRpcPeer jsonRpcPeer, String str) throws IOException, MessageHandlingException, JSONException {
        JSONObject jSONObject = new JSONObject(str);
        if (jSONObject.has("method")) {
            handleRemoteRequest(jsonRpcPeer, jSONObject);
        } else if (jSONObject.has("result")) {
            handleRemoteResponse(jsonRpcPeer, jSONObject);
        } else {
            throw new MessageHandlingException("Improper JSON-RPC message: " + str);
        }
    }

    private void handleRemoteRequest(JsonRpcPeer jsonRpcPeer, JSONObject jSONObject) throws MessageHandlingException {
        JSONObject jSONObject2;
        JSONObject jSONObject3;
        String jSONObject4;
        JsonRpcRequest jsonRpcRequest = (JsonRpcRequest) this.mObjectMapper.convertValue(jSONObject, JsonRpcRequest.class);
        try {
            jSONObject3 = this.mMethodDispatcher.dispatch(jsonRpcPeer, jsonRpcRequest.method, jsonRpcRequest.params);
            jSONObject2 = null;
        } catch (JsonRpcException e) {
            logDispatchException(e);
            jSONObject2 = (JSONObject) this.mObjectMapper.convertValue(e.getErrorMessage(), JSONObject.class);
            jSONObject3 = null;
        }
        if (jsonRpcRequest.id != null) {
            JsonRpcResponse jsonRpcResponse = new JsonRpcResponse();
            jsonRpcResponse.id = jsonRpcRequest.id.longValue();
            jsonRpcResponse.result = jSONObject3;
            jsonRpcResponse.error = jSONObject2;
            try {
                jSONObject4 = ((JSONObject) this.mObjectMapper.convertValue(jsonRpcResponse, JSONObject.class)).toString();
            } catch (OutOfMemoryError e2) {
                jsonRpcResponse.result = null;
                jsonRpcResponse.error = (JSONObject) this.mObjectMapper.convertValue(e2.getMessage(), JSONObject.class);
                jSONObject4 = ((JSONObject) this.mObjectMapper.convertValue(jsonRpcResponse, JSONObject.class)).toString();
            }
            jsonRpcPeer.getWebSocket().sendText(jSONObject4);
        }
    }

    private void handleRemoteResponse(JsonRpcPeer jsonRpcPeer, JSONObject jSONObject) throws MismatchedResponseException {
        JsonRpcResponse jsonRpcResponse = (JsonRpcResponse) this.mObjectMapper.convertValue(jSONObject, JsonRpcResponse.class);
        PendingRequest andRemovePendingRequest = jsonRpcPeer.getAndRemovePendingRequest(jsonRpcResponse.id);
        if (andRemovePendingRequest == null) {
            throw new MismatchedResponseException(jsonRpcResponse.id);
        }
        if (andRemovePendingRequest.callback != null) {
            andRemovePendingRequest.callback.onResponse(jsonRpcPeer, jsonRpcResponse);
        }
    }
}
