package com.taobao.weex.devtools.inspector.elements.android;

import android.os.Handler;
import android.os.Looper;
import android.view.View;
import com.taobao.weex.devtools.common.Util;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;
import javax.annotation.Nullable;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public abstract class ViewHighlighter {
    public abstract void clearHighlight();

    public abstract void setHighlightedView(View view, int i);

    public static ViewHighlighter newInstance() {
        return new OverlayHighlighter();
    }

    protected ViewHighlighter() {
    }

    /* loaded from: classes.dex */
    private static final class NoopHighlighter extends ViewHighlighter {
        @Override // com.taobao.weex.devtools.inspector.elements.android.ViewHighlighter
        public void clearHighlight() {
        }

        @Override // com.taobao.weex.devtools.inspector.elements.android.ViewHighlighter
        public void setHighlightedView(View view, int i) {
        }

        private NoopHighlighter() {
        }
    }

    /* loaded from: classes.dex */
    private static final class OverlayHighlighter extends ViewHighlighter {
        private View mHighlightedView;
        private final ViewHighlightOverlays mHighlightOverlays = ViewHighlightOverlays.newInstance();
        private AtomicReference<View> mViewToHighlight = new AtomicReference<>();
        private AtomicInteger mContentColor = new AtomicInteger();
        private final Runnable mHighlightViewOnUiThreadRunnable = new Runnable() { // from class: com.taobao.weex.devtools.inspector.elements.android.ViewHighlighter.OverlayHighlighter.1
            @Override // java.lang.Runnable
            public void run() {
                OverlayHighlighter.this.highlightViewOnUiThread();
            }
        };
        private final Handler mHandler = new Handler(Looper.getMainLooper());

        @Override // com.taobao.weex.devtools.inspector.elements.android.ViewHighlighter
        public void clearHighlight() {
            setHighlightedViewImpl(null, 0);
        }

        @Override // com.taobao.weex.devtools.inspector.elements.android.ViewHighlighter
        public void setHighlightedView(View view, int i) {
            setHighlightedViewImpl((View) Util.throwIfNull(view), i);
        }

        private void setHighlightedViewImpl(@Nullable View view, int i) {
            this.mHandler.removeCallbacks(this.mHighlightViewOnUiThreadRunnable);
            this.mViewToHighlight.set(view);
            this.mContentColor.set(i);
            this.mHandler.postDelayed(this.mHighlightViewOnUiThreadRunnable, 100L);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void highlightViewOnUiThread() {
            View andSet = this.mViewToHighlight.getAndSet(null);
            View view = this.mHighlightedView;
            if (andSet == view) {
                return;
            }
            if (view != null) {
                this.mHighlightOverlays.removeHighlight(view);
            }
            if (andSet != null) {
                this.mHighlightOverlays.highlightView(andSet, this.mContentColor.get());
            }
            this.mHighlightedView = andSet;
        }
    }
}
