package com.taobao.weex.devtools.inspector.network.utils;

import android.util.Pair;
import com.alibaba.android.bindingx.core.BindingXEventType;
import com.taobao.weex.devtools.inspector.network.NetworkEventReporter;
import com.taobao.weex.devtools.inspector.network.Timing;
import com.taobao.weex.ui.module.WXModalUIModule;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class ResponseConverter {
    public static NetworkEventReporter.InspectorResponse convertFrom(Map<String, Object> map) {
        return new GeneralResponse(map);
    }

    /* loaded from: classes.dex */
    private static class GeneralResponse implements NetworkEventReporter.TimingInspectorResponse {
        private Map<String, Object> data;
        List<Pair<String, String>> headers;

        public GeneralResponse(Map<String, Object> map) {
            ArrayList arrayList = new ArrayList(0);
            this.headers = arrayList;
            this.data = map;
            this.headers = (List) ExtractUtil.getValue(map, "headers", arrayList);
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponse
        public String url() {
            return (String) ExtractUtil.getValue(this.data, "url", "unknown");
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponse
        public boolean connectionReused() {
            return ((Boolean) ExtractUtil.getValue(this.data, "connectionReused", false)).booleanValue();
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponse
        public int connectionId() {
            return ((Integer) ExtractUtil.getValue(this.data, "connectionId", 0)).intValue();
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponse
        public boolean fromDiskCache() {
            return ((Boolean) ExtractUtil.getValue(this.data, "fromDiskCache", false)).booleanValue();
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponseCommon
        public String requestId() {
            return (String) ExtractUtil.getValue(this.data, "requestId", "-1");
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponseCommon
        public int statusCode() {
            return ((Integer) ExtractUtil.getValue(this.data, "statusCode", 200)).intValue();
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorResponseCommon
        public String reasonPhrase() {
            return (String) ExtractUtil.getValue(this.data, "reasonPhrase", WXModalUIModule.OK);
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorHeaders
        public int headerCount() {
            return this.headers.size();
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorHeaders
        public String headerName(int i) {
            return (String) this.headers.get(i).first;
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorHeaders
        public String headerValue(int i) {
            return (String) this.headers.get(i).second;
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.InspectorHeaders
        public String firstHeaderValue(String str) {
            for (Pair<String, String> pair : this.headers) {
                if (pair.first != null && ((String) pair.first).equalsIgnoreCase(str)) {
                    return (String) pair.second;
                }
            }
            return null;
        }

        @Override // com.taobao.weex.devtools.inspector.network.NetworkEventReporter.TimingInspectorResponse
        public Timing resourceTiming() {
            Map<String, Object> map = (Map) ExtractUtil.getValue(this.data, BindingXEventType.TYPE_TIMING, new HashMap());
            if (map.isEmpty()) {
                return null;
            }
            Timing timing = new Timing();
            timing.requestTime = optValue(map, "requestTime");
            if (timing.requestTime == 0.0d) {
                return null;
            }
            timing.proxyStart = optValue(map, "sendBeforeTime") + optValue(map, "waitingTime");
            timing.proxyEnd = timing.proxyStart + 0.0d;
            timing.dnsStart = timing.proxyEnd + 0.0d;
            timing.dnsEnd = timing.dnsStart + 0.0d;
            timing.connectStart = timing.dnsEnd + 0.0d;
            timing.sslStart = timing.connectStart + 0.0d;
            timing.sendEnd = timing.sslStart + 0.0d;
            timing.connectEnd = timing.connectStart + optValue(map, "firstDataTime");
            timing.sendStart = timing.connectEnd + 0.0d;
            timing.sendEnd = timing.sendStart + optValue(map, "sendDataTime");
            timing.receiveHeadersEnd = timing.sendEnd + optValue(map, "serverRT") + optValue(map, "recDataTime");
            return timing;
        }

        private double optValue(Map<String, Object> map, String str) {
            try {
                Object obj = map.get(str);
                if (obj != null && !obj.toString().isEmpty()) {
                    return Double.valueOf(map.get(str).toString()).doubleValue();
                }
            } catch (NumberFormatException unused) {
            }
            return 0.0d;
        }
    }
}
