package com.taobao.weex.devtools.toolbox;

import android.content.Context;
import android.graphics.Color;
import android.graphics.Typeface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.TextView;
import androidx.fragment.app.Fragment;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.ITracingAdapter;
import com.taobao.weex.devtools.adapter.WXTracingAdapter;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.feature.weex_devtool.R;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class EventDetailFragment extends Fragment {
    private TextView eventName;
    private TextView eventPayload;
    private WXTracing.TraceEvent rootEvent;
    private View rootView;
    private LinearLayout subEvents;

    public static EventDetailFragment getFragment(int i, int i2) {
        EventDetailFragment eventDetailFragment = new EventDetailFragment();
        Bundle bundle = new Bundle();
        bundle.putInt("instanceId", i);
        bundle.putInt("traceId", i2);
        eventDetailFragment.setArguments(bundle);
        return eventDetailFragment;
    }

    @Override // androidx.fragment.app.Fragment
    public View onCreateView(LayoutInflater layoutInflater, ViewGroup viewGroup, Bundle bundle) {
        int i = getArguments().getInt("instanceId");
        int i2 = getArguments().getInt("traceId");
        ITracingAdapter tracingAdapter = WXSDKManager.getInstance().getTracingAdapter();
        if (tracingAdapter != null && (tracingAdapter instanceof WXTracingAdapter)) {
            this.rootEvent = ((WXTracingAdapter) tracingAdapter).getTraceEventByInstanceId(i).subEvents.get(i2);
        }
        this.rootView = layoutInflater.inflate(R.layout.fragment_event_detail, viewGroup, false);
        instantiationViews();
        this.eventName.setText(this.rootEvent.fname);
        for (int i3 = 0; i3 < this.rootEvent.subEvents.size(); i3++) {
            WXTracing.TraceEvent valueAt = this.rootEvent.subEvents.valueAt(i3);
            if (!"DomExecute".equals(valueAt.fname) && !"UIExecute".equals(valueAt.fname)) {
                EventView eventView = new EventView(getContext());
                eventView.desc.setText(valueAt.fname);
                this.subEvents.addView(eventView);
                int screenWidth = (int) (((valueAt.ts - this.rootEvent.ts) / this.rootEvent.duration) * (WXViewUtils.getScreenWidth(getContext()) - WXViewUtils.dip2px(8.0f)));
                ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) eventView.indicator.getLayoutParams();
                marginLayoutParams.width = ((int) ((valueAt.duration / this.rootEvent.duration) * WXViewUtils.getScreenWidth(getContext()))) + WXViewUtils.dip2px(2.0f);
                marginLayoutParams.height = -1;
                marginLayoutParams.leftMargin = screenWidth - WXViewUtils.dip2px(2.0f);
                marginLayoutParams.bottomMargin = 1;
                if ("DOMThread".equals(valueAt.tname)) {
                    eventView.indicator.setBackgroundColor(Color.parseColor("#84A6E8"));
                } else if ("UIThread".equals(valueAt.tname)) {
                    eventView.indicator.setBackgroundColor(Color.parseColor("#83B86E"));
                } else {
                    eventView.indicator.setBackgroundColor(-16711681);
                }
                eventView.indicator.setLayoutParams(marginLayoutParams);
                TextView textView = eventView.duration;
                textView.setText(valueAt.duration + " ms");
            }
        }
        if (this.rootEvent.payload != null) {
            try {
                if (this.rootEvent.payload.startsWith(Operators.BLOCK_START_STR)) {
                    JSONObject jSONObject = new JSONObject(this.rootEvent.payload);
                    this.rootEvent.payload = jSONObject.toString(2);
                } else if (this.rootEvent.payload.startsWith(Operators.ARRAY_START_STR)) {
                    JSONArray jSONArray = new JSONArray(this.rootEvent.payload);
                    this.rootEvent.payload = jSONArray.toString(2);
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
            this.eventPayload.setText(this.rootEvent.payload);
        }
        return this.rootView;
    }

    private void instantiationViews() {
        this.eventName = (TextView) this.rootView.findViewById(R.id.event_name);
        this.subEvents = (LinearLayout) this.rootView.findViewById(R.id.sub_events);
        TextView textView = (TextView) this.rootView.findViewById(R.id.event_payload);
        this.eventPayload = textView;
        textView.setTypeface(Typeface.MONOSPACE);
    }

    /* loaded from: classes.dex */
    private static class EventView extends FrameLayout {
        TextView desc;
        TextView duration;
        View indicator;

        public EventView(Context context) {
            super(context);
            init();
        }

        private void init() {
            this.indicator = new View(getContext());
            this.desc = new TextView(getContext());
            TextView textView = new TextView(getContext());
            this.duration = textView;
            textView.setGravity(5);
            addView(this.indicator);
            addView(this.desc);
            addView(this.duration);
        }
    }
}
